<?php
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;

if (!function_exists('wiseguard_widget_cms_accordion_register_controls')) {
    add_action('etc_widget_cms_accordion_register_controls', 'wiseguard_widget_cms_accordion_register_controls', 10, 1);
    function wiseguard_widget_cms_accordion_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_accordion/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_accordion/layout/2.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Heading Section Start
        $widget->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Heading Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
            $widget->add_control(
                'smallheading_text',
                [
                    'label'       => esc_html__( 'Small Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is small heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'condition'   => [
                        'layout' => ['1']
                    ]                    
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'smallheading_color',
                'label'     => esc_html__( 'Small Heading Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-smallheading' => 'color: {{VALUE}};',
                ],
                'separator'   => 'after',
                'condition'   => [
                    'smallheading_text!' => '',
                    'layout' => ['1']
                ]
            ]);
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'heading_color',
                'label'    => esc_html__( 'Heading Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading, {{WRAPPER}} .cms-heading a' => 'color: {{VALUE}};',
                ],
                'separator'   => 'after'
            ]);
            $widget->add_control(
                'description_text',
                [
                    'label'       => esc_html__( 'Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'description_color',
                'label'     => esc_html__( 'Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
        // accordion Section Start
        $widget->start_controls_section(
            'section_cms_accordion',
            [
                'label' => esc_html__('Accordion Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
            $widget->add_control(
                'active_section',
                [
                    'label'     => esc_html__( 'Active section', 'wiseguard' ),
                    'type'      => Controls_Manager::NUMBER,
                    'default'   => '1',
                    'min'       => '0',
                    'max'       => '50',
                    'separator' => 'after',
                ]
            );
            $repeater = new Repeater();
            $repeater->add_control(
                'ac_title',
                [
                    'label'       => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Title',
                    'placeholder' => esc_html__( 'Enter your title', 'wiseguard' ),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'ac_content',
                [
                    'label'       => esc_html__( 'Content', 'wiseguard' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => 'Item content. Click the edit button to change this text.',
                    'placeholder' => esc_html__( 'Enter your content', 'wiseguard' ),
                    'label_block' => true,
                ]
            );
            $widget->add_control(
                'cms_accordion',
                [
                    'label' => esc_html__('List', 'wiseguard'),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                    'default' => [
                        [
                            'ac_title'   => 'Title',
                            'ac_content' => 'Item content. Click the edit button to change this text.',
                        ],
                        [
                            'ac_title'   => 'Title',
                            'ac_content' => 'Item content. Click the edit button to change this text.',
                        ],
                    ],
                    'title_field' => '{{{ ac_title }}}',
                ]
            );
        $widget->end_controls_section(); // accordion Section End
        //  Style tab
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_color',
                'label'    => esc_html__( 'Accordion Title Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-accordion-title' => 'color: {{VALUE}};',
                ],
                'separator' => 'before'
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_active_color',
                'label'    => esc_html__( 'Accordion Active Title Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-accordion-title:hover, {{WRAPPER}} .cms-accordion-title:active' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'content_color',
                'label'    => esc_html__( 'Accordion Content Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-accordion-content' => 'color: {{VALUE}};',
                ],
                'separator' => 'before'
            ]);
        $widget->end_controls_section();
    }
}
