<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_banner_register_controls')) {
    add_action('etc_widget_cms_banner_register_controls', 'wiseguard_widget_cms_banner_register_controls', 10, 1);
    function wiseguard_widget_cms_banner_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_banner/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_banner/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_banner/layout/3.jpg'
                        ],
                        '4' => [
                            'label' => esc_html__( 'Layout 4', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_banner/layout/4.jpg'
                        ],
                        '5' => [
                            'label' => esc_html__( 'Layout 5', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_banner/layout/5.jpg'
                        ],
                        '6' => [
                            'label' => esc_html__( 'Layout 6', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_banner/layout/6.jpg'
                        ],
                        '7' => [
                            'label' => esc_html__( 'Layout 7 (Default post Image)', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_banner/layout/7.jpg'
                        ],
                        '8' => [
                            'label' => esc_html__( 'Layout 8', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_banner/layout/8.jpg'
                        ],
                        '9' => [
                            'label' => esc_html__( 'Layout 9', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_banner/layout/9.jpg'
                        ],
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start

        // single_image Section Start
        $widget->start_controls_section(
            'section_single_image',
            [
                'label' => esc_html__('Banner Image', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
            $widget->add_control(
                'banner',
                [
                    'label'   => esc_html__( 'Banner', 'wiseguard' ),
                    'type'    => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ]
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'banner',
                    'label'   => esc_html__('Image Size','wiseguard'),
                    'default' => 'custom',
                    'condition' => [
                        'banner[url]!' => ''
                    ]
                ]
            );
        $widget->end_controls_section(); // single_image Section End

        $widget->start_controls_section(
            'section_banner_content',
            [
                'label' => esc_html__('Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'small_banner',
                [
                    'label'   => esc_html__( 'Small Banner', 'wiseguard' ),
                    'type'    => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ],
                    'condition' => [
                        'layout' => ['3']
                    ]
                ]
            );
            $widget->add_control(
                'icon',
                [
                    'label'     => esc_html__( 'Icon', 'wiseguard' ),
                    'type'      => Controls_Manager::ICONS,
                    'default'   => [
                        'library' => 'wiseguard-icon',
                        'value'   => 'wiseguard-icon-default' 
                    ],
                    'condition' => [
                        'layout' => ['2','3','4']
                    ]
                ]
            );
            $widget->add_control(
                'icon_pos',
                [
                    'label'     => esc_html__( 'Icon Position', 'wiseguard' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => 'top-left',
                    'options'   => [
                        'top-left'     => esc_html__('Top - Left','wiseguard'),
                        'top-right'    => esc_html__('Top - Right','wiseguard'),
                        'bottom-left'  => esc_html__('Bottom - Left','wiseguard'),
                        'bottom-right' => esc_html__('Bottom - Right','wiseguard'),
                    ],
                    'condition' => [
                        'layout' => ['2']
                    ]
                ]
            );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'condition' => [
                        'layout' => ['3','4','6']
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'heading_color',
                'label'    => esc_html__( 'Heading Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .banner-icon' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout'        => ['3','4','6'],
                    'heading_text!' => ''
                ]
            ]);
            $widget->add_control(
                'description_text',
                [
                    'label'       => esc_html__( 'Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the description',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'condition' => [
                        'layout' => ['6','7','8']
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'description_color',
                'label'    => esc_html__( 'Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'layout'        => ['6','7','8'],
                    'description_text!' => ''
                ]
            ]);
        $widget->end_controls_section(); // single_image Section End
        // Link 1
        $widget->start_controls_section('link1_section',[
            'label' => esc_html__('Link #1', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['8']
            ]
        ]);
            $widget->add_control(
                'link1_text',
                [
                    'label'       => esc_html__( 'Link #1 Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Discover More',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'link1_type',
                [
                    'label'   => esc_html__('Link #1 Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link1_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link1_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link1_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
        // Features
        $widget->start_controls_section('features_section',[
            'label' => esc_html__('Features Settings', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['8']
            ]
        ]);
            //
            $cms_feature = new Repeater();
            $cms_feature->add_control(
                'title',
                [
                    'label'       => esc_html__( 'Title', 'wiseguard' ),
                    'default'     => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );
            $widget->add_control(
                'cms_feature',
                [
                    'label'   => esc_html__('Features List', 'wiseguard'),
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => $cms_feature->get_controls(),
                    'default' => [
                        [
                            'title' => 'Live Stream From Any Mobile and Lifetime Guarantee',
                        ],
                        [
                            'title' => 'Alerts, Schedules, Automations, All Smart Controls',
                        ],
                        [
                            'title' => 'Professional Grade Protection and Monitoring 24/7',
                        ]
                    ],
                    'title_field' => '{{{ title }}}'
                ]
            );
        $widget->end_controls_section();
        // Style Tab
        $widget->start_controls_section(
            'section_style',
            [
                'label' => esc_html__('Style Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
            $widget->add_responsive_control(
                'align',
                [
                    'label'        => esc_html__( 'Alignment', 'wiseguard' ),
                    'type'         => Controls_Manager::CHOOSE,
                    'responsive'   => true,
                    'options'      => [
                        'start'    => [
                            'title' => esc_html__( 'Left', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-left',
                        ],
                        'center'  => [
                            'title' => esc_html__( 'Center', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-center',
                        ],
                        'end'   => [
                            'title' => esc_html__( 'Right', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-right',
                        ],
                        'justify' => [
                            'title' => esc_html__( 'Justified', 'wiseguard' ),
                            'icon' => 'eicon-text-align-justify',
                        ]
                    ],
                    'prefix_class' => 'text%s-'
                ]
            );
            $widget->add_control(
                'as_background',
                [
                    'label' => esc_html__('As Background', 'wiseguard'),
                    'type'  => Controls_Manager::SWITCHER
                ]
            );
            $widget->add_control(
                'min_height',
                [
                    'label' => esc_html__('Min Height', 'wiseguard'),
                    'type'  => Controls_Manager::SWITCHER
                ]
            );
            $widget->add_control(
                'class',
                [
                    'label' => esc_html__('Element Class', 'wiseguard'),
                    'type'  => Controls_Manager::TEXT
                ]
            );
            $widget->add_control(
                'img_class',
                [
                    'label' => esc_html__('Image CSS Class', 'wiseguard'),
                    'type'  => Controls_Manager::TEXT
                ]
            );
        $widget->end_controls_section();
        // Edge Settings
        $widget->start_controls_section(
            'edge_setting',
            [
                'label' => esc_html__('Edge Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'edge1_color',
                'label'    => esc_html__( 'Color #1', 'wiseguard' ),
                'custom'   => false
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'edge2_color',
                'label'    => esc_html__( 'Color #2', 'wiseguard' ),
                'custom'   => false
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'edge3_color',
                'label'    => esc_html__( 'Color #3', 'wiseguard' ),
                'custom'   => false
            ]);
        $widget->end_controls_section();
    }
}
