<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;

if (!function_exists('wiseguard_widget_cms_blog_register_controls')) {
    add_action('etc_widget_cms_blog_register_controls', 'wiseguard_widget_cms_blog_register_controls', 10, 1);
    function wiseguard_widget_cms_blog_register_controls($widget)
    {
        // Layout Settings
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard' ),
                'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__('Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_blog/layout/1.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();

        // Post term options
        $post_term_options = etc_get_grid_term_options('post');

        // Content Tab Start

        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Source', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'source',
            [
                'label' => esc_html__('Select Categories', 'wiseguard'),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $post_term_options,
            ]
        );
        $widget->add_control(
            'orderby',
            [
                'label'   => esc_html__('Order By', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date'   => esc_html__('Date', 'wiseguard'),
                    'ID'     => esc_html__('ID', 'wiseguard'),
                    'author' => esc_html__('Author', 'wiseguard'),
                    'title'  => esc_html__('Title', 'wiseguard'),
                    'rand'   => esc_html__('Random', 'wiseguard'),
                ],
            ]
        );
        $widget->add_control(
            'order',
            [
                'label'   => esc_html__('Sort Order', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__('Descending', 'wiseguard'),
                    'asc'  => esc_html__('Ascending', 'wiseguard'),
                ],
            ]
        );
        $widget->add_control(
            'limit',
            [
                'label'   => esc_html__('Total items', 'wiseguard'),
                'type'    => Controls_Manager::NUMBER
            ]
        );
        $widget->end_controls_section();
        // Heading Section Start
        $widget->start_controls_section(
            'heading_section',
            [
                'label' => esc_html__('Heading Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );  
            // Heading
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true
                ]
            ); 
            // Button
            $widget->add_control(
                'btn_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__( 'Check All Blog Posts', 'wiseguard' ),
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' )
                ]
            );
            $widget->add_control(
                'link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'btn_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'page_link',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'btn_text!' => '',
                        'link_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'btn_text!' => '',
                        'link_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
    }
}
