<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;

if (!function_exists('wiseguard_widget_cms_blog_carousel_register_controls')) {
    add_action('etc_widget_cms_blog_carousel_register_controls', 'wiseguard_widget_cms_blog_carousel_register_controls', 10, 1);
    function wiseguard_widget_cms_blog_carousel_register_controls($widget)
    {
        // Post term options
        $post_term_options = etc_get_grid_term_options('post');
        // Layout Settings
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard' ),
                'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__('Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/layout/1.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start
        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Source', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'source',
            [
                'label' => esc_html__('Select Categories', 'wiseguard'),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $post_term_options,
            ]
        );
        $widget->add_control(
            'orderby',
            [
                'label' => esc_html__('Order By', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date' => esc_html__('Date', 'wiseguard'),
                    'ID' => esc_html__('ID', 'wiseguard'),
                    'author' => esc_html__('Author', 'wiseguard'),
                    'title' => esc_html__('Title', 'wiseguard'),
                    'rand' => esc_html__('Random', 'wiseguard'),
                ],
            ]
        );
        $widget->add_control(
            'order',
            [
                'label' => esc_html__('Sort Order', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__('Descending', 'wiseguard'),
                    'asc' => esc_html__('Ascending', 'wiseguard'),
                ],
            ]
        );
        $widget->add_control(
            'limit',
            [
                'label' => esc_html__('Total items', 'wiseguard'),
                'type' => Controls_Manager::NUMBER,
                'default' => '6',
            ]
        );
        $widget->end_controls_section();
        // Source Section End
        // Display Section Start
        $widget->start_controls_section(
            'display_section',
            [
                'label' => esc_html__('Content Display', 'wiseguard'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'thumbnail',
                    'default' => 'custom',
                ]
            );
            $widget->add_control(
                'num_words',
                [
                    'label'       => esc_html__('Excerpt Length', 'wiseguard'),
                    'type'        => Controls_Manager::NUMBER,
                    'default'     => '',
                    'placeholder' => '25',
                    'separator'   => 'after',
                ]
            );

            $widget->add_control(
                'readmore_text',
                [
                    'label'       => esc_html__('Readmore Text', 'wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'placeholder' => esc_html__('Read More','wiseguard'),
                ]
            );
        $widget->end_controls_section();
        // Display Section End
        // Heading Section Start
        $widget->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Heading Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['1']
                ]
            ]
        );
            $widget->add_control(
                'smallheading_text',
                [
                    'label'       => esc_html__( 'Small Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'separator'   => 'after'
                ]
            );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true
                ]
            );
        $widget->end_controls_section();
        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel Settings', 'wiseguard'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

            $slides_to_show = range(1, 10);
            $slides_to_show = array_combine($slides_to_show, $slides_to_show);
            $widget->add_responsive_control(
                'slides_to_show',
                [
                    'label'   => esc_html__('Slides to Show', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                            '' => esc_html__('Default', 'wiseguard'),
                        ] + $slides_to_show,
                    'frontend_available' => true,
                ]
            );

            $widget->add_responsive_control(
                'slides_to_scroll',
                [
                    'label'       => esc_html__('Slides to Scroll', 'wiseguard'),
                    'type'        => Controls_Manager::SELECT,
                    'description' => esc_html__('Set how many slides are scrolled per swipe.', 'wiseguard'),
                    'options'     => [
                            '' => esc_html__('Default', 'wiseguard'),
                        ] + $slides_to_show,
                    'condition' => [
                        'slides_to_show!' => '1',
                    ],
                    'frontend_available' => true,
                ]
            );
            $widget->add_responsive_control(
                'space_between',
                [
                    'label' => esc_html__('Space Between', 'wiseguard'),
                    'type'  => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'size' => 40,
                    ],
                    'condition' => [
                        'slides_to_show!' => '1',
                    ],
                    'frontend_available' => true,
                ]
            );
            $widget->add_control(
                'lazyload',
                [
                    'label'              => esc_html__('Lazyload', 'wiseguard'),
                    'type'               => Controls_Manager::SWITCHER,
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'autoplay',
                [
                    'label'              => esc_html__('Autoplay', 'wiseguard'),
                    'type'               => \Elementor\Controls_Manager::SWITCHER,
                    'default'            => 'yes',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'pause_on_hover',
                [
                    'label'              => esc_html__('Pause on Hover', 'wiseguard'),
                    'type'               => \Elementor\Controls_Manager::SWITCHER,
                    'default'            => 'yes',
                    'frontend_available' => true,
                    'condition'          => [
                        'autoplay' => 'yes',
                    ],
                ]
            );

            $widget->add_control(
                'pause_on_interaction',
                [
                    'label'              => esc_html__('Pause on Interaction', 'wiseguard'),
                    'type'               => \Elementor\Controls_Manager::SWITCHER,
                    'default'            => 'yes',
                    'frontend_available' => true,
                    'condition'          => [
                        'autoplay' => 'yes',
                    ],
                ]
            );

            $widget->add_control(
                'autoplay_speed',
                [
                    'label'     => esc_html__('Autoplay Speed', 'wiseguard'),
                    'type'      => Controls_Manager::NUMBER,
                    'default'   => 5000,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'infinite',
                [
                    'label'              => esc_html__('Infinite Loop', 'wiseguard'),
                    'type'               => \Elementor\Controls_Manager::SWITCHER,
                    'default'            => 'yes',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'effect',
                [
                    'label'   => esc_html__('Effect', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'default' => 'slide',
                    'options' => [
                        'slide' => esc_html__('Slide', 'wiseguard'),
                        'fade'  => esc_html__('Fade', 'wiseguard'),
                    ],
                    'condition' => [
                        'slides_to_show' => '1',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'speed',
                [
                    'label'              => esc_html__('Animation Speed', 'wiseguard'),
                    'type'               => Controls_Manager::NUMBER,
                    'default'            => 500,
                    'render_type'        => 'none',
                    'frontend_available' => true
                ]
            );
            $widget->add_control(
                'arrows',
                [
                    'label'              => esc_html__('Show Arrows', 'wiseguard'),
                    'type'               => \Elementor\Controls_Manager::SWITCHER,
                    'default'            => 'yes',
                    'frontend_available' => true,
                    'label_block'        => true
                ]
            );
            
            $widget->add_control(
                'arrow_prev_icon',
                [
                    'label'            => esc_html__('Previous Arrow Icon', 'wiseguard'),
                    'type'             => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'skin'             => 'inline',
                    'label_block'      => false,
                    'skin_settings'    => [
                        'inline' => [
                            'none' => [
                                'label' => 'Default',
                                'icon'  => 'cmsi-arrow-left',
                            ],
                            'icon' => [
                                'icon' => 'cmsi-arrow-left',
                            ]
                        ]
                    ],
                    'condition' => [
                        'arrows' => 'yes'
                    ],
                ]
            );
            $widget->add_control(
                'arrow_next_icon',
                [
                    'label'            => esc_html__('Next Arrow Icon', 'wiseguard'),
                    'type'             => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'skin'             => 'inline',
                    'label_block'      => false,
                    'skin_settings'    => [
                        'inline' => [
                            'none' => [
                                'label' => 'Default',
                                'icon'  => 'cmsi-arrow-right',
                            ],
                            'icon' => [
                                'icon' => 'cmsi-arrow-right',
                            ],
                        ],
                    ],
                    'condition' => [
                        'arrows' => 'yes'
                    ],
                ]
            );
            $widget->add_control(
                'dots',
                [
                    'label'              => esc_html__('Show Dots', 'wiseguard'),
                    'type'               => \Elementor\Controls_Manager::SWITCHER,
                    'default'            => 'yes',
                    'frontend_available' => true,
                    'label_block'        => true
                ]
            );
        $widget->end_controls_section();
        // Custom layout
        $widget->start_controls_section(
            'content_width_section',
            [
                'label'      => esc_html__('Custom Styles', 'wiseguard'),
                'tab'        => Controls_Manager::TAB_STYLE,
            ]
        );
            $widget->add_control(
                'content_width',
                [
                    'label'     => esc_html__('Content Width', 'wiseguard'),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        ''             => esc_html__('Default', 'wiseguard'),
                        'start'        => esc_html__('Full to Start', 'wiseguard'),
                        'end'          => esc_html__('Full to End', 'wiseguard'),
                        'start-large'  => esc_html__('Full to Start (Large)', 'wiseguard'),
                        'end-large'    => esc_html__('Full to End (Large)', 'wiseguard'),
                        'start-mlarge' => esc_html__('Full to Start (Medium Large)', 'wiseguard'),
                        'end-mlarge'   => esc_html__('Full to End (Medium Large)', 'wiseguard'),
                        'start-xlarge' => esc_html__('Full to Start (Extra Large)', 'wiseguard'),
                        'end-xlarge'   => esc_html__('Full to End (Extra Large)', 'wiseguard'),
                        'both'         => esc_html__('Full to Both', 'wiseguard')
                    ],
                    'prefix_class' => 'cms-swiper-full-'
                ]
            );
            $widget->add_control(
                'item_shadow',
                [
                    'label'     => esc_html__('Item Shadow?', 'wiseguard'),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'yes' => esc_html__('Yes', 'wiseguard'),
                        'no'   => esc_html__('No', 'wiseguard')
                    ],
                    'default' => 'no',
                    'dynamic' => [
                        'active' => true
                    ],
                    'style_transfer' => true,
                    'prefix_class' => 'cms-carousel-item-shadow-',

                ]
            );
        $widget->end_controls_section();
        // Naivgation Section Start
        $widget->start_controls_section(
            'navigation_section',
            [
                'label'      => esc_html__('Navigation', 'wiseguard'),
                'tab'        => Controls_Manager::TAB_STYLE,
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'arrows',
                            'operator' => '==',
                            'value' => 'yes',
                        ],
                        [
                            'name' => 'dots',
                            'operator' => '==',
                            'value' => 'yes',
                        ],
                    ],
                ],
            ]
        );

        $widget->add_control(
            'heading_style_arrows',
            [
                'label'     => esc_html__('Arrows', 'wiseguard'),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'arrows' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'arrows_size',
            [
                'label' => esc_html__('Size', 'wiseguard'),
                'type'  => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 20,
                        'max' => 60,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button-prev, {{WRAPPER}} .cms-carousel-button-next' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'arrows_color',
            [
                'label' => esc_html__('Color', 'wiseguard'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .cms-carousel-button-prev, {{WRAPPER}} .cms-carousel-button-next' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-button-prev svg, {{WRAPPER}} .cms-carousel-button-next svg' => 'fill: {{VALUE}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'heading_style_dots',
            [
                'label' => esc_html__('Dots', 'wiseguard'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'dots_size',
            [
                'label' => esc_html__('Size', 'wiseguard'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 5,
                        'max' => 10,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'dots_inactive_color',
            [
                'label' => esc_html__('Color', 'wiseguard'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    // The opacity property will override the default inactive dot color which is opacity 0.2.
                    '{{WRAPPER}} .swiper-pagination-bullet:not(.swiper-pagination-bullet-active)' => 'background: {{VALUE}}; opacity: 1',
                ],
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'dots_color',
            [
                'label' => esc_html__('Active Color', 'wiseguard'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-pagination-bullet' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'dots' => 'yes',
                ],
            ]
        );

        $widget->end_controls_section();
        // Heading style
        $widget->start_controls_section(
            'heading_section_style',
            [
                'label' => esc_html__('Heading Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => ['1']
                ]
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'smallheading_color',
                'label'     => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-smallheading' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'heading_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading, {{WRAPPER}} .cms-heading a' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
    }
}
