<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if (!function_exists('wiseguard_widget_cms_button_register_controls')) {
    add_action('etc_widget_cms_button_register_controls', 'wiseguard_widget_cms_button_register_controls', 10, 1);
    function wiseguard_widget_cms_button_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_button/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_button/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_button/layout/3.jpg'
                        ],
                        '4' => [
                            'label' => esc_html__( 'Layout 4', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_button/layout/4.jpg'
                        ],
                        '5' => [
                            'label' => esc_html__( 'Layout 5', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_button/layout/5.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Button Section Start
        $widget->start_controls_section(
            'button_section',
            [
                'label' => esc_html__('Button Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );         
            $widget->add_control(
                'text',
                [
                    'label'       => esc_html__( 'Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__( 'Click here', 'wiseguard' ),
                    'placeholder' => esc_html__( 'Click here', 'wiseguard' )
                ]
            );
            $widget->add_control(
                'link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom'
                ]
            );
            $widget->add_control(
                'page_link',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link_type' => 'custom'
                    ]
                ]
            );
            $widget->add_responsive_control(
                'align',
                [
                    'label'        => esc_html__( 'Alignment', 'wiseguard' ),
                    'type'         => Controls_Manager::CHOOSE,
                    'responsive'   => true,
                    'options'      => [
                        'start'    => [
                            'title' => esc_html__( 'Left', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-left',
                        ],
                        'center'  => [
                            'title' => esc_html__( 'Center', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-center',
                        ],
                        'end'   => [
                            'title' => esc_html__( 'Right', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-right',
                        ],
                        'justify' => [
                            'title' => esc_html__( 'Justified', 'wiseguard' ),
                            'icon' => 'eicon-text-align-justify',
                        ]
                    ],
                    'prefix_class' => 'text%s-'
                ]
            );
            $widget->add_control(
                'size',
                [
                    'label'        => esc_html__( 'Size', 'wiseguard' ),
                    'type'         => Controls_Manager::SELECT,
                    'options'      => [
                        'btn-xs' => esc_html__('Extra Small','wiseguard'),
                        'btn-sm' => esc_html__('Small','wiseguard'),
                        ''       => esc_html__('Default','wiseguard'),
                        'btn-md' => esc_html__('Medium','wiseguard'),
                        'btn-lg' => esc_html__('Large','wiseguard'),
                        'btn-xl' => esc_html__('Extra Large','wiseguard'),

                    ],
                    'condition' => [
                        'layout!' => '4'
                    ]
                ]
            );

            $widget->add_control(
                'btn_icon',
                [
                    'label'       => esc_html__( 'Icon', 'wiseguard' ),
                    'type'        => Controls_Manager::ICONS,
                    'skin'        => 'inline',
                    'default'     => [],
                    'label_block' => false  
                ]
            );
            $widget->add_control(
                'icon_align',
                [
                    'label'     => esc_html__( 'Icon Position', 'wiseguard' ),
                    'type'      => Controls_Manager::SELECT,
                    'default'   => '',
                    'options'   => [
                        ''      => esc_html__( 'Default', 'wiseguard' ),
                        'first' => esc_html__( 'Before', 'wiseguard' ),
                        'last'  => esc_html__( 'After', 'wiseguard' ),
                    ],
                ]
            );
            $widget->add_control(
                'icon_font_size',
                [
                    'label'        => esc_html__( 'Icon Font Size', 'wiseguard' ),
                    'type'         => Controls_Manager::SLIDER,
                    'control_type' => 'responsive',
                    'size_units'   => [ 'px' ],
                    'range'        => [
                        'px' => [
                            'min' => 5,
                            'max' => 35,
                        ],
                    ],
                    'selectors'    => [
                        '{{WRAPPER}} .cms-btn-icon' => 'font-size: {{SIZE}}{{UNIT}};',
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Section Start
        $widget->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );         
            $widget->add_control(
                'content_text',
                [
                    'label'       => esc_html__( 'Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'content_text_color',
                'label'    => esc_html__( 'Text Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-content-text' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
    }
}
