<?php

use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_chart_register_controls')) {
    add_action('etc_widget_cms_chart_register_controls', 'wiseguard_widget_cms_chart_register_controls', 10, 1);
    function wiseguard_widget_cms_chart_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_chart/layout/1.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Section Start
        $widget->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );  
            $widget->add_control(
                'title',
                [
                    'label'       => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Stats & Charts',
                    'placeholder' => esc_html__( 'Enter your title', 'wiseguard' )
                ]
            );      
            $widget->add_control(
                'text',
                [
                    'label'       => esc_html__( 'Content', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Our mix of company-owned and contractor assets allows us to retain optimal levels of control whilst expanding our reach to over 96% of towns in Australia. With 40 years of LTL experience, we are now a trusted LTL freight provider for shippers of all sizes and commodity types.',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' )
                ]
            ); 
            $widget->add_control(
                'link_text',
                [
                    'label'       => esc_html__( 'Link Settings', 'wiseguard' ),
                    'description' => esc_html__('Link Text', 'wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Click here', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'page_link',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link_text!' => '',
                        'link_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'custom_link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link_text!' => '',
                        'link_type' => 'custom'
                    ]
                ]
            );
            $widget->add_control(
                'link2_text',
                [
                    'label'       => esc_html__( 'Link #2 Settings', 'wiseguard' ),
                    'description' => esc_html__('Link Text', 'wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Check All Services', 'wiseguard' ),
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'link2_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link2_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link2_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link2_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
        $widget->start_controls_section(
            'chart_section',
            [
                'label' => esc_html__('Chart Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT
            ]
        );

            $repeater = new Repeater();
            $repeater->add_control(
                'chart_title',
                [
                    'label' => esc_html__('Title', 'wiseguard'),
                    'type' => Controls_Manager::TEXT
                ]
            );
            $repeater->add_control(
                'chart_main_title',
                [
                    'label' => esc_html__('Main Title', 'wiseguard'),
                    'type' => Controls_Manager::TEXT
                ]
            );
            $repeater->add_control(
                'chart_value',
                [
                    'label' => esc_html__('Value', 'wiseguard'),
                    'type' => Controls_Manager::TEXT
                ]
            );
            $repeater->add_control(
                'chart_color',
                [
                    'label' => esc_html__('Color', 'wiseguard'),
                    'type' => Controls_Manager::TEXT
                ]
            );

            $widget->add_control(
                'cms_chart',
                [
                    'name'   => 'cms_chart',
                    'label'  => esc_html__( 'Chart Items', 'wiseguard' ),
                    'type'   => \Elementor\Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                    'default' => [
                        [
                            'chart_title'      => 'Retail',
                            'chart_main_title' => 'Retail & Consumer',
                            'chart_value'      => 40,
                            'chart_color'      => '#9bcb3b',
                        ],
                        [
                            'chart_title'      => 'Sciences',
                            'chart_main_title' => 'Sciences & Healthcare',
                            'chart_value'      => 20,
                            'chart_color'      => '#5553ce',
                        ],
                        [
                            'chart_title'      => 'Industrial',
                            'chart_main_title' => 'Industrial & Chemical',
                            'chart_value'      => 15,
                            'chart_color'      => '#f13a30',
                        ],
                        [
                            'chart_title'      => 'Power',
                            'chart_main_title' => 'Power Generation',
                            'chart_value'      => 15,
                            'chart_color'      => '#f8a137',
                        ],
                        [
                            'chart_title'      => 'Oil & Gas',
                            'chart_main_title' => 'Oil & Gas',
                            'chart_value'      => 10,
                            'chart_color'      => '#1875f0',
                        ]
                    ],
                    'title_field' => '{{{ chart_title }}} ({{{ chart_value }}})',
                    'separator'   => 'after',
                ]
            );
            $widget->add_control(
                'cms_chart_dimensions',
                [
                    'label'        => esc_html__( 'Chart Dimensions', 'wiseguard' ),
                    'type'         => \Elementor\Controls_Manager::SLIDER,
                    'control_type' => 'responsive',
                    'range' => [
                        'px' => [
                            'min' => 100,
                            'max' => 1000,
                        ]
                    ],
                    'default' => [
                        'size' => 400
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .cms-charts-chart' => 'max-width:{{SIZE}}px;' //max-height:{{SIZE}}px;
                    ],
                    'separator' => 'before'
                ]
            );
        $widget->end_controls_section();
        // Style
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__( 'Style Settings', 'wiseguard' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
            $widget->add_control(
                'cms_chart_type',
                [
                    'label'   => esc_html__( 'Chart Type', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'options' => array(
                        'doughnut'  => __('Doughnut','wiseguard'),
                        'pie'       => __('Pie','wiseguard'),
                        'polarArea' => __('Polar Area','wiseguard'),
                        //'line'      => __('line','wiseguard')
                    ),
                    'default' => 'doughnut'
                ]
            );
            $widget->add_control(
                'legend_display',
                [
                    'label'   => esc_html__( 'Show Legend', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'options' => array(
                        'true'  => __('Yes','wiseguard'),
                        'false' => __('No','wiseguard')
                    ),
                    'default' => 'false'
                ]
            );
            $widget->add_control(
                'legend_position',
                [
                    'label'   => esc_html__( 'Legend Position', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'options' => array(
                        'top'    => __('Top','wiseguard'),
                        'right'  => __('Right','wiseguard'),
                        'bottom' => __('Bottom','wiseguard'),
                        'left'   => __('Left','wiseguard')
                    ),
                    'default' => 'top',
                    'condition' => [
                        'legend_display' => 'true'
                    ]
                ]
            );
            $widget->add_control(
                'title_display',
                [
                    'label'   => esc_html__( 'Show Title', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'options' => array(
                        'true'  => __('Yes','wiseguard'),
                        'false' => __('No','wiseguard')
                    ),
                    'default' => 'false'
                ]
            );
            $widget->add_control(
                'title_text',
                [
                    'label'   => esc_html__( 'Title', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::TEXTAREA,
                    'default' => 'Your Title',
                    'condition' => [
                        'title_display' => 'true'
                    ]
                ]
            );
            $widget->add_control(
                'title_position',
                [
                    'label'   => esc_html__( 'Title Position', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'options' => array(
                        'top'    => __('Top','wiseguard'),
                        'right'  => __('Right','wiseguard'),
                        'bottom' => __('Bottom','wiseguard'),
                        'left'   => __('Left','wiseguard')
                    ),
                    'default' => 'top',
                    'condition' => [
                        'title_display' => 'true'
                    ]
                ]
            );
        $widget->end_controls_section();
    }
}