<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_clients_register_controls')) {
    add_action('etc_widget_cms_clients_register_controls', 'wiseguard_widget_cms_clients_register_controls', 10, 1);
    function wiseguard_widget_cms_clients_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_clients/layout/1.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start
        // List Section Start
        $widget->start_controls_section(
            'list_section',
            [
                'label' => esc_html__('List', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__('Image', 'wiseguard'),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'name',
            [
                'label' => esc_html__('Name', 'wiseguard'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Client Name', 'wiseguard'),
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label'   => esc_html__( 'Link', 'wiseguard' ),
                'type'    => Controls_Manager::URL,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow'    => true,
                ],
            ]
        );

        $widget->add_control(
            'clients',
            [
                'label' => esc_html__('Clients', 'wiseguard'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Client Name', 'wiseguard'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Client Name', 'wiseguard'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Client Name', 'wiseguard'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                ],
                'title_field' => '{{{ name }}}',
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'    => 'image',
                'default' => 'full',
            ]
        );
        $widget->end_controls_section();
        // List Section End

        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $slides_to_show = range(1, 10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                    ] + $slides_to_show,
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label' => esc_html__('Slides to Scroll', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'wiseguard'),
                'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'wiseguard'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 40,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrows',
            [
                'label'              => esc_html__('Show Arrows', 'wiseguard'),
                'type'               => Controls_Manager::SWITCHER,
                'default'            => 'yes',
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
            'dots',
            [
                'label' => esc_html__('Show Dots', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'wiseguard'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'wiseguard'),
                    'fade' => esc_html__('Fade', 'wiseguard'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'wiseguard'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();
        // Style
         $widget->start_controls_section(
            'section_style',
            [
                'label' => esc_html__('Style Settings', 'wiseguard'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            $widget->add_control(
                'opacity',
                [
                    'label' => esc_html__('Opacity', 'wiseguard'),
                    'type' => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max'  => 1,
                            'min'  => 0.01,
                            'step' => 0.01,
                        ]
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .client-item:not(:hover) > img' => 'opacity:{{SIZE}};'
                    ]
                ]
            );
        $widget->end_controls_section();
    }
}
