<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;

if (!function_exists('wiseguard_widget_cms_contact_form_register_controls')) {
    add_action('etc_widget_cms_contact_form_register_controls', 'wiseguard_widget_cms_contact_form_register_controls', 10, 1);
    function wiseguard_widget_cms_contact_form_register_controls($widget)
    {
        $cf7 = get_posts('post_type="wpcf7_contact_form"&numberposts=-1');
        $contact_forms = array();
        if ($cf7) {
            foreach ($cf7 as $cform) {
                $contact_forms[$cform->ID] = $cform->post_title;
            }
        } else {
            $contact_forms[0] = esc_html__('No contact forms found', 'wiseguard');
        }

        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_contact_form/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_contact_form/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_contact_form/layout/3.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start

        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Form Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
            $widget->add_control(
                'ctf7_slug',
                [
                    'label'       => esc_html__('Select Form', 'wiseguard'),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => $contact_forms,
                    'label_block' => true,
                    'separator'   => 'before'
                ]
            );
            $widget->add_control(
                'ctf7_title_icon',
                [
                    'label'       => esc_html__('Form Title Icon', 'wiseguard'),
                    'type'        => Controls_Manager::ICONS,
                    'skin'        => 'inline',
                    'label_block' => true,
                ]
            );
            $widget->add_control(
                'ctf7_title',
                [
                    'label'       => esc_html__('Form Title', 'wiseguard'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                ]
            );
            $widget->add_control(
                'ctf7_description',
                [
                    'label'   => esc_html__('Form Description', 'wiseguard'),
                    'type'    => Controls_Manager::TEXTAREA,
                    'show_label' => true,
                ]
            );
            $widget->add_control(
                'ctf7_note',
                [
                    'label'       => esc_html__('Form Note', 'wiseguard'),
                    'description' => esc_html__('Add your note after Submit button', 'wiseguard'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'show_label'  => true,
                ]
            );
        $widget->end_controls_section();
        // Style
        $widget->start_controls_section(
            'section_style',
            [
                'label' => esc_html__('Style Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'heading_bg_color',
                'label'     => esc_html__( 'Heading Background Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .banner-title' => 'background-color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'icon_color',
                'label'     => esc_html__( 'Icon Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-banner-icon' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_color',
                'label'     => esc_html__( 'Title Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-title' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'desc_color',
                'label'     => esc_html__( 'Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'note_color',
                'label'     => esc_html__( 'Note Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-note' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
    }
}
