<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_counter_register_controls')) {
    add_action('etc_widget_cms_counter_register_controls', 'wiseguard_widget_cms_counter_register_controls', 10, 1);
    function wiseguard_widget_cms_counter_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout_mode',
                [
                    'label'   => esc_html__('Layout Mode', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'grid'     => esc_html__('Grid', 'wiseguard'),
                        'carousel' => esc_html__('Carousel', 'wiseguard')
                    ],
                    'default' => 'grid'
                ]
            );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_counter/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_counter/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_counter/layout/3.jpg'
                        ],
                        '4' => [
                            'label' => esc_html__( 'Layout 4', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_counter/layout/4.jpg'
                        ],
                        '5' => [
                            'label' => esc_html__( 'Layout 5', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_counter/layout/5.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start
        // Heading
        $widget->start_controls_section(
            'heading_section',
            [
                'label' => esc_html__('Heading Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['5']
                ]
            ]
        );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'description_bold_text',
                [
                    'label'       => esc_html__( 'Description (Bold)', 'wiseguard' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => 'Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text ever since', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'description_text',
                [
                    'label'       => esc_html__( 'Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before'
                ]
            );
            // Button
            $widget->add_control(
                'link1_text',
                [
                    'label'       => esc_html__( 'Link #1 Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Discover More',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'separator'   => 'before'
                ]
            );
            $widget->add_control(
                'link1_type',
                [
                    'label'   => esc_html__('Link #1 Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link1_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link1_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link1_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'custom'
                    ]
                ]
            );
            // Icons
            $icons = new Repeater();
                $icons->add_control(
                    '_icon',
                    [
                        'label'            => esc_html__( 'Icon', 'wiseguard' ),
                        'type'             => \Elementor\Controls_Manager::ICONS,
                        'fa4compatibility' => 'icon',
                        'default'          => [
                            'library' => 'cmsi-wiseguard',
                            'value'   => 'wiseguard-icon-default'       
                        ],
                        'skin'        => 'inline',
                        'label_block' => false
                    ]
                );
            $widget->add_control(
                'heading_icon',
                [
                    'label'   => esc_html__('Icons','wiseguard'),
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => $icons->get_controls(),
                    'default' => [
                        [
                            '_icon' => [
                                'library' => 'cmsi-wiseguard',
                                'value'   => 'wiseguard-icon-default'
                            ]
                        ],
                        [
                            '_icon' => [
                                'library' => 'cmsi-wiseguard',
                                'value'   => 'wiseguard-icon-default'
                            ]
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Banner 
        $widget->start_controls_section(
            'banner_section',
            [
                'label' => esc_html__('Banner Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['4']
                ]
            ]
        );
            $widget->add_control(
                'banner',
                [
                    'label'   => esc_html__( 'Banner', 'wiseguard' ),
                    'type'    => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ],
                    'skin'  => 'inline'
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'image',
                    'label'   => esc_html__('Banner Size','wiseguard'),
                    'default' => 'custom'
                ]
            );
        $widget->end_controls_section();
        // Reapeater Counter
        $widget->start_controls_section(
            'section_counters',
            [
                'label' => esc_html__('Counters Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT
            ]
        );
            $repeater = new Repeater();

            $repeater->add_control(
                'starting_number',
                [
                    'label'   => esc_html__( 'Starting Number', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::NUMBER,
                    'default' => 1,
                ]
            );
            $repeater->add_control(
                'ending_number',
                [
                    'label'   => esc_html__( 'Ending Number', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::NUMBER,
                    'default' => 100,
                ]
            );
            $repeater->add_control(
                'prefix',
                [
                    'label'       => esc_html__( 'Number Prefix', 'wiseguard' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => '1',
                ]
            );
            $repeater->add_control(
                'suffix',
                [
                    'label'       => esc_html__( 'Number Suffix', 'wiseguard' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => '+',
                ]
            );
            $repeater->add_control(
                'duration',
                [
                    'label'   => esc_html__( 'Animation Duration', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::NUMBER,
                    'default' => 3000,
                    'min'     => 100,
                    'step'    => 100,
                ]
            );
            $repeater->add_control(
                'thousand_separator_char',
                [
                    'label'     => esc_html__( 'Separator', 'wiseguard' ),
                    'type'      => \Elementor\Controls_Manager::SELECT,
                    'options'   => [
                        ''  => 'Default',
                        ',' => 'Comma',
                        '.' => 'Dot',
                        ' ' => 'Space',
                    ],
                    'default'   => '',
                ]
            );
            $repeater->add_control(
                'show_icon',
                [
                    'label'       => esc_html__( 'Show Icon', 'wiseguard' ),
                    'type'        => \Elementor\Controls_Manager::SWITCHER,
                    'default'     => 'yes',
                    'label_block' => true
                ]
            );
            $repeater->add_control(
                'icon_type',
                [
                    'label'     => esc_html__( 'Icon Type', 'wiseguard' ),
                    'type'      => \Elementor\Controls_Manager::SELECT,
                    'options'   => [
                        'icon'  => esc_html__( 'Icon', 'wiseguard' ),
                        'image' => esc_html__( 'Image', 'wiseguard' ),
                    ],
                    'default'   => 'icon',
                    'condition' => [
                        'show_icon' => 'yes'
                    ]
                ]
            );
            $repeater->add_control(
                'counter_icon',
                [
                    'label'            => esc_html__( 'Icon', 'wiseguard' ),
                    'type'             => \Elementor\Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'default'          => [
                        'library' => 'cmsi-wiseguard',
                        'value'   => 'wiseguard-icon-default'       
                    ],
                    'condition'        => [
                        'show_icon' => 'yes',
                        'icon_type' => 'icon'
                    ],
                    'skin'        => 'inline',
                    'label_block' => false
                ]
            );
            $repeater->add_control(
                'icon_image',
                [
                    'label'     => esc_html__( 'Icon Image', 'wiseguard' ),
                    'type'      => \Elementor\Controls_Manager::MEDIA,
                    'default'   => [
                        'url' => Utils::get_placeholder_image_src()
                    ],
                    'condition' => [
                        'show_icon' => 'yes',
                        'icon_type' => 'image'
                    ],
                    'label_block' => false,
                    'skin'        => 'inline'
                ]
            );
            $repeater->add_control(
                'title',
                [
                    'label'       => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'label_block' => true,
                    'default'     => 'Counter',
                    'placeholder' => esc_html__( 'Enter your Title', 'wiseguard' ),
                ]
            );
            $repeater->add_control(
                'description',
                [
                    'label'       => esc_html__( 'Description', 'wiseguard' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'label_block' => true,
                    'default'     => 'Turpis massa tincidunt dui ut. Sit amet nisl purus in mollis nunc. Id neque aliquam vestibulum morbi blandit cursus risus',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                ]
            );
            // Button
            $repeater->add_control(
                'link_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__( 'Click here', 'wiseguard' ),
                    'placeholder' => esc_html__( 'Click here', 'wiseguard' )
                ]
            );
            $repeater->add_control(
                'link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link_text!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'page_link',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link_text!' => '', 
                        'link_type' => 'page'
                    ]
                ]
            );
            $repeater->add_control(
                'link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link_text!' => '',
                        'link_type'  => 'custom'
                    ]
                ]
            );

            // add counter item
            $widget->add_control(
                'counters',
                [
                    'label'  => esc_html__('Counters List', 'wiseguard'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                    'default' => [
                        [
                            'starting_number' => '1',
                            'ending_number'   => '300',
                            'prefix'          => '',
                            'suffix'          => 'K',
                            'title'           => 'Qualified Employees Works With Us',
                        ],
                        [
                            'starting_number' => '1',
                            'ending_number'   => '99',
                            'prefix'          => '',
                            'suffix'          => '%',
                            'title'           => 'Geographical Coverage Waste Collection',
                        ]
                    ],
                    'title_field' => '{{{ title }}}',
                ]
            );
        $widget->end_controls_section();

        // Style Section Start
        $widget->start_controls_section(
            'section_style_heading',
            [
                'label' => esc_html__('Heading', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'heading_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'description_bold_color',
                'label'    => esc_html__( 'Description Bold Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc-bold' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'description_color',
                'label'    => esc_html__( 'Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'link1_color',
                'label'    => esc_html__( 'Link #1 Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .btn1' => 'background-color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'link1_hover_color',
                'label'    => esc_html__( 'Link #1 Hover Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .btn1:hover' => 'background-color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'heading_icon_color',
                'label'    => esc_html__( 'Icon Color', 'wiseguard' ),
                'custom'   => false
            ]);
        $widget->end_controls_section();
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Number', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'number_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-counter-number' => 'color: {{VALUE}};'
                ]
            ]);
            $widget->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'number_typography',
                    'selector' => '{{WRAPPER}} .cms-counter-numbers',
                ]
            );
        $widget->end_controls_section();
        // Icon Section Start
        $widget->start_controls_section('icon_style',[
            'label' =>  esc_html__('Icon', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_STYLE
        ]);
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'icon_image',
                    'label'   => esc_html__('Image Size','wiseguard'),
                    'default' => 'custom'
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'icon_color',
                'label'    => esc_html__( 'Icon Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-counter-icon i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-counter-icon svg' => 'fill: {{VALUE}};'
                ]
            ]);
        $widget->end_controls_section();
        // Title Section Start
        $widget->start_controls_section(
            'section_title',
            [
                'label' => esc_html__('Title', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_color',
                'label'    => esc_html__( 'Title Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-counter-title' => 'color: {{VALUE}};',
                ]
            ]);
            $widget->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'title_typography',
                    'selector' => '{{WRAPPER}} .cms-counter-title',
                ]
            );
        $widget->end_controls_section();
        // Desc Section Start
        $widget->start_controls_section(
            'section_desc',
            [
                'label' => esc_html__('Description', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'desc_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-counter-desc' => 'color: {{VALUE}};',
                ]
            ]);
            $widget->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'desc_typography',
                    'selector' => '{{WRAPPER}} .cms-counter-title',
                ]
            );
        $widget->end_controls_section();
        // Item Section Start
        $widget->start_controls_section(
            'section_item',
            [
                'label' => esc_html__('Item', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => ['1']
                ]
            ]
        );
            $widget->add_control(
                'border_color',
                [
                    'label'     => esc_html__( 'Border Color', 'wiseguard' ),
                    'type'      => \Elementor\Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .counter-item' => 'border-top-color: {{VALUE}};border-bottom-color: {{VALUE}};'
                    ]
                ]
            );
        $widget->end_controls_section(); // Title Section End
        // Background
        $widget->start_controls_section(
            'section_background',
            [
                'label' => esc_html__('Background', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => ['2','3']
                ]
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'bg_color',
                'label'    => esc_html__( 'Background Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-counter' => 'background-color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]);
        $widget->end_controls_section();

        // Start Settings
        $widget->start_controls_section(
            'grid_settings_section',
            [
                'label' => esc_html__('Grid Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_SETTINGS,
                'condition' => [
                    'layout_mode' => ['grid']
                ]
            ]
        );
            $widget->add_responsive_control(
                'col',
                [
                    'label'        => esc_html__('Columns', 'wiseguard'),
                    'type'         => Controls_Manager::SELECT,
                    'default'      => '',
                    'default_args' => [
                        'tablet' => '',
                        'mobile' => ''
                    ],
                    'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                        '1' => '1',
                        '2' => '2',
                        '3' => '3',
                        '4' => '4',
                        '6' => '6',
                    ]
                ]
            );
        $widget->end_controls_section();
        // Carousel
        $widget->start_controls_section(
            'carousel_settings_section',
            [
                'label' => esc_html__('Carousel Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_SETTINGS,
                'condition' => [
                    'layout_mode' => ['carousel']
                ]
            ]
        );
            $slides_to_show = range(1, 10);
            $slides_to_show = array_combine($slides_to_show, $slides_to_show);
            $widget->add_responsive_control(
                'slides_to_show',
                [
                    'label' => esc_html__('Slides to Show', 'wiseguard'),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                            '' => esc_html__('Default', 'wiseguard'),
                        ] + $slides_to_show,
                    'frontend_available' => true,
                ]
            );

            $widget->add_responsive_control(
                'slides_to_scroll',
                [
                    'label' => esc_html__('Slides to Scroll', 'wiseguard'),
                    'type' => Controls_Manager::SELECT,
                    'description' => esc_html__('Set how many slides are scrolled per swipe.', 'wiseguard'),
                    'options' => [
                            '' => esc_html__('Default', 'wiseguard'),
                        ] + $slides_to_show,
                    'condition' => [
                        'slides_to_show!' => '1',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_responsive_control(
                'space_between',
                [
                    'label' => esc_html__('Space Between', 'wiseguard'),
                    'type' => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'size' => 40,
                    ],
                    'condition' => [
                        'slides_to_show!' => '1',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'arrows',
                [
                    'label' => esc_html__('Show Arrows', 'wiseguard'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                ]
            );
            $widget->add_control(
                'dots',
                [
                    'label' => esc_html__('Show Dots', 'wiseguard'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'arrow_prev_icon',
                [
                    'label'            => esc_html__('Previous Arrow Icon', 'wiseguard'),
                    'type'             => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'skin'             => 'inline',
                    'label_block'      => false,
                    'skin_settings'    => [
                        'inline' => [
                            'none' => [
                                'label' => 'Default',
                                'icon' => 'eicon-chevron-left',
                            ],
                            'icon' => [
                                'icon' => 'eicon-star',
                            ],
                        ],
                    ],
                    'condition' => [
                        'arrows' => 'yes'
                    ],
                ]
            );

            $widget->add_control(
                'arrow_next_icon',
                [
                    'label'            => esc_html__('Next Arrow Icon', 'wiseguard'),
                    'type'             => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'skin'             => 'inline',
                    'label_block'      => false,
                    'skin_settings'    => [
                        'inline' => [
                            'none' => [
                                'label' => 'Default',
                                'icon' => 'eicon-chevron-right',
                            ],
                            'icon' => [
                                'icon' => 'eicon-star',
                            ],
                        ],
                    ],
                    'condition' => [
                        'arrows' => 'yes'
                    ],
                ]
            );

            $widget->add_control(
                'lazyload',
                [
                    'label' => esc_html__('Lazyload', 'wiseguard'),
                    'type' => Controls_Manager::SWITCHER,
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'autoplay',
                [
                    'label' => esc_html__('Autoplay', 'wiseguard'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'pause_on_hover',
                [
                    'label' => esc_html__('Pause on Hover', 'wiseguard'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                ]
            );

            $widget->add_control(
                'pause_on_interaction',
                [
                    'label' => esc_html__('Pause on Interaction', 'wiseguard'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                ]
            );

            $widget->add_control(
                'autoplay_speed',
                [
                    'label' => esc_html__('Autoplay Speed', 'wiseguard'),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 5000,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'infinite',
                [
                    'label' => esc_html__('Infinite Loop', 'wiseguard'),
                    'type' => \Elementor\Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'effect',
                [
                    'label' => esc_html__('Effect', 'wiseguard'),
                    'type' => Controls_Manager::SELECT,
                    'default' => 'slide',
                    'options' => [
                        'slide' => esc_html__('Slide', 'wiseguard'),
                        'fade' => esc_html__('Fade', 'wiseguard'),
                    ],
                    'condition' => [
                        'slides_to_show' => '1',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'speed',
                [
                    'label' => esc_html__('Animation Speed', 'wiseguard'),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 500,
                    'render_type' => 'none',
                    'frontend_available' => true,
                ]
            );
        $widget->end_controls_section();
    }
}
