<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_fancy_box_register_controls')) {
    add_action('etc_widget_cms_fancy_box_register_controls', 'wiseguard_widget_cms_fancy_box_register_controls', 10, 1);
    function wiseguard_widget_cms_fancy_box_register_controls($widget)
    {
        // Layout Section Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__('Templates', 'wiseguard'),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__('Layout 1', 'wiseguard'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_fancy_box/layout/1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__('Layout 2', 'wiseguard'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_fancy_box/layout/2.jpg'
                    ],
                    '3' => [
                        'label' => esc_html__('Layout 3', 'wiseguard'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_fancy_box/layout/3.jpg'
                    ],
                    '4' => [
                        'label' => esc_html__('Layout 4', 'wiseguard'),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_fancy_box/layout/4.jpg'
                    ]
                ]
            ]
        );
        $widget->end_controls_section();
        // Icon Section Start
        $widget->start_controls_section(
            'fancy_box_section',
            [
                'label' => esc_html__('Fancy Box', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $fancy_box = new Repeater();
            $fancy_box->add_control(
                'icon_type',
                [
                    'label'   => esc_html__('Icon Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'icon'  => esc_html__('Icon','wiseguard'),
                        'image' => esc_html__('Image','wiseguard'),
                        ''      => esc_html__('None','wiseguard'),
                    ],
                    'default' => 'icon'
                ]
            );
            $fancy_box->add_control(
                'selected_icon',
                [
                    'label'     => esc_html__('Icon', 'wiseguard'),
                    'type'      => Controls_Manager::ICONS,
                    'condition' => [
                        'icon_type' => 'icon'
                    ],
                    'default' => [
                        'library' => 'cmsi',
                        'value'   => 'cmsi-alert'  
                    ]
                ]
            );
            $fancy_box->add_control(
                'icon_image',
                [
                    'label'       => esc_html__('Icon Image', 'wiseguard'),
                    'type'        => Controls_Manager::MEDIA,
                    'description' => esc_html__('Select image icon.', 'wiseguard'),
                    'condition'   => [
                        'icon_type' => 'image',
                    ],
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ]
                ]
            );
            $fancy_box->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'icon_image',
                    'label'   => esc_html__('Image Size','wiseguard'),
                    'default' => 'custom',
                    'condition'   => [
                        'icon_type'        => 'image',
                        'icon_image[url]!' => '',
                    ]
                ]
            );
            $fancy_box->add_control(
                'title',
                [
                    'label'       => esc_html__('Title', 'wiseguard'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => esc_html__('This is the heading', 'wiseguard'),
                    'placeholder' => esc_html__('Enter your title', 'wiseguard'),
                    'label_block' => true
                ]
            );
            $fancy_box->add_control(
                'description',
                [
                    'label'       => esc_html__('Description', 'wiseguard'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => '',
                    'placeholder' => esc_html__('Enter your description', 'wiseguard'),
                    'rows'        => 10,
                    'show_label'  => true
                ]
            );
            $fancy_box->add_control(
                'btn_text',
                [
                    'label'       => esc_html__('Link Settings', 'wiseguard'),
                    'description' => esc_html__('Link Text','wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',  
                    'label_block' => true
                ]
            );
            $fancy_box->add_control(
                'btn_link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        //'btn_text!'     => ''
                    ]
                ]
            );
            $fancy_box->add_control(
                'btn_page_link',
                [
                    'label'     => esc_html__('Select Page', 'wiseguard'),
                    'type'      => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        //'btn_text!'     => '',
                        'btn_link_type' => 'page'
                    ]
                ]
            );
            $fancy_box->add_control(
                'btn_link',
                [
                    'label'     => esc_html__('Custom Link', 'wiseguard'),
                    'type'      => Controls_Manager::URL,
                    'condition' => [
                        //'btn_text!'     => '',
                        'btn_link_type' => 'custom'
                    ]
                ]
            );
            $widget->add_control(
                'fancy_box',
                [
                    'label'       => esc_html__('Fancy Box','wiseguard'),
                    'type'        => Controls_Manager::REPEATER,
                    'fields'      => $fancy_box->get_controls(),
                    'title_field' => '{{title}}',
                    'default' => [
                        [
                            'icon_type' => 'icon',
                            'selected_icon'      => [
                                'library' => 'cmsi',
                                'value'   => 'cmsi-alert'  
                            ],
                            'title' => 'This is Heading'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Style Section Start
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            // Grid Columns
            $widget->add_responsive_control(
                'col',
                [
                    'label'        => esc_html__('Columns', 'wiseguard'),
                    'type'         => Controls_Manager::SELECT,
                    'default'      => '',
                    'default_args' => [
                        'tablet' => '',
                        'mobile' => ''
                    ],
                    'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                        '1' => '1',
                        '2' => '2',
                        '3' => '3',
                        '4' => '4',
                        '6' => '6',
                    ]
                ]
            );
            // Icon
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'icon_color',
                'label'     => esc_html__( 'Icon Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-icon' => 'color: {{VALUE}};'
                ]
            ]);
            // Title
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_color',
                'label'    => esc_html__( 'Title Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-title' => 'color: {{VALUE}};'
                ],
                'separator' => 'before',
            ]);
            // Description
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'description_color',
                'label'    => esc_html__( 'Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};'
                ],
                'separator' => 'before',
            ]);
            // Button
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'btn_color',
                'label'    => esc_html__( 'Button Text Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-fancy-btn' => 'color: {{VALUE}};border-color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'btn_hover_color',
                'label'    => esc_html__( 'Button Text Hover Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-fancy-btn:hover' => 'color: {{VALUE}};border-color: {{VALUE}};',
                ],
                'separator' => 'before',
            ]);
            // Background color
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'bg_color',
                'label'    => esc_html__( 'Background Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-fancybox' => 'background-color: {{VALUE}};',
                ],
                'separator' => 'before'
            ]);
            // Background Hover color
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'bg_hover_color',
                'label'    => esc_html__( 'Background Hover Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-fancybox:hover' => 'background-color: {{VALUE}};',
                ],
                'separator' => 'before'
            ]);
        $widget->end_controls_section();
    }
}
