<?php
use Elementor\Controls_Manager;
if (!function_exists('wiseguard_widget_cms_google_map_register_controls')) {
    add_action('etc_widget_cms_google_map_register_controls', 'wiseguard_widget_cms_google_map_register_controls', 10, 1);
    function wiseguard_widget_cms_google_map_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_google_map/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_google_map/layout/2.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start
        $widget->start_controls_section(
            'map_section',
            [
                'label' => esc_html__('Map Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT
            ]
        );
            $default_address = esc_html__( 'The Great Kings Building Management 2307 Beverley Road, Brooklyn, NY 145784', 'wiseguard' );
            $widget->add_control(
                'map_address',
                [
                    'label'   => esc_html__( 'Location', 'wiseguard' ),
                    'type'    => Controls_Manager::TEXT,
                    'dynamic' => [
                        'active' => true
                    ],
                    'placeholder' => $default_address,
                    'default'     => $default_address,
                    'label_block' => true,
                ]
            );
            $widget->add_control(
                'zoom',
                [
                    'label' => esc_html__( 'Zoom', 'wiseguard' ),
                    'type' => Controls_Manager::SLIDER,
                    'default' => [
                        'size' => 15,
                    ],
                    'range' => [
                        'px' => [
                            'min' => 1,
                            'max' => 20,
                        ],
                    ],
                    'separator' => 'before',
                ]
            );
            $widget->add_responsive_control(
                'height',
                [
                    'label' => esc_html__( 'Height', 'wiseguard' ),
                    'type'  => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 40,
                            'max' => 1440,
                        ]
                    ],
                    'size_units' => [ 'px' ],
                    'selectors' => [
                        '{{WRAPPER}} .cms-egmap' => 'height: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}} iframe' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                    'default' => [
                        'size' => 620,
                    ]
                ]
            );
            $widget->add_control(
                'view',
                [
                    'label'   => esc_html__( 'View', 'wiseguard' ),
                    'type'    => Controls_Manager::HIDDEN,
                    'default' => 'traditional',
                ]
            );
        $widget->end_controls_section();
        // Content
        $widget->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['2']
                ]
            ]
        );
            $widget->add_control(
                'title',
                [
                    'label'       => '',
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'London Office',  
                    'placeholder' => esc_html__('Enter your title', 'wiseguard')
                ]
            );
            $widget->add_control(
                'address',
                [
                    'label'       => '',
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'The Great Kings Building Management 2307 Beverley Road, Brooklyn, NY 145784',
                    'placeholder' => esc_html__('Enter your address', 'wiseguard')
                ]
            );
            $widget->add_control(
                'email',
                [
                    'label'       => '',
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'WiseGuard@cmshero.com',
                    'placeholder' => 'WiseGuard@cmshero.com'
                ]
            );
            $widget->add_control(
                'phone',
                [
                    'label'       => esc_html__('Phone Number','wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '02 01061245741',
                    'placeholder' => '02 01061245741'
                ]
            );
            // Button
            $widget->add_control(
                'btn_text',
                [
                    'label'       => esc_html__( 'Button Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__( 'Click here', 'wiseguard' ),
                    'placeholder' => esc_html__( 'Click here', 'wiseguard' )
                ]
            );
            $widget->add_control(
                'link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom'
                ]
            );
            $widget->add_control(
                'page_link',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
    }
}
