<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_howitwork_register_controls')) {
    add_action('etc_widget_cms_howitwork_register_controls', 'wiseguard_widget_cms_howitwork_register_controls', 10, 1);
    function wiseguard_widget_cms_howitwork_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_howitwork/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_howitwork/layout/2.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start
        // Heading Section Start
        $widget->start_controls_section(
            'section_heading',
            [
                'label'     => esc_html__('Heading Content', 'wiseguard'),
                'tab'       => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['1']
                ]
            ]
        );
            $widget->add_control(
                'smallheading_text',
                [
                    'label'       => esc_html__( 'Small Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is small heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'separator'   => 'after',
                ]
            );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'description_text',
                [
                    'label'       => esc_html__( 'Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'heading_link_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__( 'Click here', 'wiseguard' ),
                    'placeholder' => esc_html__( 'Click here', 'wiseguard' )
                ]
            );
            $widget->add_control(
                'heading_link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom'
                ]
            );
            $widget->add_control(
                'heading_page_link',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'heading_link_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'heading_link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'heading_link_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
        // Reapeater Counter
        $widget->start_controls_section(
            'section_counters',
            [
                'label' => esc_html__('How it Work Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT
            ]
        );
            // Layout 1
            $repeater = new Repeater();
                $repeater->add_control(
                    'hiw_banner',
                    [
                        'label'   => esc_html__( 'Banner', 'wiseguard' ),
                        'type'    => \Elementor\Controls_Manager::MEDIA,
                        'default' => [
                            'url' => Utils::get_placeholder_image_src()
                        ],
                        'condition' => [
                            'layout' => ['1']
                        ]
                    ]
                );
                $repeater->add_control(
                    'hiw_banner_icon',
                    [
                        'label'            => esc_html__( 'Banner Icon', 'wiseguard' ),
                        'type'             => \Elementor\Controls_Manager::ICONS,
                        'default'          => [
                            'library' => 'cmsi-wiseguard',
                            'value'   => 'wiseguard-icon-default'       
                        ],
                        'skin'        => 'inline',
                        'label_block' => false
                    ]
                );
                $repeater->add_control(
                    'hiw_banner_title',
                    [
                        'label'       => esc_html__( 'Banner Title', 'wiseguard' ),
                        'type'        => \Elementor\Controls_Manager::TEXTAREA,
                        'label_block' => true,
                        'default'     => 'Banner Title',
                        'placeholder' => esc_html__( 'Enter your Title', 'wiseguard' ),
                    ]
                );
                $repeater->add_control(
                    'hiw_icon',
                    [
                        'label'            => esc_html__( 'Icon', 'wiseguard' ),
                        'type'             => \Elementor\Controls_Manager::ICONS,
                        'default'          => [
                            'library' => 'cmsi-wiseguard',
                            'value'   => 'wiseguard-icon-default'       
                        ],
                        'skin'        => 'inline',
                        'label_block' => false
                    ]
                );
                $repeater->add_control(
                    'title',
                    [
                        'label'       => esc_html__( 'Title', 'wiseguard' ),
                        'type'        => \Elementor\Controls_Manager::TEXTAREA,
                        'label_block' => true,
                        'default'     => 'Your Title',
                        'placeholder' => esc_html__( 'Enter your Title', 'wiseguard' ),
                    ]
                );
                $repeater->add_control(
                    'description',
                    [
                        'label'       => esc_html__( 'Description', 'wiseguard' ),
                        'type'        => \Elementor\Controls_Manager::TEXTAREA,
                        'label_block' => true,
                        'default'     => 'Turpis massa tincidunt dui ut. Sit amet nisl purus in mollis nunc. Id neque aliquam vestibulum morbi blandit cursus risus',
                        'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    ]
                );
                $repeater->add_control(
                    'link_text',
                    [
                        'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                        'type'        => Controls_Manager::TEXT,
                        'default'     => esc_html__( 'Click here', 'wiseguard' ),
                        'placeholder' => esc_html__( 'Click here', 'wiseguard' )
                    ]
                );
                $repeater->add_control(
                    'link_type',
                    [
                        'label'   => esc_html__('Link Type', 'wiseguard'),
                        'type'    => Controls_Manager::SELECT,
                        'options' => [
                            'custom' => esc_html__('Custom', 'wiseguard'),
                            'page'   => esc_html__('Page', 'wiseguard'),
                        ],
                        'default' => 'custom'
                    ]
                );
                $repeater->add_control(
                    'page_link',
                    [
                        'label'   => esc_html__('Select Page', 'wiseguard'),
                        'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                        'post_type' => [
                            'page'
                        ],
                        'multiple'  => false,
                        'condition' => [
                            'link_type' => 'page'
                        ]
                    ]
                );
                $repeater->add_control(
                    'link',
                    [
                        'label'       => esc_html__( 'Link', 'wiseguard' ),
                        'type'        => Controls_Manager::URL,
                        'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                        'default'     => [
                            'url' => '#',
                        ],
                        'condition' => [
                            'link_type' => 'custom'
                        ]
                    ]
                );
            // add counter item
            $widget->add_control(
                'hiw_lists',
                [
                    'label'  => esc_html__('How it Work List', 'wiseguard'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                    'default' => [
                        [
                            'title' => 'Your Title',
                        ]
                    ],
                    'title_field' => '{{{ title }}}',
                    'condition' => [
                        'layout' => ['1']
                    ]
                ]
            );
            $widget->add_control(
                'banner_setting',
                [
                    'name'      => 'banner_heading',
                    'label'     => esc_html__('Banner Settings','wiseguard'),
                    'type'      => Controls_Manager::HEADING,
                    'separator' => 'before',
                    'condition' => [
                        'layout' => ['1']
                    ]
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'      => 'hiw_banner',
                    'default'   => 'custom',
                    'condition' => [
                        'layout' => ['1']
                    ]
                ]
            );  
                // Layout 2
                $repeater2 = new Repeater();
                $repeater2->add_control(
                    'hiw_icon',
                    [
                        'label'            => esc_html__( 'Icon', 'wiseguard' ),
                        'type'             => \Elementor\Controls_Manager::ICONS,
                        'default'          => [
                            'library' => 'cmsi-wiseguard',
                            'value'   => 'wiseguard-icon-default'       
                        ],
                        'skin'        => 'inline',
                        'label_block' => false
                    ]
                );
                $repeater2->add_control(
                    'title',
                    [
                        'label'       => esc_html__( 'Title', 'wiseguard' ),
                        'type'        => \Elementor\Controls_Manager::TEXTAREA,
                        'label_block' => true,
                        'default'     => 'Your Title',
                        'placeholder' => esc_html__( 'Enter your Title', 'wiseguard' ),
                    ]
                );
                $repeater2->add_control(
                    'description',
                    [
                        'label'       => esc_html__( 'Description', 'wiseguard' ),
                        'type'        => \Elementor\Controls_Manager::TEXTAREA,
                        'label_block' => true,
                        'default'     => 'Turpis massa tincidunt dui ut. Sit amet nisl purus in mollis nunc. Id neque aliquam vestibulum morbi blandit cursus risus',
                        'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    ]
                );
                $repeater2->add_control(
                    'link_text',
                    [
                        'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                        'type'        => Controls_Manager::TEXT,
                        'default'     => esc_html__( 'Click here', 'wiseguard' ),
                        'placeholder' => esc_html__( 'Click here', 'wiseguard' )
                    ]
                );
                $repeater2->add_control(
                    'link_type',
                    [
                        'label'   => esc_html__('Link Type', 'wiseguard'),
                        'type'    => Controls_Manager::SELECT,
                        'options' => [
                            'custom' => esc_html__('Custom', 'wiseguard'),
                            'page'   => esc_html__('Page', 'wiseguard'),
                        ],
                        'default' => 'custom'
                    ]
                );
                $repeater2->add_control(
                    'page_link',
                    [
                        'label'   => esc_html__('Select Page', 'wiseguard'),
                        'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                        'post_type' => [
                            'page'
                        ],
                        'multiple'  => false,
                        'condition' => [
                            'link_type' => 'page'
                        ]
                    ]
                );
                $repeater2->add_control(
                    'link',
                    [
                        'label'       => esc_html__( 'Link', 'wiseguard' ),
                        'type'        => Controls_Manager::URL,
                        'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                        'default'     => [
                            'url' => '#',
                        ],
                        'condition' => [
                            'link_type' => 'custom'
                        ]
                    ]
                );
            // add counter item
            $widget->add_control(
                'hiw_lists2',
                [
                    'label'  => esc_html__('How it Work List', 'wiseguard'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater2->get_controls(),
                    'default' => [
                        [
                            'hiw_icon'    => [
                                'library' => 'wiseguard-icon',
                                'value'   => 'wiseguard-icon-delete-2'
                            ],
                            'title'       => 'Provide Us With The Details',
                            'description' => 'We recognize that choosing the right service for home is the most important chosie, wiseguard can provide waste collection.',
                            'link_text' => 'Explore More'
                        ],
                        [
                            'hiw_icon'    => [
                                'library' => 'wiseguard-icon',
                                'value'   => 'wiseguard-icon-delete'
                            ],
                            'title'       => 'Pick The Suitable Plan For You',
                            'description' => 'We are reliable as our collection teams have a 24/7 presence in the world. We are never far away from your business to provide help.',
                            'link_text' => 'Explore More'
                        ],
                        [
                            'hiw_icon'    => [
                                'library' => 'wiseguard-icon',
                                'value'   => 'wiseguard-icon-recycle-bin-7'
                            ],
                            'title'       => 'Online Scheduling In Few Clicks ',
                            'description' => 'We provide cost effective waste collection services, we work hard to give unique quotes, we help you improves your cash flow.',
                            'link_text' => 'Explore More'
                        ],
                        [
                            'hiw_icon'    => [
                                'library' => 'wiseguard-icon',
                                'value'   => 'wiseguard-icon-reusable'
                            ],
                            'title'       => 'We Collect Waste & Leave Quickly',
                            'description' => 'Waste collection requires special treatment, therefore you shouldn’t put trash in your general waste bin or any big waste bags. ',
                            'link_text' => 'Explore More'
                        ]
                    ],
                    'title_field' => '{{{ title }}}',
                    'condition' => [
                        'layout' => ['2']
                    ]
                ]
            );
        $widget->end_controls_section();
    }
}