<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_icon_register_controls')) {
    add_action('etc_widget_cms_icon_register_controls', 'wiseguard_widget_cms_icon_register_controls', 10, 1);
    function wiseguard_widget_cms_icon_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_responsive_control(
                'align',
                [
                    'label'        => esc_html__( 'Alignment', 'wiseguard' ),
                    'type'         => Controls_Manager::CHOOSE,
                    'responsive'   => true,
                    'options'      => [
                        'start'    => [
                            'title' => esc_html__( 'Left', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-left',
                        ],
                        'center'  => [
                            'title' => esc_html__( 'Center', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-center',
                        ],
                        'end'   => [
                            'title' => esc_html__( 'Right', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-right',
                        ],
                        'justify'   => [
                            'title' => esc_html__( 'Justified', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-justify',
                        ]
                    ],
                    'style_transfer' => true
                ]
            );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_icon/layout/1.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();

        // icon Section Start
        $widget->start_controls_section(
            'section_icon',
            [
                'label' => esc_html__('Icons', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $repeater = new Repeater();

        $repeater->add_control(
            'cms_icon',
            [
                'label'            => esc_html__( 'Icon', 'wiseguard' ),
                'type'             => \Elementor\Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'default'          => [
                    'value'   => 'cmsi-star',
                    'library' => 'cmsi',
                ],
            ]
        );
        $repeater->add_control(
            'icon_link',
            [
                'label'       => esc_html__( 'Icon Link', 'wiseguard' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'label_block' => true,
            ]
        );
        $widget->add_control(
            'icons',
            [
                'label'   => esc_html__('Icons', 'wiseguard'),
                'type'    => \Elementor\Controls_Manager::REPEATER,
                'fields'  => $repeater->get_controls(),
                'default' => [
                    [
                        'cms_icon' => [
                            'library' => 'cmsi',
                            'value'   => 'cmsi-facebook'  
                        ],
                        'icon_link' => [
                            'url' => 'https://www.facebook.com/cmssuperheroes'
                        ]
                    ],
                    [
                        'cms_icon' => [
                            'library' => 'cmsi',
                            'value'   => 'cmsi-twitter-circle'  
                        ],
                        'icon_link' => [
                            'url' => 'https://twitter.com'
                        ]
                    ],
                    [
                        'cms_icon' => [
                            'library' => 'cmsi',
                            'value'   => 'cmsi-linkedin-circle'  
                        ],
                        'icon_link' => [
                            'url' => 'https://linkedin.com'
                        ]
                    ],
                ],
                'title_field' => '{{{ "<i class=\"" + cms_icon.value + "\"></i>" + " " + icon_link.url }}}',
            ]
        );
        $widget->end_controls_section(); // icon Section End
        // Style Section Start
        $widget->start_controls_section(
            'section_style',
            [
                'label' => esc_html__('Icons Style', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'color',
                'label'     => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-icon' => 'color: {{VALUE}} !important;',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'color_hover',
                'label'     => esc_html__( 'Color Hover', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-icon:hover' => 'color: {{VALUE}} !important;',
                ]
            ]);
        $widget->end_controls_section(); // Style Section End
        // Content Tab End
    }
}
