<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;

if (!function_exists('wiseguard_widget_cms_industry_carousel_register_controls')) {
    add_action('etc_widget_cms_industry_carousel_register_controls', 'wiseguard_widget_cms_industry_carousel_register_controls', 10, 1);
    function wiseguard_widget_cms_industry_carousel_register_controls($widget)
    {
        // Post term options
        $post_term_options = etc_get_grid_term_options('cms-industry');

        // Layout Settings
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard' ),
                'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__('Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '3',
                    'options' => [
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/layout/3.jpg'
                        ],
                        '6' => [
                            'label' => esc_html__( 'Layout 6', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/layout/6.jpg'
                        ],
                        '9' => [
                            'label' => esc_html__( 'Layout 9', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/layout/9.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start
        // Call to action
        $widget->start_controls_section(
            'cta_section',
            [
                'label' => esc_html__('Call To Action', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['6']
                ]
            ]
        );
            $widget->add_control(
                'cta_text',
                [
                    'label'       => esc_html__( 'Content', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Number One Waste Collection Service Provider!.',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' )
                ]
            ); 
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'cta_text_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-cta-desc' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'cta_text!' => ''
                ]
            ]);
            $widget->add_control(
                'cta_link_text',
                [
                    'label'       => esc_html__( 'Link Settings', 'wiseguard' ),
                    'description' => esc_html__('Link Text', 'wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Request A Quote',
                    'placeholder' => esc_html__( 'Click here', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'cta_link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'cta_link_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'cta_page_link',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'cta_link_text!' => '',
                        'cta_link_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'cta_custom_link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'cta_link_text!' => '',
                        'cta_link_type' => 'custom'
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'cta_link_color',
                'label'    => esc_html__( 'Link Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-cta-link' => 'color: {{VALUE}};'
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'cta_link_hover_color',
                'label'    => esc_html__( 'Link Hover Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-cta-link:hover' => 'color: {{VALUE}};'
                ]
            ]);
        $widget->end_controls_section();
        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Source', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'source',
            [
                'label' => esc_html__('Select Categories', 'wiseguard'),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $post_term_options,
            ]
        );
        $widget->add_control(
            'orderby',
            [
                'label'   => esc_html__('Order By', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date'   => esc_html__('Date', 'wiseguard'),
                    'ID'     => esc_html__('ID', 'wiseguard'),
                    'author' => esc_html__('Author', 'wiseguard'),
                    'title'  => esc_html__('Title', 'wiseguard'),
                    'rand'   => esc_html__('Random', 'wiseguard'),
                ],
            ]
        );
        $widget->add_control(
            'order',
            [
                'label'   => esc_html__('Sort Order', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__('Descending', 'wiseguard'),
                    'asc'  => esc_html__('Ascending', 'wiseguard'),
                ],
            ]
        );
        $widget->add_control(
            'limit',
            [
                'label'   => esc_html__('Total items', 'wiseguard'),
                'type'    => Controls_Manager::NUMBER,
                'default' => '6',
            ]
        );
        $widget->end_controls_section();
        // Source Section End
        // Display Section Start
        $widget->start_controls_section(
            'display_section',
            [
                'label' => esc_html__('Display', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'thumbnail',
                    'default' => 'custom',
                ]
            );
            $widget->add_control(
                'num_words',
                [
                    'label'       => esc_html__('Excerpt Length', 'wiseguard'),
                    'type'        => Controls_Manager::NUMBER,
                    'default'     => '',
                    'placeholder' => '25',
                    'separator'   => 'after',
                ]
            );

            $widget->add_control(
                'readmore_text',
                [
                    'label'       => esc_html__('Readmore Text', 'wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'placeholder' => esc_html__('Read More','wiseguard'),
                ]
            );
        $widget->end_controls_section();
        // Display Section End
        // Custom Content Start
        $widget->start_controls_section(
            'custom_content_section',
            [
                'label'     => esc_html__('Custom Content', 'wiseguard'),
                'tab'       => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['5']
                ]
            ]
        );
            $widget->add_control(
                'text',
                [
                    'label' => esc_html__('Custom Content','wiseguard'),
                    'type'  => Controls_Manager::TEXTAREA
                ]
            );
            // Button 1
            $widget->add_control(
                'link1_text',
                [
                    'label'       => esc_html__( 'Button #1', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Awards And Milestones', 'wiseguard' ),
                    'separator'   => 'before'
                ]
            );
            $widget->add_control(
                'link1_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default'   => 'custom',
                    'condition' => [
                        'link1_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link1_page',
                [
                    'label'     => esc_html__('Select Page', 'wiseguard'),
                    'type'      => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link1_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'custom'
                    ]
                ]
            );
            // Button 2
            $widget->add_control(
                'link2_text',
                [
                    'label'       => esc_html__( 'Button #2', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Contact Us', 'wiseguard' ),
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'link2_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link2_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link2_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link2_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
        // Custom Content End
        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $slides_to_show = range(1, 10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                    ] + $slides_to_show,
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label' => esc_html__('Slides to Scroll', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'wiseguard'),
                'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );
        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'wiseguard'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 40,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrows',
            [
                'label'              => esc_html__('Show Arrows', 'wiseguard'),
                'type'               => \Elementor\Controls_Manager::SWITCHER,
                'default'            => 'yes',
                'frontend_available' => true,
            ]
        );
            $widget->add_control(
                'arrow_prev_icon',
                [
                    'label'            => esc_html__('Previous Arrow Icon', 'wiseguard'),
                    'type'             => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'skin'             => 'inline',
                    'label_block'      => false,
                    'skin_settings' => [
                        'inline' => [
                            'none' => [
                                'label' => 'Default',
                                'icon' => 'eicon-chevron-left',
                            ],
                            'icon' => [
                                'icon' => 'eicon-chevron-left',
                            ],
                        ],
                    ],
                    'recommended' => [
                        'fa-regular' => [
                            'arrow-alt-circle-left',
                            'caret-square-left',
                        ],
                        'fa-solid' => [
                            'angle-double-left',
                            'angle-left',
                            'arrow-alt-circle-left',
                            'arrow-circle-left',
                            'arrow-left',
                            'caret-left',
                            'caret-square-left',
                            'chevron-circle-left',
                            'chevron-left',
                            'long-arrow-alt-left',
                        ],
                    ],
                    'condition' => [
                        'arrows' => 'yes'
                    ],
                ]
            );
            $widget->add_control(
                'arrow_next_icon',
                [
                    'label'            => esc_html__('Next Arrow Icon', 'wiseguard'),
                    'type'             => Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'skin'             => 'inline',
                    'label_block'      => false,
                    'skin_settings'    => [
                        'inline' => [
                            'none' => [
                                'label' => 'Default',
                                'icon' => 'eicon-chevron-right',
                            ],
                            'icon' => [
                                'icon' => 'eicon-chevron-right',
                            ]
                        ],
                    ],
                    'recommended' => [
                        'fa-regular' => [
                            'arrow-alt-circle-right',
                            'caret-square-right',
                        ],
                        'fa-solid' => [
                            'angle-double-right',
                            'angle-right',
                            'arrow-alt-circle-right',
                            'arrow-circle-right',
                            'arrow-right',
                            'caret-right',
                            'caret-square-right',
                            'chevron-circle-right',
                            'chevron-right',
                            'long-arrow-alt-right',
                        ],
                    ],
                    'condition' => [
                        'arrows' => 'yes'
                    ],
                    'separator' => 'after'
                ]
            );
        $widget->add_control(
            'dots',
            [
                'label'              => esc_html__('Show Dots', 'wiseguard'),
                'type'               => \Elementor\Controls_Manager::SWITCHER,
                'default'            => 'yes',
                'frontend_available' => true
            ]
        );    
        $widget->add_control(
            'lazyload',
            [
                'label'              => esc_html__('Lazyload', 'wiseguard'),
                'type'               => Controls_Manager::SWITCHER,
                'frontend_available' => true
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'wiseguard'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'wiseguard'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'wiseguard'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'wiseguard'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'wiseguard'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'wiseguard'),
                    'fade' => esc_html__('Fade', 'wiseguard'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'wiseguard'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();
        // Carousel Section End
        // Content Tab End

        // Style Tab Start
        // Custom layout
        $widget->start_controls_section(
            'content_width_section',
            [
                'label'      => esc_html__('Custom Styles', 'wiseguard'),
                'tab'        => Controls_Manager::TAB_STYLE,
            ]
        );
            $widget->add_control(
                'content_width',
                [
                    'label'     => esc_html__('Content Width', 'wiseguard'),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        ''             => esc_html__('Default', 'wiseguard'),
                        'start'        => esc_html__('Full to Start', 'wiseguard'),
                        'end'          => esc_html__('Full to End', 'wiseguard'),
                        'start-large'  => esc_html__('Full to Start (Large)', 'wiseguard'),
                        'end-large'    => esc_html__('Full to End (Large)', 'wiseguard'),
                        'start-mlarge' => esc_html__('Full to Start (Medium Large)', 'wiseguard'),
                        'end-mlarge'   => esc_html__('Full to End (Medium Large)', 'wiseguard'),
                        'start-xlarge' => esc_html__('Full to Start (Extra Large)', 'wiseguard'),
                        'end-xlarge'   => esc_html__('Full to End (Extra Large)', 'wiseguard'),
                        'both'         => esc_html__('Full to Both', 'wiseguard')
                    ],
                    'prefix_class' => 'cms-swiper-full-'
                ]
            );
            $widget->add_control(
                'item_shadow',
                [
                    'label'     => esc_html__('Item Shadow?', 'wiseguard'),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'yes' => esc_html__('Yes', 'wiseguard'),
                        'no'   => esc_html__('No', 'wiseguard')
                    ],
                    'default' => 'no',
                    'dynamic' => [
                        'active' => true
                    ],
                    'style_transfer' => true,
                    'prefix_class' => 'cms-carousel-item-shadow-',

                ]
            );
        $widget->end_controls_section();
        // Naivgation Section Start
        $widget->start_controls_section(
            'navigation_section',
            [
                'label'      => esc_html__('Navigation', 'wiseguard'),
                'tab'        => Controls_Manager::TAB_STYLE,
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name'     => 'arrows',
                            'operator' => '==',
                            'value'    => 'yes',
                        ]
                    ]
                ]
            ]
        );

            $widget->add_control(
                'heading_style_arrows',
                [
                    'label'     => esc_html__('Arrows', 'wiseguard'),
                    'type'      => Controls_Manager::HEADING,
                    'separator' => 'before',
                    'condition' => [
                        'arrows' => 'yes',
                    ],
                ]
            );
            $widget->add_control(
                'arrows_size',
                [
                    'label' => esc_html__('Size', 'wiseguard'),
                    'type'  => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 20,
                            'max' => 60,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .cms-carousel-button-prev i, {{WRAPPER}} .cms-carousel-button-next i' => 'font-size: {{SIZE}}{{UNIT}};',
                    ],
                    'condition' => [
                        'arrows' => 'yes',
                    ],
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'arrows_color',
                'label'     => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-carousel-button-prev, {{WRAPPER}} .cms-carousel-button-next' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-button-prev svg, {{WRAPPER}} .cms-carousel-button-next svg' => 'fill: {{VALUE}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'arrows_color_hover',
                'label'     => esc_html__( 'Color Hover', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-carousel-button-prev:hover, {{WRAPPER}} .cms-carousel-button-next:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-button-prev:hover svg, {{WRAPPER}} .cms-carousel-button-next:hover svg' => 'fill: {{VALUE}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                ]
            ]);
        $widget->end_controls_section();
        // Naivgation Section End
        // Dots Section Start
        $widget->start_controls_section(
            'dots_section',
            [
                'label'      => esc_html__('Dots', 'wiseguard'),
                'tab'        => Controls_Manager::TAB_STYLE,
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'dots',
                            'operator' => '==',
                            'value' => 'yes',
                        ]
                    ]
                ]
            ]
        );
            wiseguard_elementor_responsive_flex_alignment($widget, ['name' => 'dots-align']);
        $widget->end_controls_section();
        // Dots Section End
        // Style Tab End
    }
}
