<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;

if (!function_exists('wiseguard_widget_cms_industry_grid_register_controls')) {
    add_action('etc_widget_cms_industry_grid_register_controls', 'wiseguard_widget_cms_industry_grid_register_controls', 10, 1);
    function wiseguard_widget_cms_industry_grid_register_controls($widget)
    {
        // Layout Settings
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard' ),
                'tab' => \Elementor\Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__('Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '3',
                    'options' => [
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/layout/3.jpg'
                        ],
                        '6' => [
                            'label' => esc_html__( 'Layout 6', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/layout/6.jpg'
                        ],
                        '9' => [
                            'label' => esc_html__( 'Layout 9', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/layout/9.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();

        // Post term options
        $post_term_options = etc_get_grid_term_options('cms-industry');

        // Content Tab Start

        // Source Section Start
        $widget->start_controls_section(
            'source_section',
            [
                'label' => esc_html__('Source', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'source',
            [
                'label' => esc_html__('Select Categories', 'wiseguard'),
                'type' => Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $post_term_options,
            ]
        );
        $widget->add_control(
            'orderby',
            [
                'label'   => esc_html__('Order By', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'date',
                'options' => [
                    'date'   => esc_html__('Date', 'wiseguard'),
                    'ID'     => esc_html__('ID', 'wiseguard'),
                    'author' => esc_html__('Author', 'wiseguard'),
                    'title'  => esc_html__('Title', 'wiseguard'),
                    'rand'   => esc_html__('Random', 'wiseguard'),
                ],
            ]
        );
        $widget->add_control(
            'order',
            [
                'label'   => esc_html__('Sort Order', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'desc' => esc_html__('Descending', 'wiseguard'),
                    'asc'  => esc_html__('Ascending', 'wiseguard'),
                ],
            ]
        );
        $widget->add_control(
            'limit',
            [
                'label'   => esc_html__('Total items', 'wiseguard'),
                'type'    => Controls_Manager::NUMBER,
                'default' => '6',
            ]
        );
        $widget->end_controls_section();
        // Source Section End

        // Grid Section Start
        $widget->start_controls_section(
            'grid_section',
            [
                'label' => esc_html__('Grid', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        
        $widget->add_control(
            'filter',
            [
                'label'   => esc_html__('Filter on Masonry', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'true'  => esc_html__('Enable', 'wiseguard'),
                    'false' => esc_html__('Disable', 'wiseguard'),
                ],
                'default' => 'false',
            ]
        );
        $widget->add_control(
            'filter_default_title',
            [
                'label'     => esc_html__('Filter Default Title', 'wiseguard'),
                'type'      => Controls_Manager::TEXT,
                'default'   => esc_html__('All', 'wiseguard'),
                'condition' => [
                    'filter' => 'yes',
                ],
            ]
        );
        $widget->add_control(
            'filter_alignment',
            [
                'label'   => esc_html__('Filter Alignment', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'center' => esc_html__('Center', 'wiseguard'),
                    'left'   => esc_html__('Left', 'wiseguard'),
                    'right'  => esc_html__('Right', 'wiseguard'),
                ],
                'default'   => 'center',
                'condition' => [
                    'filter' => 'yes',
                ],
            ]
        );
        $widget->add_control(
            'pagination_type',
            [
                'label'   => esc_html__('Pagination Type', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'pagination' => esc_html__('Pagination', 'wiseguard'),
                    'loadmore'   => esc_html__('Loadmore', 'wiseguard'),
                    'false'      => esc_html__('Disable', 'wiseguard'),
                ],
                'default' => 'false',
            ]
        );
        $widget->add_responsive_control(
            'col',
            [
                'label'        => esc_html__('Columns', 'wiseguard'),
                'type'         => Controls_Manager::SELECT,
                'default'      => '',
                'default_args' => [
                    'tablet' => '',
                    'mobile' => ''
                ],
                'options' => [
                    '' => esc_html__('Default', 'wiseguard'),
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                    '6' => '6',
                ]
            ]
        );
        $widget->end_controls_section();
        // Grid Section End

        // Display Section Start
        $widget->start_controls_section(
            'display_section',
            [
                'label' => esc_html__('Display', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'    => 'thumbnail',
                'default' => 'custom',
            ]
        );
        $widget->add_control(
            'num_words',
            [
                'label'       => esc_html__('Excerpt Length', 'wiseguard'),
                'type'        => Controls_Manager::NUMBER,
                'default'     => '',
                'placeholder' => '25',
                'separator'   => 'after',
            ]
        );

        $widget->add_control(
            'readmore_text',
            [
                'label'       => esc_html__('Readmore Text', 'wiseguard'),
                'type'        => Controls_Manager::TEXT,
                'placeholder' => esc_html__('Read More','wiseguard'),
            ]
        );
        
        $widget->end_controls_section();
        // Display Section End

        // Content Tab End
    }
}
