<?php

use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;

if (!function_exists('wiseguard_widget_cms_list_register_controls')) {
    add_action('etc_widget_cms_list_register_controls', 'wiseguard_widget_cms_list_register_controls', 10, 1);
    function wiseguard_widget_cms_list_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_list/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_list/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_list/layout/3.jpg'
                        ],
                        '4' => [
                            'label' => esc_html__( 'Layout 4', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_list/layout/4.jpg'
                        ],
                        '5' => [
                            'label' => esc_html__( 'Layout 5', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_list/layout/5.jpg'
                        ],
                        '7' => [
                            'label' => esc_html__( 'Layout 7', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_list/layout/7.jpg'
                        ],
                        '8' => [
                            'label' => esc_html__( 'Layout 8', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_list/layout/8.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start
        // Heading
        $widget->start_controls_section(
            'heading_section',
            [
                'label' => esc_html__('Heading','wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['3','4','5','7']
                ]
            ]
        );
            $widget->add_responsive_control(
                'heading_align',
                [
                    'label'        => esc_html__( 'Alignment', 'wiseguard' ),
                    'type'         => Controls_Manager::CHOOSE,
                    'options'      => [
                        'start'    => [
                            'title' => esc_html__( 'Left', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-left',
                        ],
                        'center'  => [
                            'title' => esc_html__( 'Center', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-center',
                        ],
                        'end'   => [
                            'title' => esc_html__( 'Right', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-right',
                        ],
                        'justify' => [
                            'title' => esc_html__( 'Justified', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-justify',
                        ],
                    ],
                    'condition' => [
                        'heading_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'smallheading_text',
                [
                    'label'       => esc_html__( 'Small Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'smallheading_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-smallheading' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'smallheading_text!' => ''
                ]
            ]);
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'heading_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'heading_text!' => ''
                ]
            ]);
            $widget->add_control(
                'description_text',
                [
                    'label'       => esc_html__( 'Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'description_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};'
                ],
                'condition' => [
                    'description_text!' => ''
                ]
            ]);
        $widget->end_controls_section();
        // list Section Start
        $widget->start_controls_section(
            'section_list',
            [
                'label' => esc_html__('List Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
            $repeater = new Repeater();
                $repeater->add_control(
                    'title',
                    [
                        'label'       => esc_html__( 'Title', 'wiseguard' ),
                        'default'     => esc_html__( 'Title', 'wiseguard' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'label_block' => true,
                    ]
                );
            $widget->add_control(
                'cms_list',
                [
                    'label' => esc_html__('List', 'wiseguard'),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                    'default' => [
                        [
                            'title' => esc_html__('Title', 'wiseguard')
                        ],
                        [
                            'title' => esc_html__('Title', 'wiseguard'),
                        ],
                    ],
                    'title_field' => '{{{ title }}}',
                    'condition' => [
                        'layout' => ['1','3','4','5','7','8']
                    ]
                ]
            );
            $repeater7 = new Repeater();
                $repeater7->add_control(
                    'title',
                    [
                        'label'       => esc_html__( 'Title', 'wiseguard' ),
                        'default'     => esc_html__( 'Title', 'wiseguard' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'label_block' => true,
                    ]
                );
            $widget->add_control(
                'cms_list7',
                [
                    'label' => esc_html__('List', 'wiseguard'),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater7->get_controls(),
                    'default' => [
                        [
                            'title' => esc_html__('Title', 'wiseguard')
                        ],
                        [
                            'title' => esc_html__('Title', 'wiseguard'),
                        ],
                    ],
                    'title_field' => '{{{ title }}}',
                    'condition' => [
                        'layout' => ['7','8']
                    ]
                ]
            );
            $repeater2 = new Repeater();
                $repeater2->add_control(
                    'icon',
                    [
                        'label'       => esc_html__( 'Icon', 'wiseguard' ),
                        'default'     => [],
                        'type'        => Controls_Manager::ICONS,
                        'skin'        => 'inline'
                    ]
                );
                $repeater2->add_control(
                    'title',
                    [
                        'label'       => esc_html__( 'Title', 'wiseguard' ),
                        'default'     => 'Title',
                        'type'        => Controls_Manager::TEXTAREA,
                        'label_block' => true,
                    ]
                );
                $repeater2->add_control(
                    'desc',
                    [
                        'label'       => esc_html__( 'Description', 'wiseguard' ),
                        'default'     => 'Description. We are happy to take the time and attention to conduct an initial analysis of your project.',
                        'type'        => Controls_Manager::TEXTAREA,
                        'label_block' => true
                    ]
                );
            $widget->add_control(
                'cms_list2',
                [
                    'label' => esc_html__('List', 'wiseguard'),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater2->get_controls(),
                    'default' => [
                        [
                            'icon'  => ['library' => 'wiseguard-icon', 'value' => 'wiseguard-icon-garbage-10'],
                            'title' => 'Great Service & Low Cost ',
                            'desc'  => 'If your business is looking for reliable, cost effective general waste collection then you should choose us now!'
                        ],
                        [
                            'icon'  => ['library' => 'wiseguard-icon', 'value' => 'wiseguard-icon-plastic-2'],
                            'title' => esc_html__('Carbon Trust Certified', 'wiseguard'),
                            'desc'  => 'We will work with you to treat trash in the best possible way for environment and to save our beloved planet.'
                        ],
                        [
                            'icon'  => ['library' => 'wiseguard-icon', 'value' => 'wiseguard-icon-clean'],
                            'title' => esc_html__('Trusted And Local Experts', 'wiseguard'),
                            'desc'  => 'We are here to help you manage your waste removal, regardless of the size and type of your waste.'
                        ]
                    ],
                    'title_field' => '{{{ title }}}',
                    'condition' => [
                        'layout' => ['2']
                    ]
                ]
            );
            $repeater45 = new Repeater();
                $repeater45->add_control(
                    'banner',
                    [
                        'label'       => esc_html__( 'Banner', 'wiseguard' ),
                        'default'     => [],
                        'type'        => Controls_Manager::MEDIA,
                        'label_block' => true
                    ]
                );
                $repeater45->add_control(
                    'title',
                    [
                        'label'       => esc_html__( 'Title', 'wiseguard' ),
                        'default'     => esc_html__( 'Title', 'wiseguard' ),
                        'type'        => Controls_Manager::TEXTAREA,
                        'label_block' => true,
                    ]
                );
                $repeater45->add_control(
                    'desc',
                    [
                        'label'       => esc_html__( 'Description', 'wiseguard' ),
                        'default'     => 'We are happy to take the time and attention to conduct an initial analysis of your project. Thanks to this, we will be able to advise you accordingly.',
                        'type'        => Controls_Manager::TEXTAREA,
                        'label_block' => true
                    ]
                );
            $widget->add_control(
                'cms_list45',
                [
                    'label' => esc_html__('List', 'wiseguard'),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater45->get_controls(),
                    'default' => [
                        [
                            'title' => esc_html__('Title', 'wiseguard'),
                            'desc'  => 'We are happy to take the time and attention to conduct an initial analysis of your project. Thanks to this, we will be able to advise you accordingly.'
                        ],
                        [
                            'title' => esc_html__('Title #2', 'wiseguard'),
                            'desc'  => 'We are happy to take the time and attention to conduct an initial analysis of your project. Thanks to this, we will be able to advise you accordingly.'
                        ],
                    ],
                    'title_field' => '{{{ title }}}',
                    'condition' => [
                        'layout' => ['45']
                    ]
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'banner',
                    'label'   => esc_html__('Banner Size','wiseguard'),
                    'default' => 'custom',
                    'condition' => [
                        'layout' => ['45']
                    ]
                ]
            );
        $widget->end_controls_section(); // list Section End

        // Link 1
        $widget->start_controls_section('link1_section',[
            'label' => esc_html__('Link #1', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['1']
            ]
        ]);
            $widget->add_control(
                'link1_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Meet Our Experts', 'wiseguard' ),
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'link1_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link1_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link1_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link1_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
        // Link 2
        $widget->start_controls_section('link2_section',[
            'label' => esc_html__('Link #2', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['1']
            ]
        ]);
            $widget->add_control(
                'link2_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Get A Free Quote', 'wiseguard' ),
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'link2_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link2_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link2_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link2_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();

        // Style Section Start
        $widget->start_controls_section(
            'general_style_section',
            [
                'label' => esc_html__('Style', 'wiseguard'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            // Grid Columns
            $widget->add_responsive_control(
                'col',
                [
                    'label'        => esc_html__('Columns', 'wiseguard'),
                    'type'         => Controls_Manager::SELECT,
                    'default'      => '',
                    'default_args' => [
                        'tablet' => '',
                        'mobile' => ''
                    ],
                    'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                        '1' => '1',
                        '2' => '2',
                        '3' => '3',
                        '4' => '4',
                        '6' => '6',
                    ],
                    'condition' => [
                        'layout' => ['5']
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'icon_color',
                'label'    => esc_html__( 'Icon Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-icon' => 'color: {{VALUE}};'
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_color',
                'label'    => esc_html__( 'Title Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-title' => 'color: {{VALUE}};'
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'desc_color',
                'label'    => esc_html__( 'Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};'
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'bg_color',
                'label'    => esc_html__( 'Background Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-lists' => 'background-color: {{VALUE}};'
                ],
                'condition' => [
                    'layout' => ['5']
                ]
            ]);
        $widget->end_controls_section();// Style Section End
        // Content Tab End
    }
}
