<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_maps_pointers_register_controls')) {
    add_action('etc_widget_cms_maps_pointers_register_controls', 'wiseguard_widget_cms_maps_pointers_register_controls', 10, 1);
    function wiseguard_widget_cms_maps_pointers_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_maps_pointers/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_maps_pointers/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_maps_pointers/layout/3.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content
        $widget->start_controls_section(
            'conter_section',
            [
                'label' => esc_html__('Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
            // Rating
            $widget->add_control(
                'star_rated',
                [
                    'label'       => esc_html__( 'Star', 'wiseguard' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => [
                        '0'   => '0',
                        '20'  => '1',
                        '40'  => '2',
                        '60'  => '3',
                        '80'  => '4',
                        '100' => '5',
                    ],
                    'default' => '100',
                    'condition'   => [
                        'layout'  => ['3']  
                    ]
                ]
            );    
            $widget->add_control(
                'percent',
                [
                    'label'       => esc_html__( 'Percentage', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '99.9%',
                    'placeholder' => '99.9%',
                    'condition'   => [
                        'layout'  => ['3']  
                    ]
                ]
            );
            $widget->add_control(
                'percent_text',
                [
                    'label'       => esc_html__('Percentage Text', 'wiseguard'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Customer Satisfaction',
                    'placeholder' => 'Customer Satisfaction',
                    'condition'   => [
                        'layout'  => ['3']  
                    ]
                ]
            );
            $widget->add_control(
                'percent_text2',
                [
                    'label'   => esc_html__('Other Text', 'wiseguard'),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => 'based on 750+ reviews of 6,154 Completed Projects, and 2,194 Happy Customers trust us.',
                    'condition'   => [
                        'layout'  => ['3']  
                    ]
                ]
            );
            // Heading
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'condition'   => [
                        'layout'  => ['3']  
                    ]
                ]
            );
            // WordMap
            $widget->add_control(
                'maps_img',
                [
                    'label'   => esc_html__('World Map', 'wiseguard' ),
                    'type'    => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => get_template_directory_uri().'/elementor/templates/widgets/cms_maps_pointers/world-map.png',
                    ]
                ]
            );
            $widget->add_control(
                'active_pointer',
                [
                    'label'     => esc_html__( 'Active Pointer', 'wiseguard' ),
                    'type'      => Controls_Manager::NUMBER,
                    'default'   => 1,
                    'separator' => 'after',
                ]
            );
            $repeater = new Repeater();
            $repeater->add_control(
                'banner',
                [
                    'label'       => esc_html__('Banner', 'wiseguard'),
                    'type'        => Controls_Manager::MEDIA,
                    'label_block' => true,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ]
                ]
            );
            $repeater->add_control(
                'title',
                [
                    'label'       => esc_html__('Title', 'wiseguard'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'label_block' => true
                ]
            );
            $repeater->add_control(
                'address',
                [
                    'label'       => esc_html__('Address', 'wiseguard'),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'label_block' => true,
                ]
            );
            $repeater->add_responsive_control(
                'postion',
                [
                    'label'              => esc_html__('Item Postion', 'wiseguard' ),
                    'type'               => Controls_Manager::DIMENSIONS,
                    'allowed_dimensions' => ['top', 'left'],
                    'size_units'         => [ '%' ],
                    'range' => [
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'unit' => '%',
                        'top'  => '10',
                        'left' => '10'
                    ],
                    'selectors' => [
                        '{{WRAPPER}} {{CURRENT_ITEM}}.cms-pointer-item' => 'top: {{TOP}}{{UNIT}};left: {{LEFT}}{{UNIT}}',
                    ]
                ]
            );
            // add Pointers item
            $widget->add_control(
                'cms_pointers',
                [
                    'label'  => esc_html__('Pointers List', 'wiseguard'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                    'default' => [
                        [
                            'banner'  => [
                                'url' => Utils::get_placeholder_image_src()
                            ],
                            'title'   => 'Beverley Pickup',
                            'address' => '2307 Beverley Rd Brooklyn, New York 11226 United States.',
                            'postion' => [
                                'unit' => '%',
                                'top'  => '18',
                                'left' => '32'
                            ]
                        ]
                    ],
                    'title_field' => '{{{ title }}}',
                ]
            );
        $widget->end_controls_section();
        // Style
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE, 
            ]
        );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'banner',
                    'default' => 'custom',
                ]
            );
        $widget->end_controls_section();
    }
}