<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;

if (!function_exists('wiseguard_widget_cms_pricing_register_controls')) {
    add_action('etc_widget_cms_pricing_register_controls', 'wiseguard_widget_cms_pricing_register_controls', 10, 1);
    function wiseguard_widget_cms_pricing_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_pricing/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_pricing/layout/2.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start

        // Heading Section Start
        $widget->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Heading Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
            $widget->add_control(
                'badge_text',
                [
                    'label'       => esc_html__( 'Badge Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'BEST VALUE',
                    'label_block' => false,
                    'separator'   => 'after',
                    'dynamic'     => [
                        'active' => true,
                    ],
                    'condition' => [
                        'layout' => ['2']
                    ]
                ]
            );
            $widget->add_control(
                'price',
                [
                    'label'       => esc_html__( 'Price', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '$150',
                    'label_block' => true,
                    'separator'   => false,
                    'dynamic'     => [
                        'active' => true,
                    ]
                ]
            );
            $widget->add_control(
                'price_pack',
                [
                    'label'       => esc_html__( 'Price Pack', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '/Mo',
                    'label_block' => false,
                    'separator'   => 'after',
                    'dynamic'     => [
                        'active' => true,
                    ],
                    'condition' => [
                        'price!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'cms_icon',
                [
                    'label'            => esc_html__( 'Icon', 'wiseguard' ),
                    'type'             => Controls_Manager::ICONS,
                    'default'          => [
                        'value'   => 'cmsi-star',
                        'library' => 'cmsi',
                    ],
                ]
            );
            $widget->add_control(
                'subheading_text',
                [
                    'label'       => esc_html__( 'Small Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'placeholder' => esc_html__( 'Enter your small title', 'wiseguard' ),
                    'label_block' => true,
                    'dynamic' => [
                        'active' => true,
                    ]
                ]
            );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => esc_html__( 'Starter Plan', 'wiseguard' ),
                    'placeholder' => esc_html__( 'Enter your title', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'description_text_bold',
                [
                    'label'       => esc_html__( 'Description (Bold)', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'placeholder' => esc_html__( 'Enter your description', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'description_text',
                [
                    'label'       => esc_html__( 'Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'placeholder' => esc_html__( 'Enter your description', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before'
                ]
            );
        $widget->end_controls_section();
        // Link 1
        $widget->start_controls_section('link1_section',[
            'label' => esc_html__('Link #1', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT
        ]);
            $widget->add_control(
                'link1_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Get Started Now',
                    'placeholder' => esc_html__( 'Get Started Now', 'wiseguard' ),
                    'separator'   => 'before'
                ]
            );
            $widget->add_control(
                'link1_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link1_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link1_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link1_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'custom'
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'      => 'link1_color',
                'label'     => esc_html__('Link Color', 'wiseguard'),
                'custom'    => false,
                'default'   => 'accent',
                'condition' => [
                    'link1_text!' => ''
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'      => 'link1_hover',
                'label'     => esc_html__('Link Color', 'wiseguard'),
                'custom'    => false,
                'default'   => 'primary',
                'condition' => [
                    'link1_text!' => ''
                ]
            ]);
        $widget->end_controls_section();
        // Link 2
        $widget->start_controls_section('link2_section',[
            'label' => esc_html__('Link #2', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['2']
            ]
        ]);
            $widget->add_control(
                'link2_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Contact Us', 'wiseguard' ),
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'link2_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link2_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link2_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link2_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'custom'
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'      => 'link2_color',
                'label'     => esc_html__('Link Color', 'wiseguard'),
                'custom'    => false,
                'default'   => 'white',
                'condition' => [
                    'link2_text!' => ''
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'      => 'link2_hover',
                'label'     => esc_html__('Link Color', 'wiseguard'),
                'custom'    => false,
                'default'   => 'white',
                'condition' => [
                    'link2_text!' => ''
                ]
            ]);
        $widget->end_controls_section();
        // Features
        $widget->start_controls_section('features_section',[
            'label' => esc_html__('Features Settings', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT
        ]);
            $repeater = new Repeater();
            $repeater->add_control(
                'icon',
                [
                    'label'       => esc_html__( 'Icon', 'wiseguard' ),
                    'default'     => [
                        'library'   => 'cmsi',
                        'value'     => 'cmsi-check-circle'
                    ],
                    'type'        => Controls_Manager::ICONS,
                    'skin'        => 'inline',
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'title',
                [
                    'label'       => esc_html__( 'Title', 'wiseguard' ),
                    'default'     => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );
            $widget->add_control(
                'cms_feature',
                [
                    'label'   => esc_html__('Features List', 'wiseguard'),
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => $repeater->get_controls(),
                    'default' => [
                        [
                            'icon'  => [
                                'library'   => 'cmsi',
                                'value'     => 'cmsi-check'
                            ],
                            'title' => 'Enterprise Network Video Recorders',
                        ],
                        [
                            'icon'  => [
                                'library'   => 'cmsi',
                                'value'     => 'cmsi-check'
                            ],
                            'title' => 'Intelligent video technology storage',
                        ],
                        [
                            'icon'  => [
                                'library'   => 'cmsi',
                                'value'     => 'cmsi-check'
                            ],
                            'title' => 'Streaming over network or Internet',
                        ]
                    ],
                    'title_field' => '{{{ title }}}',
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'feature_text_color',
                'label'    => esc_html__( 'Text Color', 'wiseguard' ),
                'custom'   => false 
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'feature_icon_color',
                'label'    => esc_html__( 'Icon Color', 'wiseguard' ),
                'custom'   => false 
            ]);
        $widget->end_controls_section();
        // Banner
        $widget->start_controls_section('banner_section',[
            'label' => esc_html__('Banner', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['2']
            ]
        ]);
            $widget->add_control(
                'banner',
                [
                    'label'   => esc_html__( 'Banner', 'wiseguard' ),
                    'type'    => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ]
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'banner',
                    'label'   => esc_html__('Banner Size','wiseguard'),
                    'default' => 'custom',
                    'condition' => [
                        'banner[url]!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'banner_gradient',
                [
                    'label'        => esc_html__( 'Gradient Style', 'wiseguard' ),
                    'type'         => Controls_Manager::SELECT,
                    'options'      => wiseguard_elementor_gradient_opts(),
                    'default'   => '',
                    'separator' => 'before',
                    'condition' => [
                        'banner[url]!' => ''
                    ]
                ]
            );
        $widget->end_controls_section();
    }
}
