<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_process_register_controls')) {
    add_action('etc_widget_cms_process_register_controls', 'wiseguard_widget_cms_process_register_controls', 10, 1);
    function wiseguard_widget_cms_process_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout_mode',
                [
                    'label'   => esc_html__( 'Layout Mode', 'wiseguard' ),
                    'type'    => Controls_Manager::SELECT,
                    'default' => 'carousel',
                    'options' => [
                        'grid'     => esc_html__('Grid', 'wiseguard'),
                        'carousel' => esc_html__('Carousel', 'wiseguard')
                    ]
                ]
            );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_process/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_process/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_process/layout/3.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Tab Start
        // Heading Section Start
        $widget->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Heading Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['3']
                ]
            ]
        );
            $widget->add_control(
                'smallheading_text',
                [
                    'label'       => esc_html__( 'Small Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is small heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'separator'   => 'after'
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'smallheading_color',
                'label'     => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-smallheading' => 'color: {{VALUE}};',
                ]
            ]);
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'heading_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading, {{WRAPPER}} .cms-heading a' => 'color: {{VALUE}};',
                ]
            ]);
            $widget->add_control(
                'description_bold_text',
                [
                    'label'       => esc_html__( 'Description (Bold)', 'wiseguard' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => 'Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text ever since', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before'
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'description_bold_color',
                'label'     => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc-bold' => 'color: {{VALUE}};',
                ]
            ]);
            
            $widget->add_control(
                'description_text',
                [
                    'label'       => esc_html__( 'Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before'
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'description_color',
                'label'     => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};',
                ]
            ]);
            
        $widget->end_controls_section();
        // Link 1
        $widget->start_controls_section('link1_section',[
            'label' => esc_html__('Link #1', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['3']
            ]
        ]);
            $widget->add_control(
                'link1_text',
                [
                    'label'       => esc_html__( 'Link #1 Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Discover More',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'link1_type',
                [
                    'label'   => esc_html__('Link #1 Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link1_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link1_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link1_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'custom'
                    ]
                ]
            );
            // Link #1
            wiseguard_elementor_colors_opts($widget,[
                'name'      => 'link1_color',
                'label'     => esc_html__( 'Link #1 Color', 'wiseguard' ),
                'custom'    => false,
                'separator' => 'before'
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'   => 'link1_color_hover',
                'label'  => esc_html__( 'Link #1 Color Hover', 'wiseguard' ),
                'custom' => false
            ]);
        $widget->end_controls_section();
        // Features
        $widget->start_controls_section('features_section',[
            'label' => esc_html__('Features Settings', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['3']
            ]
        ]);
            $repeater = new Repeater();
            $repeater->add_control(
                'title',
                [
                    'label'       => esc_html__( 'Title', 'wiseguard' ),
                    'default'     => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );
            $widget->add_control(
                'show_feature',
                [
                    'label'   => esc_html__('Show Feature', 'wiseguard'),
                    'type'    => Controls_Manager::SWITCHER,
                    'default' => 'yes'
                ]
            );
            $widget->add_control(
                'cms_feature',
                [
                    'label'   => esc_html__('Features List', 'wiseguard'),
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => $repeater->get_controls(),
                    'default' => [
                        [
                            'title' => 'Quality Control System, Highly Professional Staff',
                        ],
                        [
                            'title' => 'Satisfaction Guarantee, and Accurate Testing',
                        ]
                    ],
                    'title_field' => '{{{ title }}}'
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'feature_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading-features' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-heading-features .cms-icon' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
        // List Section Start
        $widget->start_controls_section(
            'list_section',
            [
                'label' => esc_html__('Process Lists', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $process = new Repeater();
            $process->add_control(
                'icon',
                [
                    'label' => esc_html__('Icon', 'wiseguard'),
                    'type' => Controls_Manager::ICONS,
                    'skin' => 'inline'
                ]
            );
            $process->add_control(
                'image',
                [
                    'label' => esc_html__('Image', 'wiseguard'),
                    'type' => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ]
                ]
            );
            $process->add_control(
                'step_title',
                [
                    'label'   => esc_html__('Step Title', 'wiseguard'),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => 'Step title here',
                ]
            );
            $process->add_control(
                'title',
                [
                    'label'   => esc_html__('Title', 'wiseguard'),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => 'Your title here',
                ]
            );

            $process->add_control(
                'desc',
                [
                    'label'   => esc_html__( 'Description', 'wiseguard' ),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => 'Your description here. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry',
                ]
            );
            $process->add_control(
                'btn_text',
                [
                    'label'       => esc_html__('Button', 'wiseguard'),
                    'description' => esc_html__('Button Text','wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Discover More Info',  
                    'label_block' => true
                ]
            );
            $process->add_control(
                'btn_link_type',
                [
                    'label'   => esc_html__('Button Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'btn_text!'     => ''
                    ]
                ]
            );
            $process->add_control(
                'btn_page_link',
                [
                    'label'     => esc_html__('Select Page', 'wiseguard'),
                    'type'      => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'btn_text!'     => '',
                        'btn_link_type' => 'page'
                    ]
                ]
            );
        $widget->add_control(
            'process',
            [
                'label'   => esc_html__('Process', 'wiseguard'),
                'type'    => \Elementor\Controls_Manager::REPEATER,
                'fields'  => $process->get_controls(),
                'default' => [
                    [
                        'icon'  => [],
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title' => esc_html__('Your title here', 'wiseguard'),
                        'desc'  => 'Your description here. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry',
                    ],
                    [
                        'icon' => [],
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title' => esc_html__('Your title here #2', 'wiseguard'),
                        'desc'  => 'Your description here. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry',
                    ],
                    [
                        'icon'  => [],
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'title' => esc_html__('Your title here #3', 'wiseguard'),
                        'desc'  => 'Your description here. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry',
                    ]
                ],
                'title_field' => '{{{ title }}}',
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'    => 'image',
                'default' => 'custom',
            ]
        );
        $widget->end_controls_section();
        // List Section End
        // Style section
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'count_color',
                'label'    => esc_html__( 'Count Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-count' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_color',
                'label'    => esc_html__( 'Title Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading' => 'color: {{VALUE}};',
                ]
            ]);
             wiseguard_elementor_colors_opts($widget,[
                'name'     => 'desc_bold_color',
                'label'    => esc_html__( 'Description Bold Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc-bold' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'desc_color',
                'label'    => esc_html__( 'Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'feature_border_color',
                'label'    => esc_html__( 'Features List Border Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading-features .cms-list' => 'border-bottom-color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
        // Style Section End
        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel Settings', 'wiseguard'),
                'tab' => Controls_Manager::TAB_SETTINGS,
                'condition' => [
                    'layout_mode' => 'carousel'
                ]
            ]
        );
            $widget->add_control(
                'content_width',
                [
                    'label'     => esc_html__('Content Width', 'wiseguard'),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        ''            => esc_html__('Default', 'wiseguard'),
                        'start'       => esc_html__('Full to Start', 'wiseguard'),
                        'end'         => esc_html__('Full to End', 'wiseguard'),
                        'start-large' => esc_html__('Full to Start (Large)', 'wiseguard'),
                        'end-large'   => esc_html__('Full to End (Large)', 'wiseguard'),
                        'start-xlarge' => esc_html__('Full to Start (Extra Large)', 'wiseguard'),
                        'end-xlarge'   => esc_html__('Full to End (Extra Large)', 'wiseguard')
                    ],
                    'prefix_class' => 'cms-swiper-full-'
                ]
            );
            $widget->add_control(
                'item_shadow',
                [
                    'label'     => esc_html__('Item Shadow?', 'wiseguard'),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'yes' => esc_html__('Yes', 'wiseguard'),
                        'no'   => esc_html__('No', 'wiseguard')
                    ],
                    'default' => 'no',
                    'dynamic' => [
                        'active' => true
                    ],
                    'style_transfer' => true,
                    'prefix_class'   => 'cms-carousel-item-shadow-',
                    'separator'      => 'after'
                ]
            );

            $slides_to_show = range(1, 10);
            $slides_to_show = array_combine($slides_to_show, $slides_to_show);
            $widget->add_responsive_control(
                'slides_to_show',
                [
                    'label' => esc_html__('Slides to Show', 'wiseguard'),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                            '' => esc_html__('Default', 'wiseguard'),
                        ] + $slides_to_show,
                    'frontend_available' => true,
                ]
            );

            $widget->add_responsive_control(
                'slides_to_scroll',
                [
                    'label' => esc_html__('Slides to Scroll', 'wiseguard'),
                    'type' => Controls_Manager::SELECT,
                    'description' => esc_html__('Set how many slides are scrolled per swipe.', 'wiseguard'),
                    'options' => [
                            '' => esc_html__('Default', 'wiseguard'),
                        ] + $slides_to_show,
                    'condition' => [
                        'slides_to_show!' => '1',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_responsive_control(
                'space_between',
                [
                    'label' => esc_html__('Space Between', 'wiseguard'),
                    'type' => Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'size' => 40,
                    ],
                    'condition' => [
                        'slides_to_show!' => '1',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'arrows',
                [
                    'label' => esc_html__('Show Arrows', 'wiseguard'),
                    'type' => Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'arrows_color',
                'label'     => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-carousel-button-prev, {{WRAPPER}} .cms-carousel-button-next' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-button-prev svg, {{WRAPPER}} .cms-carousel-button-next svg' => 'fill: {{VALUE}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'arrows_color_hover',
                'label'     => esc_html__( 'Color Hover', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-carousel-button-prev:hover, {{WRAPPER}} .cms-carousel-button-next:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-button-prev:hover svg, {{WRAPPER}} .cms-carousel-button-next:hover svg' => 'fill: {{VALUE}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                ],
                'separator' => 'after'
            ]);
            $widget->add_control(
                'dots',
                [
                    'label' => esc_html__('Show Dots', 'wiseguard'),
                    'type' => Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'lazyload',
                [
                    'label' => esc_html__('Lazyload', 'wiseguard'),
                    'type' => Controls_Manager::SWITCHER,
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'autoplay',
                [
                    'label' => esc_html__('Autoplay', 'wiseguard'),
                    'type' => Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'pause_on_hover',
                [
                    'label' => esc_html__('Pause on Hover', 'wiseguard'),
                    'type' => Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                ]
            );

            $widget->add_control(
                'pause_on_interaction',
                [
                    'label' => esc_html__('Pause on Interaction', 'wiseguard'),
                    'type' => Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                ]
            );

            $widget->add_control(
                'autoplay_speed',
                [
                    'label' => esc_html__('Autoplay Speed', 'wiseguard'),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 5000,
                    'condition' => [
                        'autoplay' => 'yes',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'infinite',
                [
                    'label' => esc_html__('Infinite Loop', 'wiseguard'),
                    'type' => Controls_Manager::SWITCHER,
                    'default' => 'yes',
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'effect',
                [
                    'label' => esc_html__('Effect', 'wiseguard'),
                    'type' => Controls_Manager::SELECT,
                    'default' => 'slide',
                    'options' => [
                        'slide' => esc_html__('Slide', 'wiseguard'),
                        'fade' => esc_html__('Fade', 'wiseguard'),
                    ],
                    'condition' => [
                        'slides_to_show' => '1',
                    ],
                    'frontend_available' => true,
                ]
            );

            $widget->add_control(
                'speed',
                [
                    'label' => esc_html__('Animation Speed', 'wiseguard'),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 500,
                    'render_type' => 'none',
                    'frontend_available' => true,
                ]
            );

        $widget->end_controls_section();
        // Carousel Section End
        // Content Tab End
    }
}
