<?php
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;

if (!function_exists('wiseguard_widget_cms_product_tabs_register_controls')) {
    add_action('etc_widget_cms_product_tabs_register_controls', 'wiseguard_widget_cms_product_tabs_register_controls', 10, 1);
    function wiseguard_widget_cms_product_tabs_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_product_tabs/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_product_tabs/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_product_tabs/layout/3.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Products Content
        $widget->start_controls_section(
            'section_list',
            [
                'label' => esc_html__('Products Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
            $widget->add_control(
                'active_tab',
                [
                    'label'     => esc_html__( 'Active Tab', 'wiseguard' ),
                    'type'      => Controls_Manager::NUMBER,
                    'default'   => 2,
                    'min'       => '0',
                    'max'       => '50',
                    'separator' => 'after',
                ]
            );
            $repeater = new Repeater();
            $repeater->add_control(
                'tab_title_icon',
                [
                    'label'       => esc_html__( 'Tab Title Icon', 'wiseguard' ),
                    'type'        => Controls_Manager::ICONS,
                    'skin'        => 'inline',
                    'label_block' => false,
                ]
            );
            $repeater->add_control(
                'tab_title',
                [
                    'label'       => esc_html__( 'Tab Title', 'wiseguard' ),
                    'default'     => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                ]
            );
            // Product #1
            $repeater->add_control(
                'product1',
                [
                    'label'     => esc_html__( 'Choose Product #1', 'wiseguard' ),
                    'type'      => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'product'
                    ],
                    'multiple'    => false,
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'product1_desc',
                [
                    'label'     => esc_html__( 'Custom Product Description #1', 'wiseguard' ),
                    'type'      => Controls_Manager::TEXTAREA,
                    'description' => esc_html__('Enter your custom product Description. Default is Product Short Description','wiseguard'),
                    'label_block' => true,
                    'condition' => [
                        'product1!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'product1_feature',
                [
                    'label'       => esc_html__( 'Product Feature #1', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'description' => esc_html__('Each Feature perline','wiseguard'),
                    'label_block' => true,
                    'condition' => [
                        'product1!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'product1_icon',
                [
                    'label'       => esc_html__( 'Product Icon #1', 'wiseguard' ),
                    'type'        => Controls_Manager::ICONS,
                    'skin'        => 'inline',
                    'label_block' => false,
                    'condition'   => [
                        'product1!' => ''
                    ]
                ]
            );
            // Product #2
            $repeater->add_control(
                'product2',
                [
                    'label'     => esc_html__( 'Choose Product #2', 'wiseguard' ),
                    'type'      => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'product'
                    ],
                    'multiple'    => false,
                    'label_block' => true,
                    'separator'   => 'before'
                ]
            );
            $repeater->add_control(
                'product2_desc',
                [
                    'label'     => esc_html__( 'Custom Product Description #2', 'wiseguard' ),
                    'type'      => Controls_Manager::TEXTAREA,
                    'description' => esc_html__('Enter your custom product Description. Default is Product Short Description','wiseguard'),
                    'label_block' => true,
                    'condition' => [
                        'product2!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'product2_feature',
                [
                    'label'       => esc_html__( 'Product Feature #2', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'description' => esc_html__('Each Feature perline','wiseguard'),
                    'label_block' => true,
                    'condition' => [
                        'product2!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'product2_icon',
                [
                    'label'       => esc_html__( 'Product Icon #2', 'wiseguard' ),
                    'type'        => Controls_Manager::ICONS,
                    'skin'        => 'inline',
                    'label_block' => false,
                    'condition'   => [
                        'product2!' => ''
                    ]
                ]
            );
            // Product #3
            $repeater->add_control(
                'product3',
                [
                    'label'     => esc_html__( 'Choose Product #3', 'wiseguard' ),
                    'type'      => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'product'
                    ],
                    'multiple'    => false,
                    'label_block' => true,
                    'separator'   => 'before'
                ]
            );
            $repeater->add_control(
                'product3_desc',
                [
                    'label'     => esc_html__( 'Custom Product Description #3', 'wiseguard' ),
                    'type'      => Controls_Manager::TEXTAREA,
                    'description' => esc_html__('Enter your custom product Description. Default is Product Short Description','wiseguard'),
                    'label_block' => true,
                    'condition' => [
                        'product3!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'product3_feature',
                [
                    'label'       => esc_html__( 'Product Feature #3', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'description' => esc_html__('Each Feature perline','wiseguard'),
                    'label_block' => true,
                    'condition' => [
                        'product3!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'product3_icon',
                [
                    'label'       => esc_html__( 'Product Icon #3', 'wiseguard' ),
                    'type'        => Controls_Manager::ICONS,
                    'skin'        => 'inline',
                    'label_block' => false,
                    'condition'   => [
                        'product3!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'cms_product_tabs',
                [
                    'label'   => esc_html__('Products', 'wiseguard'),
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => $repeater->get_controls(),
                    'default' => [
                        [
                            'tab_title' => 'Containers'
                        ],
                        [
                            'tab_title' => 'Trash Bins',
                        ],
                        [
                            'tab_title' => 'Dumpsters',
                        ]
                    ],
                    'title_field' => '{{{ tab_title }}}'
                ]
            );
        $widget->end_controls_section();
        // Style 
        $widget->start_controls_section(
            'section_style',
            [
                'label' => esc_html__('Style Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            $widget->add_responsive_control(
                'col',
                [
                    'label'        => esc_html__('Product Columns', 'wiseguard'),
                    'type'         => Controls_Manager::SELECT,
                    'default'      => '',
                    'default_args' => [
                        'tablet' => '',
                        'mobile' => ''
                    ],
                    'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                        '1' => '1',
                        '2' => '2',
                        '3' => '3',
                        '4' => '4',
                        '6' => '6',
                    ]
                ]
            );

            wiseguard_elementor_colors_opts($widget,[
                'name'   => 'cms-tab-title-color',
                'label'  => esc_html__( 'Tab Title Color', 'wiseguard' ),
                'custom' => false
            ]);

            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_color',
                'label'     => esc_html__( 'Product Title Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .p-title' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'desc_color',
                'label'     => esc_html__( 'Product Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .p-desc' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'   => 'btn_color',
                'label'  => esc_html__( 'Button Color', 'wiseguard' ),
                'custom' => false
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'   => 'btn_hover_color',
                'label'  => esc_html__( 'Button Hover Color', 'wiseguard' ),
                'custom' => false
            ]);
        $widget->end_controls_section();
    }
}
