<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Utils;

if (!function_exists('wiseguard_widget_cms_progressbar_register_controls')) {
    add_action('etc_widget_cms_progressbar_register_controls', 'wiseguard_widget_cms_progressbar_register_controls', 10, 1);
    function wiseguard_widget_cms_progressbar_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_progressbar/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_progressbar/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_progressbar/layout/3.jpg'
                        ],
                        '4' => [
                            'label' => esc_html__( 'Layout 4', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_progressbar/layout/4.jpg'
                        ],
                        '5' => [
                            'label' => esc_html__( 'Layout 5', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_progressbar/layout/5.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Heading 
        $widget->start_controls_section(
            'heading_section',
            [
                'label'      => esc_html__('Heading', 'wiseguard'),
                'tab'        => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'smallheading_text',
                [
                    'label'       => esc_html__( 'Small Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is small heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'condition'   => [
                        'layout'    => ['4']
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'smallheading_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-smallheading' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout'             => ['4'],
                    'smallheading_text!' => ''
                ]
            ]);
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'condition'   => [
                        'layout'    => ['2','3','4','5']
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'heading_color',
                'label'    => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout'    => ['2','3','4','5'],
                    'heading_text!' => ''
                ]
            ]);
            $widget->add_control(
                'description_bold_text',
                [
                    'label'       => esc_html__( 'Description (Bold)', 'wiseguard' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => 'Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text ever since', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before',
                    'condition' => [
                        'layout'    => ['2','3','5']
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'description_bold_color',
                'label'     => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc-bold' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout'    => ['2','3','5'],
                    'description_bold_text!' => ''
                ]
            ]);
            $widget->add_control(
                'description_text',
                [
                    'label'       => esc_html__( 'Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before',
                    'condition' => [
                        'layout'    => ['2','3','4']
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'description_color',
                'label'     => esc_html__( 'Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout'    => ['2','3','4'],
                    'description_text!' => ''
                ]
            ]);
        $widget->end_controls_section();
        // Progressbar Section Start
        $widget->start_controls_section(
            'section_progressbar',
            [
                'label' => esc_html__('Progressbar Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'title',
            [
                'label'       => esc_html__( 'Title', 'wiseguard' ),
                'type'        => \Elementor\Controls_Manager::TEXT,
                'placeholder' => esc_html__( 'Enter your title', 'wiseguard' ),
                'default'     => esc_html__( 'My Skill', 'wiseguard' ),
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'percent',
            [
                'label'       => esc_html__( 'Percentage', 'wiseguard' ),
                'type'        => \Elementor\Controls_Manager::SLIDER,
                'default'     => [
                    'size' => 80,
                    'unit' => '%',
                ],
                'label_block' => true,
            ]
        );

        $widget->add_control(
            'progressbar_list',
            [
                'label' => esc_html__('List', 'wiseguard'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'title' => esc_html__('My Skill #1', 'wiseguard'),
                        'percent' => [
                            'size' => 90,
                            'unit' => '%',
                        ],
                    ],
                    [
                        'title' => esc_html__('My Skill #2', 'wiseguard'),
                        'percent' => [
                            'size' => 80,
                            'unit' => '%',
                        ],
                    ],
                ],
                'title_field' => '{{{ title }}}',
            ]
        );
        $widget->end_controls_section(); // Progressbar Section End
        // Signature
        $widget->start_controls_section('signature_section',[
            'label' => esc_html__('Signature', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['3']
            ]
        ]);
            $widget->add_control(
                'savatar',
                [
                    'label'   => esc_html__( 'Avatar', 'wiseguard' ),
                    'type'    => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ]
                ]
            );
            $widget->add_control(
                'simage',
                [
                    'label'   => esc_html__( 'Signature Image', 'wiseguard' ),
                    'type'    => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => get_template_directory_uri() . '/assets/images/signature.png'
                    ]
                ]
            );
            $widget->add_control(
                'sname',
                [
                    'label'       => esc_html__( 'Name', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Michael Brian',
                    'label_block' => false
                ]
            );
            $widget->add_control(
                'sposition',
                [
                    'label'       => esc_html__( 'Position', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'The Founder',
                    'label_block' => false
                ]
            );
        $widget->end_controls_section();
        // Link 1
        $widget->start_controls_section('link1_section',[
            'label' => esc_html__('Link #1', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['3','5']
            ]
        ]);
            $widget->add_control(
                'link1_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Discover More',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'separator' => 'before'
                ]
            );
            $widget->add_control(
                'link1_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link1_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link1_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link1_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
        // Link 2
        $widget->start_controls_section('link2_section',[
            'label' => esc_html__('Link #2', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['5']
            ]
        ]);
            $widget->add_control(
                'link2_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Your Button',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'separator'   => 'before'
                ]
            );
            $widget->add_control(
                'link2_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link2_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link2_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link2_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
        // Style Section Start
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_color',
                'label'     => esc_html__( 'Progress Title Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-progress-bar-title' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-progress-bar-title > span' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'progressbar_color',
                'label'     => esc_html__( 'Progress Bar Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-progress-bar' => 'background-color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'progress_color',
                'label'     => esc_html__( 'Progress Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-progress-wrap' => 'background-color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'link1_color',
                'label'     => esc_html__( 'Link #1 Color', 'wiseguard' ),
                'custom'    => false,
                'selector'  => 'before'    
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'link1_color_hover',
                'label'     => esc_html__( 'Link #1 Hover Color', 'wiseguard' ),
                'custom'    => false 
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'link2_color',
                'label'     => esc_html__( 'Link #2 Color', 'wiseguard' ),
                'custom'    => false,
                'selector'  => 'before'    
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'link2_color_hover',
                'label'     => esc_html__( 'Link #2 Hover Color', 'wiseguard' ),
                'custom'    => false 
            ]);
        $widget->end_controls_section();
    }
}
