<?php
use Elementor\Controls_Manager;

if (!function_exists('wiseguard_widget_cms_quickcontact_register_controls')) {
    add_action('etc_widget_cms_quickcontact_register_controls', 'wiseguard_widget_cms_quickcontact_register_controls', 10, 1);
    function wiseguard_widget_cms_quickcontact_register_controls($widget)
    {
        // Layout Settings
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__( 'Layout', 'wiseguard' ),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_responsive_control(
                'align',
                [
                    'label'        => esc_html__( 'Alignment', 'wiseguard' ),
                    'type'         => Controls_Manager::CHOOSE,
                    'options'      => [
                        'start'    => [
                            'title' => esc_html__( 'Left', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-left',
                        ],
                        'center'  => [
                            'title' => esc_html__( 'Center', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-center',
                        ],
                        'end'   => [
                            'title' => esc_html__( 'Right', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-right',
                        ],
                        'justify' => [
                            'title' => esc_html__( 'Justified', 'wiseguard' ),
                            'icon'  => 'eicon-text-align-justify',
                        ],
                    ]
                ]
            );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_quickcontact/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_quickcontact/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_quickcontact/layout/3.jpg'
                        ],
                        '4' => [
                            'label' => esc_html__( 'Layout 4', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_quickcontact/layout/4.jpg'
                        ],
                        '5' => [
                            'label' => esc_html__( 'Layout 5', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_quickcontact/layout/5.jpg'
                        ],
                        '6' => [
                            'label' => esc_html__( 'Layout 6', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_quickcontact/layout/6.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();

        // Title Section Start
        $widget->start_controls_section(
            'title_section',
            [
                'label'     => esc_html__('Title', 'wiseguard'),
                'tab'       => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['1']
                ]
            ]
        );
            $widget->add_control(
                'title',
                [
    				'label'       => '',
    				'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Quick Contact',  
    				'placeholder' => esc_html__('Enter your title', 'wiseguard')
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_color',
                'label'     => esc_html__( 'Title Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-title' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
        // Desc Section Start
        $widget->start_controls_section(
            'desc_section',
            [
                'label' => esc_html__('Description', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['1']
                ]
            ]
        );
            $widget->add_control(
                'desc',
                [
                    'label'       => '',
                    'default'     => 'If you have any questions or need help, feel free to contact with our team.',
                    'type'        => Controls_Manager::TEXTAREA,
                    'placeholder' => esc_html__('Enter your text', 'wiseguard')
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'desc_color',
                'label'     => esc_html__( 'Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
        // Address Section Start
        $widget->start_controls_section(
            'address_section',
            [
                'label' => esc_html__('Address', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
            $widget->add_control(
                'address_title',
                [
                    'label'       => esc_html__('Address Title','wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Location'  
                ]
            );
            $widget->add_control(
                'address',
                [
    				'label'       => '',
    				'type'        => Controls_Manager::TEXTAREA,
                    'default'     => '2307 Beverley Rd Brooklyn, New York 11226 United States.',
    				'placeholder' => esc_html__('Enter your address', 'wiseguard')
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'icon_address_color',
                'label'     => esc_html__( 'Icon Address Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-address .cms-icon' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => ['2','3','4','5','6']
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'address_color',
                'label'     => esc_html__( 'Address Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-address' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'address_color_hover',
                'label'     => esc_html__( 'Address Hover Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-address:hover' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
        // Email Section Start
        $widget->start_controls_section(
            'email_section',
            [
                'label' => esc_html__('Email', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['1','2','4','5']
                ]
            ]
        );
            $widget->add_control(
                'email_title',
                [
                    'label'       => esc_html__('Email Title','wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Email:',
                    'placeholder' => 'Email:',
                    'condition'   => [
                        'layout'  => ['2','4']
                    ]
                ]
            );
            $widget->add_control(
                'email',
                [
    				'label'       => '',
    				'type'        => Controls_Manager::TEXTAREA,
    				'default'     => 'Wiseguard@farost.net',
                    'placeholder' => 'Wiseguard@farost.net'
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'icon_email_color',
                'label'     => esc_html__( 'Icon Email Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-email .cms-icon' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => ['2']
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'email_color',
                'label'     => esc_html__( 'Email Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-email' => 'color: {{VALUE}};',
                ]
            ]);
             wiseguard_elementor_colors_opts($widget,[
                'name'     => 'email_color_hover',
                'label'     => esc_html__( 'Email Hover Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-email:hover' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
        // Phone Section Start
        $widget->start_controls_section(
            'phone_section',
            [
                'label' => esc_html__('Phone Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition'   => [
                    'layout'  => ['1','2','3','6']
                ]
            ]
        );
            $widget->add_control(
                'phone_title',
                [
                    'label'       => esc_html__('Phone Title','wiseguard'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'placeholder' => esc_html__('Enter title', 'wiseguard'),
                    'default'     => 'Customer Service',  
                    'condition'   => [
                        'layout'  => ['2','3','6']
                    ]
                ]
            );
            $widget->add_control(
                'phone',
                [
    				'label'       => esc_html__('Phone Number','wiseguard'),
    				'type'        => Controls_Manager::TEXT,
    				'default'     => '02 01061245741',
                    'placeholder' => '02 01061245741'
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'icon_phone_color',
                'label' => esc_html__('Icon Phone Color', 'wiseguard'),
                'selectors' => [
                    '{{WRAPPER}} .cms-phone .cms-icon' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'phone_color',
                'label' => esc_html__('Phone Color', 'wiseguard'),
                'selectors' => [
                    '{{WRAPPER}} .cms-phone' => 'color: {{VALUE}};',
                ],
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'phone_color_hover',
                'label' => esc_html__('Phone Hover Color', 'wiseguard'),
                'selectors' => [
                    '{{WRAPPER}} .cms-phone:hover' => 'color: {{VALUE}};',
                ],
            ]);
        $widget->end_controls_section();
        // Time Section Start
        $widget->start_controls_section(
            'time_section',
            [
                'label' => esc_html__('Time Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition'=> [
                    'layout' => ['3','4','5','6']
                ]
            ]
        );
            $widget->add_control(
                'time_title',
                [
                    'label'       => esc_html__('Time Title','wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => false,
                    'placeholder' => esc_html__('Enter title', 'wiseguard'),
                    'default'     => 'Mon - Fri',
                ]
            );
            $widget->add_control(
                'time',
                [
                    'label'       => esc_html__('Time','wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'placeholder' => '8:00 am - 7:00 pm',
                    'default'     => '8:00 am - 7:00 pm'  
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'icon_time_color',
                'label' => esc_html__('Icon Time Color', 'wiseguard'),
                'selectors' => [
                    '{{WRAPPER}} .cms-time .cms-icon' => 'color: {{VALUE}};',
                ],
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'time_color',
                'label' => esc_html__('Time Color', 'wiseguard'),
                'selectors' => [
                    '{{WRAPPER}} .cms-time' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'time_color_hover',
                'label' => esc_html__('Time Hover Color', 'wiseguard'),
                'selectors' => [
                    '{{WRAPPER}} .cms-time:hover' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
        // Button Section Start
        $widget->start_controls_section(
            'button_section',
            [
                'label'     => esc_html__('Button Settings', 'wiseguard'),
                'tab'       => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['3','6']
                ]
            ]
        );         
            $widget->add_control(
                'btn_text',
                [
                    'label'       => esc_html__( 'Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',
                    'placeholder' => esc_html__( 'Click here', 'wiseguard' )
                ]
            );
            $widget->add_control(
                'link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'btn_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'page_link',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'btn_text!' => '',
                        'link_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'btn_text!' => '',
                        'link_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();

        // Style Section
        $widget->start_controls_section(
            'show_hide_title_section',
            [
                'label' => esc_html__('Title Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'layout' => ['2','4','5']
                ]
            ]
        );
	        wiseguard_add_hidden_device_controls($widget, [
                'prefix' => 'title_',
            ]);
        $widget->end_controls_section(); 
    }
}
