<?php
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_reviews_register_controls')) {
    add_action('etc_widget_cms_reviews_register_controls', 'wiseguard_widget_cms_reviews_register_controls', 10, 1);
    function wiseguard_widget_cms_reviews_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_reviews/layout/1.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content
        $widget->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );  
            $reviews = new Repeater();
            $reviews->add_control(
                'banner',
                [
                    'label'   => esc_html__( 'Banner', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ]
                ]
            );
            $reviews->add_control(
                'text',
                [
                    'label'   => esc_html__( 'Text', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::TEXT,
                    'default' => 'Reliable and trusted services to meet all your waste requirements, feel free to request a free quote today!!'
                ]
            );
            $reviews->add_control(
                'link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => 'https://your-link.com',
                    'default'     => [
                        'url' => '#',
                    ]
                ]
            );
            //
            $widget->add_control(
                'reviews',
                [
                    'label' => esc_html__('Reviews','wiseguard'),
                    'type'  => Controls_Manager::REPEATER,
                    'fields' => $reviews->get_controls(),
                    'default' => [
                        [
                            'banner' => ['url' => Utils::get_placeholder_image_src()],
                            'title'  => 'Check out our reviews on Google',
                            'link'   => ['url' => '#']
                        ],
                        [
                            'banner' => ['url' => Utils::get_placeholder_image_src()],
                            'title'  => 'Check out our reviews on Yelp',
                            'link'   => ['url' => '#']
                        ],
                        [
                            'banner' => ['url' => Utils::get_placeholder_image_src()],
                            'title'  => 'Check out our reviews on Trustpilot',
                            'link'   => ['url' => '#']
                        ]
                    ],
                    'title_field' => '{{title}}'
                ]
            );
        $widget->end_controls_section();

        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'star_color',
                'label'    => esc_html__( 'Star Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-star-rate' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'text_color',
                'label'    => esc_html__( 'Text Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-text' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
    }
}
