<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;

if (!function_exists('wiseguard_widget_cms_star_rating_register_controls')) {
    add_action('etc_widget_cms_star_rating_register_controls', 'wiseguard_widget_cms_star_rating_register_controls', 10, 1);
    function wiseguard_widget_cms_star_rating_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_star_rating/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_star_rating/layout/2.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content Section Start
        $widget->start_controls_section(
            'rate_section',
            [
                'label' => esc_html__('Rate Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );  
            $widget->add_control(
                'star_rated',
                [
                    'label'       => esc_html__( 'Star', 'wiseguard' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => [
                        '0'   => '0',
                        '20'  => '1',
                        '40'  => '2',
                        '60'  => '3',
                        '80'  => '4',
                        '100' => '5',
                    ],
                    'default' => '100'
                ]
            );    
            $widget->add_control(
                'percent',
                [
                    'label'       => esc_html__( 'Percentage', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '99.9%',
                    'placeholder' => '99.9%'
                ]
            );
            $widget->add_control(
                'percent_text',
                [
                    'label'       => esc_html__('Percentage Text', 'wiseguard'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Customer Satisfaction',
                    'placeholder' => 'Customer Satisfaction'
                ]
            );
            $widget->add_control(
                'percent_text2',
                [
                    'label'   => esc_html__('Other Text', 'wiseguard'),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => 'based on 750+ reviews of 6,154 Completed Projects, and 2,194 Happy Customers trust us.'
                ]
            );
        $widget->end_controls_section();
        // Banner
        $widget->start_controls_section(
            'banner_section',
            [
                'label' => esc_html__('Banner', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );  
            $widget->add_control(
                'banner',
                [
                    'label'   => esc_html__( 'Banner', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ]
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'banner',
                    'label'   => esc_html__('Banner Size','wiseguard'),
                    'default' => 'custom',
                    'condition' => [
                        'banner[url]!' => ''
                    ]
                ]
            );
        $widget->end_controls_section();
        // Content
        $widget->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );  
            $widget->add_control(
                'phone',
                [
                    'label'   => esc_html__( 'Phone Number', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::TEXT,
                    'default' => '+2 01161145741'
                ]
            );
            $widget->add_control(
                'avatar',
                [
                    'label'   => esc_html__( 'Avatar', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ]
                ]
            );
            $widget->add_control(
                'text',
                [
                    'label'   => esc_html__( 'Text', 'wiseguard' ),
                    'type'    => \Elementor\Controls_Manager::TEXT,
                    'default' => 'Reliable and trusted services to meet all your waste requirements, feel free to request a free quote today!!'
                ]
            );
            $widget->add_control(
                'link_text',
                [
                    'label'       => esc_html__( 'Link Settings', 'wiseguard' ),
                    'description' => esc_html__('Link Text', 'wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__( 'Click here', 'wiseguard' ),
                    'placeholder' => esc_html__( 'Click here', 'wiseguard' ),
                    'label_block' => true,
                    'separator'   => 'before'
                ]
            );
            $widget->add_control(
                'link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'page_link',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link_text!' => '',
                        'link_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'custom_link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link_text!' => '',
                        'link_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();

        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'star_color',
                'label'    => esc_html__( 'Star Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-star-rate' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'star_rated_color',
                'label'    => esc_html__( 'Star Rated Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-star-rated' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'text_color',
                'label'    => esc_html__( 'Text Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-text' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
    }
}
