<?php
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;

if (!function_exists('wiseguard_widget_cms_tabs_register_controls')) {
    add_action('etc_widget_cms_tabs_register_controls', 'wiseguard_widget_cms_tabs_register_controls', 10, 1);
    function wiseguard_widget_cms_tabs_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '4',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_tabs/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_tabs/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_tabs/layout/3.jpg'
                        ],
                        '4' => [
                            'label' => esc_html__( 'Layout 4', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_tabs/layout/4.jpg'
                        ]
                    ]
                ]
            );
        $widget->end_controls_section();
        // Heading
        $widget->start_controls_section(
            'section_heading',
            [
                'label' => esc_html__('Heading Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition'   => [
                    'layout'  => ['2']  
                ]
            ]
        );
            $widget->add_control(
                'smallheading_text',
                [
                    'label'       => esc_html__( 'Small Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is small heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'separator'   => 'after'
                ]
            );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true
                ]
            );
            $widget->add_control(
                'description_text',
                [
                    'label'       => esc_html__( 'Description', 'wiseguard' ),
                    'type'        => \Elementor\Controls_Manager::TEXTAREA,
                    'default'     => 'Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text ever since', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before'
                ]
            );
        $widget->end_controls_section();
        // Tablet Content
        $widget->start_controls_section(
            'section_content',
            [
                'label' => esc_html__('Tab Contents', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
            $widget->add_control(
                'active_tab',
                [
                    'label'     => esc_html__( 'Active Tab', 'wiseguard' ),
                    'type'      => Controls_Manager::NUMBER,
                    'default'   => 1,
                    'min'       => 0,
                    'max'       => 50,
                    'separator' => 'after',
                ]
            );
            $repeater = new Repeater();
            $repeater->add_control(
                'tab_title',
                [
                    'label'       => esc_html__( 'Tab Title', 'wiseguard' ),
                    'default'     => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                ]
            );
            // Tab Content
            $repeater->add_control(
                'tab_content_title',
                [
                    'label'       => esc_html__( 'Content Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Enter Your Title',
                    'label_block' => true,
                    'condition'   => [
                        'tab_title!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'tab_content_desc',
                [
                    'label'       => esc_html__( 'Content Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Enter your Description. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text',
                    'label_block' => true,
                    'condition'   => [
                        'tab_title!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'tab_content_icon',
                [
                    'label'       => esc_html__( 'Content Icon', 'wiseguard' ),
                    'type'        => Controls_Manager::ICONS,
                    'skin'        => 'inline',
                    'label_block' => false,
                    'condition'   => [
                        'tab_title!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'tab_content_link',
                [
                    'label'     => esc_html__( 'Choose Page', 'wiseguard' ),
                    'type'      => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'    => false,
                    'label_block' => true,
                    'condition'   => [
                        'tab_title!' => ''
                    ]
                ]
            );
            $repeater->add_control(
                'tab_content_link_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Explore More',
                    'label_block' => true,
                    'condition' => [
                        'tab_title!' => '',
                        'tab_content_link!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'cms_tabs',
                [
                    'label'   => esc_html__('Contents', 'wiseguard'),
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => $repeater->get_controls(),
                    'default' => [
                        [
                            'tab_title'         => 'Your Tabs #1',
                            'tab_content_title' => 'Your Title #1',
                            'tab_content_desc'  => 'Your Description. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text'
                        ],
                        [
                            'tab_title'         => 'Your Tabs #2',
                            'tab_content_title' => 'Your Title #2',
                            'tab_content_desc'  => 'Your Description. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text',
                        ]
                    ],
                    'title_field' => '{{{ tab_title }}}',
                    'condition' => [
                        'layout' => ['1']
                    ]
                ]
            );
            // Layout 2
            $repeater2 = new Repeater();
            $repeater2->add_control(
                'tab_title',
                [
                    'label'       => esc_html__( 'Tab Title', 'wiseguard' ),
                    'default'     => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                ]
            );
            // Tab Content
            $repeater2->add_control(
                'tab_content_banner',
                [
                    'label'       => esc_html__( 'Content Banner', 'wiseguard' ),
                    'type'        => Controls_Manager::MEDIA,
                    'default'     => [
                        'url' => Utils::get_placeholder_image_src()
                    ],
                    'label_block' => true,
                    'condition'   => [
                        'tab_title!' => ''
                    ]
                ]
            );
            $repeater2->add_control(
                'tab_content_icon',
                [
                    'label'       => esc_html__( 'Banner Icon', 'wiseguard' ),
                    'type'        => Controls_Manager::ICONS,
                    'skin'        => 'inline',
                    'label_block' => false,
                    'condition'   => [
                        'tab_title!' => ''
                    ],
                    'default' => [
                        'library' => 'wiseguard-icon',
                        'value'   => 'wiseguard-icon-default'  
                    ]
                ]
            );
            $repeater2->add_control(
                'tab_content_title',
                [
                    'label'       => esc_html__( 'Banner Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Enter Your Title',
                    'label_block' => true,
                    'condition'   => [
                        'tab_title!' => ''
                    ]
                ]
            );
            $repeater2->add_control(
                'tab_content_desc',
                [
                    'label'       => esc_html__( 'Content Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Enter your Description. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text',
                    'label_block' => true,
                    'condition'   => [
                        'tab_title!' => ''
                    ]
                ]
            );
            
            $widget->add_control(
                'cms_tabs2',
                [
                    'label'   => esc_html__('Contents', 'wiseguard'),
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => $repeater2->get_controls(),
                    'default' => [
                        [
                            'tab_title'         => 'Your Tabs #1',
                            'tab_content_title' => 'Your Title #1',
                            'tab_content_desc'  => 'Your Description. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text'
                        ],
                        [
                            'tab_title'         => 'Your Tabs #2',
                            'tab_content_title' => 'Your Title #2',
                            'tab_content_desc'  => 'Your Description. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text',
                        ]
                    ],
                    'title_field' => '{{{ tab_title }}}',
                    'condition' => [
                        'layout' => ['2','3']
                    ]
                ]
            );
            // Layout 4
            $cms_tabs4 = new Repeater();
            $cms_tabs4->add_control(
                'tab_title',
                [
                    'label'       => esc_html__( 'Tab Title', 'wiseguard' ),
                    'default'     => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                ]
            );
            // Tab Content
            $cms_tabs4->add_control(
                'tab_content_banner',
                [
                    'label'       => esc_html__( 'Banner', 'wiseguard' ),
                    'type'        => Controls_Manager::MEDIA,
                    'default'     => [
                        'url' => Utils::get_placeholder_image_src()
                    ],
                    'label_block' => true,
                    'condition'   => [
                        'tab_title!' => ''
                    ]
                ]
            );
            $cms_tabs4->add_control(
                'tab_content_icon',
                [
                    'label'       => esc_html__( 'Banner Icon', 'wiseguard' ),
                    'type'        => Controls_Manager::ICONS,
                    'skin'        => 'inline',
                    'label_block' => false,
                    'condition'   => [
                        'tab_title!' => ''
                    ],
                    'default' => [
                        'library' => 'wiseguard-icon',
                        'value'   => 'wiseguard-icon-default'  
                    ]
                ]
            );
            $cms_tabs4->add_control(
                'tab_content_title',
                [
                    'label'       => esc_html__( 'Title', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Enter Your Title',
                    'label_block' => true,
                    'condition'   => [
                        'tab_title!' => ''
                    ]
                ]
            );
            $cms_tabs4->add_control(
                'tab_content_desc',
                [
                    'label'       => esc_html__( 'Content Description', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Enter your Description. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text',
                    'label_block' => true,
                    'condition'   => [
                        'tab_title!' => ''
                    ]
                ]
            );
            $cms_tabs4->add_control(
                'btn_text',
                [
                    'label'       => esc_html__('Button', 'wiseguard'),
                    'description' => esc_html__('Button Text','wiseguard'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '',  
                    'label_block' => true
                ]
            );
            $cms_tabs4->add_control(
                'btn_link_type',
                [
                    'label'   => esc_html__('Button Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'btn_text!'     => ''
                    ]
                ]
            );
            $cms_tabs4->add_control(
                'btn_page_link',
                [
                    'label'     => esc_html__('Select Page', 'wiseguard'),
                    'type'      => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'btn_text!'     => '',
                        'btn_link_type' => 'page'
                    ]
                ]
            );
            $cms_tabs4->add_control(
                'btn_link',
                [
                    'label'     => esc_html__('Button Link', 'wiseguard'),
                    'type'      => Controls_Manager::URL,
                    'condition' => [
                        'btn_text!'     => '',
                        'btn_link_type' => 'custom'
                    ]
                ]
            );
            $widget->add_control(
                'cms_tabs4',
                [
                    'label'   => esc_html__('Contents', 'wiseguard'),
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => $cms_tabs4->get_controls(),
                    'default' => [
                        [
                            'tab_title'         => 'Your Tabs #1',
                            'tab_content_title' => 'Your Title #1',
                            'tab_content_desc'  => 'Your Description. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text'
                        ],
                        [
                            'tab_title'         => 'Your Tabs #2',
                            'tab_content_title' => 'Your Title #2',
                            'tab_content_desc'  => 'Your Description. Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text',
                        ]
                    ],
                    'title_field' => '{{{ tab_title }}}',
                    'condition' => [
                        'layout' => ['4']
                    ]
                ]
            );
        $widget->end_controls_section();
        // Rating
        $widget->start_controls_section(
            'rate_section',
            [
                'label' => esc_html__('Rate Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['3']
                ]
            ]
        );  
            $widget->add_control(
                'star_rated',
                [
                    'label'       => esc_html__( 'Star', 'wiseguard' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => [
                        '0'   => '0',
                        '20'  => '1',
                        '40'  => '2',
                        '60'  => '3',
                        '80'  => '4',
                        '100' => '5',
                    ],
                    'default' => '100'
                ]
            );    
            $widget->add_control(
                'percent',
                [
                    'label'       => esc_html__( 'Percentage', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '99.9%',
                    'placeholder' => '99.9%'
                ]
            );
            $widget->add_control(
                'percent_text',
                [
                    'label'       => esc_html__('Percentage Text', 'wiseguard'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Customer Satisfaction',
                    'placeholder' => 'Customer Satisfaction'
                ]
            );
            $widget->add_control(
                'percent_text2',
                [
                    'label'   => esc_html__('Other Text', 'wiseguard'),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => 'based on 750+ reviews of 6,154 Completed Projects, and 2,194 Happy Customers trust us.'
                ]
            );
        $widget->end_controls_section();
        // Button Section Start
        $widget->start_controls_section(
            'button_section',
            [
                'label' => esc_html__('Button Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['3']
                ]
            ]
        );         
            $widget->add_control(
                'text',
                [
                    'label'       => esc_html__( 'Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__( 'Click here', 'wiseguard' ),
                    'placeholder' => esc_html__( 'Click here', 'wiseguard' )
                ]
            );
            $widget->add_control(
                'link_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom'
                ]
            );
            $widget->add_control(
                'page_link',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link',
                [
                    'label'       => esc_html__( 'Link', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link_type' => 'custom'
                    ]
                ]
            );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'btn_color',
                'label'    => esc_html__( 'Button Color', 'wiseguard' ),
                'custom'   => false 
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'btn_hover_color',
                'label'    => esc_html__( 'Button Hover Color', 'wiseguard' ),
                'custom'   => false 
            ]);
        $widget->end_controls_section();
        // Tab title style
        $widget->start_controls_section(
            'section_style_tab',
            [
                'label' => esc_html__('Tab Style', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'title_color',
                'label'    => esc_html__( 'Title Color', 'wiseguard' ),
                'custom'   => false
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'desc_color',
                'label'    => esc_html__( 'Description Color', 'wiseguard' ),
                'custom'   => false
            ]);
        $widget->end_controls_section();
        // Rate Style
        $widget->start_controls_section(
            'section_style_rate',
            [
                'label' => esc_html__('Rate Style', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'star_color',
                'label'    => esc_html__( 'Star Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-star-rate' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'star_rated_color',
                'label'    => esc_html__( 'Star Rated Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-star-rated' => 'color: {{VALUE}};',
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'rate_text_color',
                'label'    => esc_html__( 'Text Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-text' => 'color: {{VALUE}};',
                ]
            ]);
        $widget->end_controls_section();
    }
}
