<?php
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Repeater;
use Elementor\Group_Control_Image_Size;

if (!function_exists('wiseguard_widget_cms_teams_register_controls')) {
    add_action('etc_widget_cms_teams_register_controls', 'wiseguard_widget_cms_teams_register_controls', 10, 1);
    function wiseguard_widget_cms_teams_register_controls($widget)
    {
        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout_mode',
            [
                'label' => esc_html__( 'Layout Mode', 'wiseguard' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'carousel' => esc_html__( 'Carousel', 'wiseguard' ),
                    //'grid' => esc_html__( 'Grid', 'wiseguard' ),
                ],
                'default' => 'carousel',
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'wiseguard' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_teams/layout/1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_teams/layout/2.jpg'
                    ],
                ]
            ]
        );

        $widget->end_controls_section();
        // Layout Tab End

        // Content Tab Start
        // List Section Start
        $widget->start_controls_section(
            'list_section',
            [
                'label' => esc_html__('List', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'label'   => esc_html__('Image', 'wiseguard'),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $repeater->add_control(
            'name',
            [
                'label'   => esc_html__('Name', 'wiseguard'),
                'type'    => Controls_Manager::TEXT,
                'default' => esc_html__('Name', 'wiseguard'),
            ]
        );

        $repeater->add_control(
            'position',
            [
                'label'   => esc_html__('Position', 'wiseguard'),
                'type'    => Controls_Manager::TEXT,
                'default' => esc_html__('Position', 'wiseguard'),
            ]
        );

        $repeater->add_control(
            'description',
            [
                'label'       => esc_html__('Description', 'wiseguard'),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => '',
                'label_block' => true,
                'class'       => 'fuckc cccc',  
                'label_class'       => 'fuckc cccc'  
            ]
        );

        $repeater->add_control(
            'link',
            [
                'label'       => esc_html__( 'Link', 'wiseguard' ),
                'type'        => Controls_Manager::URL,
                'default' => [
                    'url' => '',
                    'is_external' => true,
                    'nofollow' => true,
                ],
                'separator' => 'after',
            ]
        );

        for ($i = 1; $i <= 4; $i++) {
            $args = [
                'label'       => esc_html__( "Social Icon", 'wiseguard' ), //{$i}
                'type'        => Controls_Manager::ICONS,
                'skin'        => 'inline',
                'label_block' => false,
            ];
            $args_link = [
                'label'       => esc_html__( "Social Link", 'wiseguard' ), //{$i}
                'type'        => \Elementor\Controls_Manager::URL,
                'placeholder' => 'https://your-link.com',
                'options'     => [ 'url', 'is_external', 'nofollow' ],
                'separator' => 'after',
            ];
            if($i == 1){
                $args['default'] = [
                    'value'   => 'cmsi-facebook',
                    'library' => 'cmsi',
                ];
                $args_link['default'] = [
                    'url'         => 'https://www.facebook.com/cmssuperheroes',
                    'is_external' => true,
                    'nofollow'    => true,
                ];
            }
            elseif($i == 2){
                $args['default'] = [
                    'value'   => 'cmsi-twitter-circle',
                    'library' => 'cmsi',
                ];
                $args_link['default'] = [
                    'url'         => 'https://www.facebook.com/cmssuperheroes',
                    'is_external' => true,
                    'nofollow'    => true,
                ];
            }
            elseif($i == 3){
                $args['default'] = [
                    'value'   => 'cmsi-instagram',
                    'library' => 'cmsi',
                ];
                $args_link['default'] = [
                    'url'         => 'https://www.facebook.com/cmssuperheroes',
                    'is_external' => true,
                    'nofollow'    => true,
                ];
            }
            elseif($i == 4){
                $args['default'] = [
                    'value'   => 'cmsi-linkedin-circle',
                    'library' => 'cmsi',
                ];
                $args_link['default'] = [
                    'url'         => 'https://www.facebook.com/cmssuperheroes',
                    'is_external' => true,
                    'nofollow'    => true,
                ];
            }
            $repeater->add_control(
                "social_icon_{$i}",
                $args
            );

            $repeater->add_control(
                "social_link_{$i}",
                $args_link
            );
        }

        $widget->add_control(
            'teams',
            [
                'label' => esc_html__('Teams', 'wiseguard'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Name', 'wiseguard'),
                        'position' => esc_html__('Position', 'wiseguard'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Name', 'wiseguard'),
                        'position' => esc_html__('Position', 'wiseguard'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                        'name' => esc_html__('Name', 'wiseguard'),
                        'position' => esc_html__('Position', 'wiseguard'),
                        'link' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                    ],
                ],
                'title_field' => '{{{ name }}}',
            ]
        );
        $widget->end_controls_section();
        // List Section End
        // Image
        $widget->start_controls_section(
            'image_section',
            [
                'label' => esc_html__('Image Settings', 'wiseguard'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'image',
                    'label'   => esc_html__('Image Size','wiseguard'),
                    'default' => 'custom'
                ]
            );
        $widget->end_controls_section();
        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel Settings', 'wiseguard'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $slides_to_show = range(1, 10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label' => esc_html__('Slides to Show', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                    ] + $slides_to_show,
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label' => esc_html__('Slides to Scroll', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'wiseguard'),
                'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'wiseguard'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 40,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrows',
            [
                'label' => esc_html__('Show Arrows', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );
        $widget->add_control(
            'dots',
            [
                'label' => esc_html__('Show Dots', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'lazyload',
            [
                'label' => esc_html__('Lazyload', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label' => esc_html__('Pause on Hover', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label' => esc_html__('Pause on Interaction', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
                'condition' => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'wiseguard'),
                'type' => Controls_Manager::NUMBER,
                'default' => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label' => esc_html__('Infinite Loop', 'wiseguard'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label' => esc_html__('Effect', 'wiseguard'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'wiseguard'),
                    'fade' => esc_html__('Fade', 'wiseguard'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label' => esc_html__('Animation Speed', 'wiseguard'),
                'type' => Controls_Manager::NUMBER,
                'default' => 500,
                'render_type' => 'none',
                'frontend_available' => true,
            ]
        );

        $widget->end_controls_section();
        // Carousel Section End
        // Custom layout
        $widget->start_controls_section(
            'content_width_section',
            [
                'label'      => esc_html__('Custom Styles', 'wiseguard'),
                'tab'        => Controls_Manager::TAB_SETTINGS,
            ]
        );
            $widget->add_control(
                'content_width',
                [
                    'label'     => esc_html__('Content Width', 'wiseguard'),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        ''            => esc_html__('Default', 'wiseguard'),
                        'start'       => esc_html__('Full to Start', 'wiseguard'),
                        'end'         => esc_html__('Full to End', 'wiseguard'),
                        'start-large' => esc_html__('Full to Start (Large)', 'wiseguard'),
                        'end-large'   => esc_html__('Full to End (Large)', 'wiseguard')
                    ],
                    'prefix_class' => 'cms-swiper-full-'
                ]
            );
            $widget->add_control(
                'item_shadow',
                [
                    'label'     => esc_html__('Item Shadow?', 'wiseguard'),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'yes' => esc_html__('Yes', 'wiseguard'),
                        'no'   => esc_html__('No', 'wiseguard')
                    ],
                    'default' => 'no',
                    'dynamic' => [
                        'active' => true
                    ],
                    'style_transfer' => true,
                    'prefix_class' => 'cms-carousel-item-shadow-',

                ]
            );
        $widget->end_controls_section();
        // Content Tab End
    }
}