<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_testimonials_register_controls')) {
    add_action('etc_widget_cms_testimonials_register_controls', 'wiseguard_widget_cms_testimonials_register_controls', 10, 1);
    function wiseguard_widget_cms_testimonials_register_controls($widget)
    {
        // Layout Tab Start
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab' => Controls_Manager::TAB_LAYOUT,
            ]
        );
        $widget->add_control(
            'layout_mode',
            [
                'label'   => esc_html__( 'Layout Mode', 'wiseguard' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'grid'     => esc_html__('Grid','wiseguard'),
                    'carousel' => esc_html__('Carousel', 'wiseguard')
                ],
                'default'   => 'carousel',
                'condition' => [
                    'layout' => ['1']
                ]
            ]
        );
        $widget->add_control(
            'layout',
            [
                'label'   => esc_html__( 'Templates', 'wiseguard' ),
                'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                'default' => '1',
                'options' => [
                    '1' => [
                        'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_testimonials/layout/1.jpg'
                    ],
                    '2' => [
                        'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_testimonials/layout/2.jpg'
                    ],
                    '3' => [
                        'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_testimonials/layout/3.jpg'
                    ],
                    '4' => [
                        'label' => esc_html__( 'Layout 4', 'wiseguard' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_testimonials/layout/4.jpg'
                    ],
                    '5' => [
                        'label' => esc_html__( 'Layout 5', 'wiseguard' ),
                        'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_testimonials/layout/5.jpg'
                    ]
                ]
            ]
        );

        $widget->end_controls_section();
        // Layout Tab End

        // Content Tab Start
        // List Section Start
        $widget->start_controls_section(
            'list_section',
            [
                'label' => esc_html__('List', 'wiseguard'),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
            $repeater = new Repeater();

            $repeater->add_control(
                'image',
                [
                    'label' => esc_html__('Avatar', 'wiseguard'),
                    'type' => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                ]
            );

            $repeater->add_control(
                'name',
                [
                    'label' => esc_html__('Name', 'wiseguard'),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Testimonial Name', 'wiseguard'),
                ]
            );

            $repeater->add_control(
                'position',
                [
                    'label' => esc_html__('Position', 'wiseguard'),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Testimonial Position', 'wiseguard'),
                ]
            );
            $repeater->add_control(
                'star_rated',
                [
                    'label'       => esc_html__( 'Star', 'wiseguard' ),
                    'type'        => Controls_Manager::SELECT,
                    'options'     => [
                        '0'   => '0',
                        '20'  => '1',
                        '40'  => '2',
                        '60'  => '3',
                        '80'  => '4',
                        '100' => '5',
                    ],
                    'default' => '100'
                ]
            );
            $repeater->add_control(
                'description',
                [
                    'label' => esc_html__('Description', 'wiseguard'),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('Testimonial Description', 'wiseguard'),
                ]
            );

            $widget->add_control(
                'testimonials',
                [
                    'label' => esc_html__('Testimonials', 'wiseguard'),
                    'type' => \Elementor\Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                    'default' => [
                        [
                            'image' => [
                                'url' => Utils::get_placeholder_image_src(),
                            ],
                            'name'        => esc_html__('Testimonial Name', 'wiseguard'),
                            'position'    => esc_html__('Testimonial Position', 'wiseguard'),
                            'star_rated'  => '100',
                            'description' => esc_html__('#1 Testimonial Description. It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'wiseguard'),
                        ],
                        [
                            'image' => [
                                'url' => Utils::get_placeholder_image_src(),
                            ],
                            'name'        => esc_html__('Testimonial Name #2', 'wiseguard'),
                            'position'    => esc_html__('Testimonial Position #2', 'wiseguard'),
                            'star_rated'  => '100',
                            'description' => esc_html__('#2 Testimonial Description. It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'wiseguard'),
                        ],
                        [
                            'image' => [
                                'url' => Utils::get_placeholder_image_src(),
                            ],
                            'name'        => esc_html__('Testimonial Name #3', 'wiseguard'),
                            'position'    => esc_html__('Testimonial Position #3', 'wiseguard'),
                            'star_rated'  => '100',
                            'description' => esc_html__('#3 Testimonial Description. It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout.', 'wiseguard'),
                        ],
                    ],
                    'title_field' => '{{{ name }}}',
                ]
            );
            $widget->add_control(
                'avatar_size_setting',
                [
                    'name'      => 'avatar_size_heading',
                    'label'     => esc_html__('Avatar Settings','wiseguard'),
                    'type'      => Controls_Manager::HEADING,
                    'separator' => 'before'
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'      => 'image',
                    'default'   => 'custom'
                ]
            );
        $widget->end_controls_section();
        // Background
        $widget->start_controls_section(
            'background_section',
            [
                'label'     => esc_html__('Background', 'wiseguard'),
                'tab'       => Controls_Manager::TAB_SETTINGS,
                'condition' => [
                    'layout' => ['-x']
                ]
            ]
        );
            $widget->add_control(
                'bg_image',
                [
                    'label' => esc_html__('Background Image', 'wiseguard'),
                    'type' => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ],
                ]
            );
            $widget->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name'    => 'bg_image',
                    'default' => 'custom',
                ]
            );
            $widget->add_control(
                'bg_gradient',
                [
                    'label' =>  esc_html__('Background Gradient','wiseguard'),
                    'type'  => Controls_Manager::SELECT,
                    'options' => array(
                        ''  => esc_html__( 'Default', 'wiseguard' ),
                        '1' => esc_html__( 'Primary - Top to Bottom', 'wiseguard' ),
                        '2' => esc_html__( 'Secondary - Top to Bottom', 'wiseguard' ),
                        '3' => esc_html__( 'Primary - Bottom to Top', 'wiseguard' ),
                        '4' => esc_html__( 'Secondary - Bottom to Top', 'wiseguard' ),
                        '5' => esc_html__( 'Secondary - Bottom to Top #2', 'wiseguard' ),
                        '6' => esc_html__( 'Primary - Bottom to Top #2', 'wiseguard' ),
                        '7' => esc_html__( 'Gray - Bottom to Top', 'wiseguard' ),
                        '8' => esc_html__( 'Secondary - Bottom to Top #3', 'wiseguard' ),
                        '9' => esc_html__( 'Secondary - Bottom to Top #4', 'wiseguard' ),
                    )
                ]
            );
        $widget->end_controls_section();
        // Carousel Section Start
        $widget->start_controls_section(
            'carousel_section',
            [
                'label' => esc_html__('Carousel', 'wiseguard'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $widget->add_control(
            'content_width',
            [
                'label'     => esc_html__('Content Width', 'wiseguard'),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    ''            => esc_html__('Default', 'wiseguard'),
                    'start'       => esc_html__('Full to Start', 'wiseguard'),
                    'end'         => esc_html__('Full to End', 'wiseguard'),
                    'start-large' => esc_html__('Full to Start (Large)', 'wiseguard'),
                    'end-large'   => esc_html__('Full to End (Large)', 'wiseguard')
                ],
                'prefix_class' => 'cms-swiper-full-'
            ]
        );
        $widget->add_control(
            'item_shadow',
            [
                'label'     => esc_html__('Item Shadow?', 'wiseguard'),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'yes' => esc_html__('Yes', 'wiseguard'),
                    'no'   => esc_html__('No', 'wiseguard')
                ],
                'default' => 'no',
                'dynamic' => [
                    'active' => true
                ],
                'style_transfer' => true,
                'prefix_class'   => 'cms-carousel-item-shadow-',
                'separator'      => 'after'
            ]
        );

        $slides_to_show = range(1, 10);
        $slides_to_show = array_combine($slides_to_show, $slides_to_show);
        $widget->add_responsive_control(
            'slides_to_show',
            [
                'label'   => esc_html__('Slides to Show', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                        '' => esc_html__('Default', 'wiseguard'),
                    ] + $slides_to_show,
                'frontend_available' => true,
                'default' => '1'
            ]
        );

        $widget->add_responsive_control(
            'slides_to_scroll',
            [
                'label'       => esc_html__('Slides to Scroll', 'wiseguard'),
                'type'        => Controls_Manager::SELECT,
                'description' => esc_html__('Set how many slides are scrolled per swipe.', 'wiseguard'),
                'options'     => [
                        '' => esc_html__('Default', 'wiseguard'),
                    ] + $slides_to_show,
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
                'default' => '1'
            ]
        );

        $widget->add_responsive_control(
            'space_between',
            [
                'label' => esc_html__('Space Between', 'wiseguard'),
                'type'  => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'size' => 30,
                ],
                'condition' => [
                    'slides_to_show!' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'arrows',
            [
                'label'              => esc_html__('Show Arrows', 'wiseguard'),
                'type'               => Controls_Manager::SWITCHER,
                'default'            => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'dots',
            [
                'label'              => esc_html__('Show Dots', 'wiseguard'),
                'type'               => Controls_Manager::SWITCHER,
                'default'            => 'yes',
                'frontend_available' => true,
            ]
        );

        /*
         * Make bullet dynamic
        
        $widget->add_control(
            'number_of_dots',
            [
                'label'              => esc_html__('Number of Dots', 'wiseguard'),
                'type'               => Controls_Manager::NUMBER,
                'min'                => 1,
                'max'                => 6,
                'default'            => 1,
                'frontend_available' => true,
                'condition'          => [
                    'dots' => 'yes',
                ],
            ]
        );*/
        $widget->add_control(
            'lazyload',
            [
                'label'              => esc_html__('Lazyload', 'wiseguard'),
                'type'               => Controls_Manager::SWITCHER,
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'autoplay',
            [
                'label'   => esc_html__('Autoplay', 'wiseguard'),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'pause_on_hover',
            [
                'label'              => esc_html__('Pause on Hover', 'wiseguard'),
                'type'               => Controls_Manager::SWITCHER,
                'default'            => 'yes',
                'frontend_available' => true,
                'condition'          => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'pause_on_interaction',
            [
                'label'              => esc_html__('Pause on Interaction', 'wiseguard'),
                'type'               => Controls_Manager::SWITCHER,
                'default'            => 'yes',
                'frontend_available' => true,
                'condition'          => [
                    'autoplay' => 'yes',
                ],
            ]
        );

        $widget->add_control(
            'autoplay_speed',
            [
                'label'     => esc_html__('Autoplay Speed', 'wiseguard'),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 5000,
                'condition' => [
                    'autoplay' => 'yes',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'infinite',
            [
                'label'              => esc_html__('Infinite Loop', 'wiseguard'),
                'type'               => Controls_Manager::SWITCHER,
                'default'            => 'yes',
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'effect',
            [
                'label'   => esc_html__('Effect', 'wiseguard'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => [
                    'slide' => esc_html__('Slide', 'wiseguard'),
                    'fade'  => esc_html__('Fade', 'wiseguard'),
                ],
                'condition' => [
                    'slides_to_show' => '1',
                ],
                'frontend_available' => true,
            ]
        );

        $widget->add_control(
            'speed',
            [
                'label'              => esc_html__('Animation Speed', 'wiseguard'),
                'type'               => Controls_Manager::NUMBER,
                'default'            => 500,
                'render_type'        => 'none',
                'frontend_available' => true,
            ]
        );
        $widget->end_controls_section();
        // Style
        $widget->start_controls_section(
            'style_section',
            [
                'label' => esc_html__('Style Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'desc_color',
                'label'    => esc_html__( 'Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-ttmn--text' => 'color: {{VALUE}};'
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'author_color',
                'label'    => esc_html__( 'Author Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-ttmn--name' => 'color: {{VALUE}};'
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'author_pos_color',
                'label'    => esc_html__( 'Position Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-ttmn--pos' => 'color: {{VALUE}};'
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'rate_color',
                'label'    => esc_html__( 'Rate Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-star-rate' => 'color: {{VALUE}};'
                ]
            ]);
            // Arrow color
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'arrows_color',
                'label'     => esc_html__( 'Arrow Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-carousel-button-prev, {{WRAPPER}} .cms-carousel-button-next' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-button-prev svg, {{WRAPPER}} .cms-carousel-button-next svg' => 'fill: {{VALUE}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                ],
                'separator' => 'before'
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'arrows_color_hover',
                'label'     => esc_html__( 'Arrow Color Hover', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-carousel-button-prev:hover, {{WRAPPER}} .cms-carousel-button-next:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .cms-carousel-button-prev:hover svg, {{WRAPPER}} .cms-carousel-button-next:hover svg' => 'fill: {{VALUE}};',
                ],
                'condition' => [
                    'arrows' => 'yes',
                ],
                'separator' => 'after'
            ]);
            // Dots Color

        $widget->end_controls_section();
    }
}
