<?php
use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Utils;
use Elementor\Repeater;

if (!function_exists('wiseguard_widget_cms_video_player_register_controls')) {
    add_action('etc_widget_cms_video_player_register_controls', 'wiseguard_widget_cms_video_player_register_controls', 10, 1);
    function wiseguard_widget_cms_video_player_register_controls($widget)
    {
        // Layout
        $widget->start_controls_section(
            'layout_section',
            [
                'label' => esc_html__('Layout', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_LAYOUT,
            ]
        );
            $widget->add_control(
                'layout',
                [
                    'label'   => esc_html__( 'Templates', 'wiseguard' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label' => esc_html__( 'Layout 1', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_video_player/layout/1.jpg'
                        ],
                        '2' => [
                            'label' => esc_html__( 'Layout 2', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_video_player/layout/2.jpg'
                        ],
                        '3' => [
                            'label' => esc_html__( 'Layout 3', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_video_player/layout/3.jpg'
                        ],
                        '4' => [
                            'label' => esc_html__( 'Layout 4', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_video_player/layout/4.jpg'
                        ],
                        '5' => [
                            'label' => esc_html__( 'Layout 5', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_video_player/layout/5.jpg'
                        ],
                        '6' => [
                            'label' => esc_html__( 'Layout 6', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_video_player/layout/6.jpg'
                        ],
                        '7' => [
                            'label' => esc_html__( 'Layout 7', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_video_player/layout/7.jpg'
                        ],
                        '8' => [
                            'label' => esc_html__( 'Layout 8', 'wiseguard' ),
                            'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_video_player/layout/8.jpg'
                        ],
                    ]
                ]
            );
        $widget->end_controls_section();
        // video_player Section Start
        $widget->start_controls_section(
            'section_video_player',
            [
                'label' => esc_html__('Video Settings', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );
        $widget->add_control(
            'video_link',
            [
                'label'    => esc_html__( 'Video URL', 'wiseguard' ),
                'subtitle' => esc_html__('Video url from  YouTube/Vimeo/Dailymotion','wiseguard'),
                'type'     => Controls_Manager::TEXT,
                'default'  => 'https://www.youtube.com/watch?v=iYf3OgEdGmo',
                'dynamic' => [
                    'active' => true
                ]
            ]
        );
        $widget->add_control(
            'video_icon',
            [
                'label'   => esc_html__( 'Video Icon', 'wiseguard' ),
                'type'    => Controls_Manager::ICONS,
                'skin'    => 'inline',
                'default' => [
                    'library' => 'cmsi',
                    'value'   => 'cmsi-play'
                ],
                'condition' => [
                    'video_link!' => ''
                ],
                'label_block' => false
            ]
        );
        $widget->add_control(
            'video_text',
            [
                'label'    => esc_html__( 'Video Text', 'wiseguard' ),
                'type'     => Controls_Manager::TEXTAREA,
                'default'  => '',
                'condition' => [
                    'video_link!' => ''
                ],
                'label_block' => false
            ]
        );
        $widget->add_control(
            'image',
            [
                'label'   => esc_html__( 'Video Banner', 'wiseguard' ),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src()
                ],
                'skin'  => 'inline',
                'condition' => [
                    'video_link!' => '',
                    'layout!'     => ['1']
                ]
            ]
        );
        $widget->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'    => 'image',
                'label'   => esc_html__('Banner Size','wiseguard'),
                'default' => 'custom',
                'condition' => [
                    'video_link!' => '',
                    'image[url]!' => '',
                    'layout!'     => ['1']
                ]
            ]
        );
        $widget->add_control(
            'banner_bg',
            [
                'label'     => esc_html__( 'Banner Background', 'wiseguard' ),
                'type'      => Controls_Manager::MEDIA,
                'default'   => [],
                'condition' => [
                    'image[url]!' => '',
                    'layout!'     => ['1']
                ],
                'selectors' => [
                    '{{WRAPPER}} .banner-bg' => 'background-image: url("{{URL}}");'
                ]
            ]
        );
        $widget->add_control(
            'banner_bg_position',
            [
                'label'     => esc_html__( 'Banner Background Position', 'wiseguard' ),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    ''             => esc_html__('Default','wiseguard'),
                    'top left'     => esc_html__('Top Left','wiseguard'),
                    'top right'    => esc_html__('Top Right','wiseguard'),
                    'bottom left'  => esc_html__('Bottom Left','wiseguard'),
                    'bottom right' => esc_html__('Bottom Right','wiseguard'),
                ],
                'condition' => [
                    'image[url]!'     => '',
                    'banner_bg[url]!' => '',
                    'layout!'         => ['1']
                ],
                'selectors' => [
                    '{{WRAPPER}} .banner-bg' => 'background-position: {{VALUE}};'
                ]
            ]
        );
        $widget->end_controls_section();
        // Content Tab Start
        $widget->start_controls_section(
            'section_video_content',
            [
                'label' => esc_html__('Content Setting', 'wiseguard'),
                'tab'   => Controls_Manager::TAB_CONTENT
            ]
        );
            $widget->add_control(
                'small_banner',
                [
                    'label'   => esc_html__( 'Small Banner', 'wiseguard' ),
                    'type'    => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src()
                    ],
                    'condition' => [
                        'layout' => ['4']
                    ]
                ]
            );
            $widget->add_control(
                'icon',
                [
                    'label'     => esc_html__( 'Icon', 'wiseguard' ),
                    'type'      => Controls_Manager::ICONS,
                    'default'   => [
                        'library' => 'wiseguard-icon',
                        'value'   => 'wiseguard-icon-default' 
                    ],
                    'condition' => [
                        'layout' => ['4']
                    ]
                ]
            );
            $widget->add_control(
                'smallheading_text',
                [
                    'label'       => esc_html__( 'Small Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the small heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'condition' => [
                        'layout' => ['3']
                    ]
                ]
            );
            $widget->add_control(
                'heading_text',
                [
                    'label'       => esc_html__( 'Heading', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'This is the heading',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'label_block' => true,
                    'condition' => [
                        'layout' => ['3','4','5','6','7']
                    ]
                ]
            );
            $widget->add_control(
                'description_text1',
                [
                    'label'       => esc_html__( 'Description #1', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry standard dummy text ever since', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before',
                    'condition' => [
                        'layout' => ['6']
                    ]
                ]
            );
            $widget->add_control(
                'description_text2',
                [
                    'label'       => esc_html__( 'Description #2', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => 'There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour', 
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'rows'        => 10,
                    'show_label'  => true,
                    'separator' => 'before',
                    'condition' => [
                        'layout' => ['6']
                    ]
                ]
            );
        $widget->end_controls_section();
        // Buttons
        // Link 1
        $widget->start_controls_section('link1_section',[
            'label' => esc_html__('Link #1', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['3','7']
            ]
        ]);
            $widget->add_control(
                'link1_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Get Started Now',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'separator'   => 'before'
                ]
            );
            $widget->add_control(
                'link1_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link1_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link1_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link1_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link1_text!' => '',
                        'link1_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
        // Link 2
        $widget->start_controls_section('link2_section',[
            'label' => esc_html__('Link #2', 'wiseguard'),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['3']
            ]
        ]);
            $widget->add_control(
                'link2_text',
                [
                    'label'       => esc_html__( 'Link Text', 'wiseguard' ),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => 'Contact Us',
                    'placeholder' => esc_html__( 'Enter your text', 'wiseguard' ),
                    'separator'   => 'before'
                ]
            );
            $widget->add_control(
                'link2_type',
                [
                    'label'   => esc_html__('Link Type', 'wiseguard'),
                    'type'    => Controls_Manager::SELECT,
                    'options' => [
                        'custom' => esc_html__('Custom', 'wiseguard'),
                        'page'   => esc_html__('Page', 'wiseguard'),
                    ],
                    'default' => 'custom',
                    'condition' => [
                        'link2_text!' => ''
                    ]
                ]
            );
            $widget->add_control(
                'link2_page',
                [
                    'label'   => esc_html__('Select Page', 'wiseguard'),
                    'type'    => Elementor_Theme_Core::POSTS_CONTROL,
                    'post_type' => [
                        'page'
                    ],
                    'multiple'  => false,
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'page'
                    ]
                ]
            );
            $widget->add_control(
                'link2_custom',
                [
                    'label'       => esc_html__( 'Link Custom', 'wiseguard' ),
                    'type'        => Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'wiseguard' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => [
                        'link2_text!' => '',
                        'link2_type' => 'custom'
                    ]
                ]
            );
        $widget->end_controls_section();
        // Feature Settings
        $widget->start_controls_section(
            'section_feature',
            [
                'label'     => esc_html__('Features Settings','wiseguard'),
                'tab'       => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => ['2']
                ]
            ]
        );
            $features = new Repeater();
            $features->add_control(
                'icon',
                [
                    'label' => esc_html__('Icon','wiseguard'),
                    'type'  => Controls_Manager::ICONS,
                    'default' => [
                        'library' => 'wiseguard-icon',
                        'value'   => 'wiseguard-icon-default' 
                    ]
                ]
            );
            $features->add_control(
                'title',
                [
                    'label'   => esc_html__('Title','wiseguard'),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => 'Your Title'
                ]
            );
            $widget->add_control(
                'features',
                [
                    'label' => esc_html__('Features List', 'wiseguard'),
                    'type'  => Controls_Manager::REPEATER,
                    'fields' => $features->get_controls(),
                    'default' => [
                        [
                            'icon' => [
                                'value'   => 'wiseguard-icon-garbage-10',
                                'library' => 'wiseguard-icon'
                            ],
                            'title' => 'Great Service & Low Cost'
                        ],
                        [
                            'icon' => [
                                'value'   => 'wiseguard-icon-plastic-2',
                                'library' => 'wiseguard-icon'
                            ],
                            'title' => 'Carbon Trust Certified'
                        ],
                        [
                            'icon' => [
                                'value'   => 'wiseguard-icon-clean',
                                'library' => 'wiseguard-icon'
                            ],
                            'title' => 'Trusted & Local Experts'
                        ]
                    ],
                    'title_field' => '{{title}}'
                ]
            );
        $widget->end_controls_section();
        // Style Tab
        $widget->start_controls_section(
            'section_style',
            [
                'label' => esc_html__('Style Settings','wiseguard'),
                'tab'   => Controls_Manager::TAB_STYLE
            ]
        );
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'smallheading_color',
                'label'    => esc_html__( 'Small Heading Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-smallheading' => 'color: {{VALUE}};',
                ],
                'condition' => [
                    'layout' => ['3']
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'heading_color',
                'label'    => esc_html__( 'Heading Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-heading' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition' => [
                    'layout' => ['3', '4']
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'desc_color',
                'label'    => esc_html__( 'Description Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-desc' => 'color: {{VALUE}};',
                ],
                'separator' => 'before',
                'condition' => [
                    'layout' => ['4']
                ]
            ]);
            wiseguard_elementor_colors_opts($widget,[
                'name'     => 'video_text_color',
                'label'    => esc_html__( 'Video Text Color', 'wiseguard' ),
                'selector' => [
                    '{{WRAPPER}} .cms-text' => 'color: {{VALUE}};',
                ],
                'separator' => 'before'
            ]);
        $widget->end_controls_section();
    }
}
