<?php
// Sources
$source    = $widget->get_setting('source',[]);
$orderby   = $widget->get_setting('orderby','date');
$order     = $widget->get_setting('order','desc');
$limit     = $widget->get_setting('limit', 5);

$tax = [];
foreach ($source as $category){
    $category_arr = explode('|', $category);
    $tax[] = $category_arr[0];
}
// Main Post Query
$main_posts = etc_get_posts_of_grid('post', [
    'post_type'                  => 'post',   
    'source'                     => $source,
    'orderby'                    => $orderby,
    'order'                      => $order,
    'limit'                      => '1',
    'tax'                        => $tax
]);
// Second Post Query
$second_posts = etc_get_posts_of_grid('post', 
    [
        'post_type' => 'post',   
        'source'    => $source,
        'orderby'   => $orderby,
        'order'     => $order,
        'limit'     => $limit - 1,
        'tax'       => $tax
    ], 
    [] , 
    [
        'offset'    => 1
    ]
);

// Wrap
$widget->add_render_attribute('wrap', [
    'class' => [
        'cms-eblog cms-eblog-'.$widget->get_setting('layout'),
        'd-flex gutter gutter-grid'
    ]
]);

// Heading
$widget->add_inline_editing_attributes( 'heading_text', 'none' );
$widget->add_render_attribute( 'heading_text', [
    'class' => [
        'cms-heading empty-none',
        'flex-basic'
    ]
]);
//Button
$page_link = $widget->get_setting('page_link','');
switch ($settings['link_type']) {
    case 'page':
        $page = !empty($page_link) ? get_page_by_path($page_link, OBJECT) : [];
        $url  = !empty($page) ? get_permalink($page->ID) : '#';
        break;
    
    default:
        $url = $widget->get_setting('link', ['url' => '#'])['url'];
        break;
}
$widget->add_inline_editing_attributes( 'btn_text' );
$widget->add_render_attribute( 'btn_text', [
    'class' => array_filter([
        'cms-link',
        'text-secondary',
        'flex-auto flex-smobile-full'
    ]),
    'href'  => $url
]);
?>
<div class="d-flex gap-20 pb-50">
    <h2 <?php etc_print_html( $widget->get_render_attribute_string( 'heading_text' ) ); ?>><?php echo nl2br( $settings['heading_text'] ); ?></h2>
    <a <?php etc_print_html( $widget->get_render_attribute_string( 'btn_text' ) ); ?>>
        <?php 
            // text
            echo esc_html( $settings['btn_text'] );
        ?>
        <i class="cmsi-arrow-right text-10 rtl-flip"></i>
    </a>
</div>
<div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
    <div class="cms-main-posts col-6 col-tablet-7 col-mobile-extra-12">
        <div class="cms-sticky">
            <?php // Content
                foreach ($main_posts['posts'] as $post):
                    wiseguard_elementor_post_thumbnail_render($settings, [
                        'post_id'       => $post->ID,
                        'custom_size'   => ['width' => 620, 'height' => 358],
                        'img_class'     => 'img-cover',
                        'as_background' => false,
                        'max_height'    => true,
                        'before'        => '',
                        'after'         => ''
                    ]);
                ?>
                <div class="cms--content bg-white pt-40 pl-40 pl-smobile-20 ml-40 mt-n40 relative">
                    <div class="cms-post-meta d-flex gap-20">
                        <div class="meta-item category"><?php wiseguard_the_terms($post->ID, 'category', ', ', 'text-white text-hover-primary'); ?></div>
                        <div class="meta-item date"><?php echo get_the_date('', $post->ID); ?></div>
                        <div class="separator"></div>
                        <div class="meta-item author"><?php wiseguard_the_author_posts_link([
                            'text'       => '',
                            'link_class' => '',
                            'object'     => $post   
                        ]); ?></div>
                    </div>
                    <h3 class="cms-heading pt-20 text-line-2">
                        <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                    </h3>
                    <div class="cms-excerpt text-line-3 text-15 pt-15"><?php 
                        echo nl2br($post->post_excerpt);
                    ?></div>
                    <a href="<?php echo esc_url(get_permalink($post->ID)) ?>" class="cms-link pt-20"><?php echo esc_html__('Read More','wiseguard'); ?><i class="cmsi-arrow-right text-10 rtl-flip"></i></a>
                </div>
            <?php endforeach; ?>
        </div>
    </div>
    <div class="cms-second-posts col-6 col-tablet-5 col-mobile-extra-12 pl-60 pl-tablet-extra-20">
        <?php // Content
            foreach ($second_posts['posts'] as $post):
        ?>
                <div class="cms-content d-flex gap-40 gap-tablet-10 gap-mobile-extra-40 gap-smobile-10 align-items-center hover-image-zoom-out">
                    <div class="flex-basic flex-tablet-full flex-mobile-extra-basic flex-smobile-full">
                        <div class="cms-post-meta d-flex gap-10 pb-5">
                            <div class="meta-item date"><?php echo get_the_date('', $post->ID); ?></div>
                            <div class="separator"></div>
                            <div class="meta-item author"><?php wiseguard_the_author_posts_link([
                                'text'       => '',
                                'link_class' => '',
                                'object'     => $post   
                            ]); ?></div>
                        </div>
                        <h4 class="cms-heading text-20 text-line-3 lh-145">
                            <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                        </h4>
                    </div>
                    <?php 
                        wiseguard_elementor_post_thumbnail_render($settings, [
                            'post_id'       => $post->ID,
                            'custom_size'   => ['width' => 180, 'height' => 120],
                            'img_class'     => 'img-cover',
                            'max_height'    => true,    
                            'before'        => '<div class="flex-auto flex-smobile-full order-tablet-first">',
                            'after'         => '</div>'
                        ]);
                    ?>
                </div>
        <?php endforeach; ?>
    </div>
</div>