<?php
$widget->add_inline_editing_attributes( 'text' );
$widget->add_inline_editing_attributes( 'link_text' );
// Wrap
$widget->add_render_attribute('wrap', [
	'class' => array_filter([
		'cms-cta',
		'cms-cta-'.$widget->get_setting('layout', '8'),
		'bg-accent',
		'cms-radius-16 overflow-hidden',
		'd-flex',
		wiseguard_elementor_get_alignment_class($widget, $settings, ['name' => 'align'])
	])
]);
// Text
$widget->add_render_attribute('title', [
	'class' => [
		'cms-title cms-heading',
		'text-'.$widget->get_setting('title_color','white'),
		'mt-n15 pb-25'
	]
]);
// Text
$widget->add_render_attribute('text', [
	'class' => [
		'cms-desc',
		'text-'.$widget->get_setting('text_color','white'),
		'pb-30'
	]
]);
// Link
$page_link = $widget->get_setting('page_link','');
switch ($settings['link_type']) {
	case 'page':
		$page = !empty($page_link) ? get_page_by_path($page_link, OBJECT) : [];
		$url  = !empty($page) ? get_permalink($page->ID) : '#';
		break;
	
	default:
		$url = $widget->get_setting('custom_link', ['url' => '#'])['url'];
		break;
}
$widget->add_render_attribute( 'link_text', [
	'class' => [
		'cms-link',
		'cms-link-1',
		'text-'.$widget->get_setting('link_color','secondary-lighten'),
		'text-hover-'.$widget->get_setting('link_color_hover','primary')
	],
	'href'	=> $url
]);
// Button
$btn_page_link = $widget->get_setting('btn_page_link','');
switch ($settings['btn_link_type']) {
	case 'page':
		$btn_page = !empty($btn_page_link) ? get_page_by_path($btn_page_link, OBJECT) : [];
		$btn_url  = !empty($btn_page) ? get_permalink($btn_page->ID) : '#';
		break;
	
	default:
		$btn_url = $widget->get_setting('btn_link', ['url' => '#'])['url'];
		break;
}
$widget->add_inline_editing_attributes('btn_text');
$widget->add_render_attribute( 'btn_text', [
	'class' => [
		'btn btn-lg',
		'btn-'.$widget->get_setting('link_color','white'),
		'btn-hover-'.$widget->get_setting('link_color_hover','secondary')
	],
	'href'	=> $btn_url
]);
// Phone
$widget->add_render_attribute('cta-phone', [
	'class' => ['cms-cta-phone cms-phone-2', 'd-flex align-items-center', 'text-white text-hover-white'],
	'href'  => 'tel:'.str_replace(' ', '', $widget->get_setting('phone')),
	'target' => '_blank',
]);
$widget->add_inline_editing_attributes('phone');
$widget->add_render_attribute('phone', [
	'class' => ['cms-phone-number cms-heading font-500'],
]);
$widget->add_inline_editing_attributes('phone_text');
$widget->add_render_attribute('phone_text', [
	'class' => ['cms-phone--text'],
]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
	<div class="col-5 col-mobile-extra-12">
		<?php 
			wiseguard_elementor_image_render($settings,[
				'name'        => 'banner',
				'img_class'   => 'h-100 w-100',
				'custom_size' => ['width' => 550, 'height' => 516],
				//'max_height'  => true	
			]);
		?>
	</div>
	<div class="col-7 col-mobile-extra-12 p-lr-110 p-lr-tablet-extra-40 p-lr-mobile-extra-20 p-tb-90 p-tb-mobile-extra-40">
		<h2 <?php etc_print_html($widget->get_render_attribute_string('title')) ?>><?php etc_print_html($settings['title']) ?></h2>
		<div <?php etc_print_html($widget->get_render_attribute_string('text')) ?>><?php etc_print_html($settings['text']) ?></div>
		<div class="d-flex gap align-items-center">
			<a <?php etc_print_html( $widget->get_render_attribute_string( 'btn_text' ) ); ?>>
				<?php 
					// text
					echo esc_html( $settings['btn_text'] );
				?><i class="cmsi-arrow-circle-right rtl-flip text-26"></i>
			</a>
			<a <?php etc_print_html( $widget->get_render_attribute_string( 'cta-phone' ) ); ?>>
				<i class="cms-phone-icon cmsi-phone-alt"></i>
				<div class="cms-phone-text">
					<div <?php etc_print_html( $widget->get_render_attribute_string( 'phone_text' ) ); ?>><?php echo esc_html($settings['phone_text']); ?></div>
					<div <?php etc_print_html( $widget->get_render_attribute_string( 'phone' ) ); ?>><?php 
						// text
						echo esc_html( $settings['phone'] );
					?></div>
				</div>
			</a>
		</div>
	</div>
</div>