<?php
	if ( empty( $settings['map_address'] ) ) {
		return;
	}
	if ( 0 === absint( $settings['zoom']['size'] ) ) {
		$settings['zoom']['size'] = 10;
	}
	$api_key = wiseguard_get_opt('gm_api_key');;
	$params = [
		rawurlencode( $settings['map_address'] ),
		absint( $settings['zoom']['size'] ),
	];
	if ( $api_key ) {
		$params[] = $api_key;
		$map_url = 'https://www.google.com/maps/embed/v1/place?key=%3$s&q=%1$s&amp;zoom=%2$d';
	} else {
		$map_url = 'https://maps.google.com/maps?q=%1$s&amp;t=m&amp;z=%2$d&amp;output=embed&amp;iwloc=near';
	}
// Wrap
$widget->add_render_attribute('wrap', [
	'class' => [
		'cms-egmap',
		'cms-egmap-'.$settings['layout'],
		'relative'
	]
]);
// Container
$widget->add_render_attribute('overlay-box', [
	'class' => [
		'overlay-box',
		'bg-white cms-radius-10 cms-shadow-1',
		'p-40 p-lr-smobile-20'
	]
]);
// Title
$widget->add_inline_editing_attributes( 'title' );
$widget->add_render_attribute( 'title', [
	'class' => [
		'cms-title',
		'cms-heading font-700',
		'text-23',
		'empty-none',
		'mt-n7'
	]
]);
// Adress
$widget->add_inline_editing_attributes( 'address' );
$widget->add_render_attribute( 'address', [
	'class' => [
		'cms-address d-block',
		'text-15',
		'text-body',
		'pb-15'
	],
	'href'   => $map_url,
	'target' => '_blank'
]);

// Email
$widget->add_inline_editing_attributes( 'email', 'none' );
$email = $widget->get_setting('email', 'WiseGuard@farost.net');
$widget->add_render_attribute( 'email', [
	'class' => [
		'cms-email',
		'text-19 font-500 cms-heading',
		'text-heading',
		'd-flex gap-20 align-items-center no-wrap text-ellipsis',
		'pb-10'
	],
	'href'   => 'mailto:'.$email,
	'target' => '_blank'
]);
// Phone
$widget->add_inline_editing_attributes( 'phone', 'none' );
$phone = $settings['phone'];
$phone_link = str_replace(' ', '', $phone);
$widget->add_render_attribute( 'phone',[ 
	'class' => [
		'cms-phone',
		'text-19 font-500 cms-heading',
		'text-heading',
		'd-flex gap-20 align-items-center no-wrap text-ellipsis',
		'pb-25'
	],
	'href'   => 'tel:'.$phone_link,
	'target' => '_blank'
]);
// Button
$page_link = $widget->get_setting('page_link','');
switch ($settings['link_type']) {
	case 'page':
		$page = !empty($page_link) ? get_page_by_path($page_link, OBJECT) : [];
		$btn_url  = !empty($page) ? get_permalink($page->ID) : '#';
		break;
	
	default:
		$btn_url = $widget->get_setting('link', ['url' => '#'])['url'];
		break;
}
$widget->add_render_attribute( 'btn_text', [
	'class' => array_filter([
		'btn btn-lg',
		'btn-secondary',
		'btn-hover-primary'
	]),
	'href'	=> $btn_url
]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
	<iframe loading="lazy"
		src="<?php echo esc_url( vsprintf( $map_url, $params ) ); ?>"
		title="<?php echo esc_attr( $settings['map_address'] ); ?>"
		aria-label="<?php echo esc_attr( $settings['map_address'] ); ?>"
	></iframe>
	<div <?php etc_print_html($widget->get_render_attribute_string('overlay-box')); ?>>
		<div <?php etc_print_html($widget->get_render_attribute_string('title')); ?>><?php etc_print_html($settings['title']); ?></div>
		<a <?php etc_print_html( $widget->get_render_attribute_string( 'address' ) ); ?>><?php 
			etc_print_html( $settings['address']); 
		?></a>
		<a <?php etc_print_html( $widget->get_render_attribute_string( 'email' ) ); ?>><span class="cms-icon cmsi-email text-16"></span><?php 
			etc_print_html( $email ); 
		?></a>
		<a <?php etc_print_html( $widget->get_render_attribute_string( 'phone' ) ); ?>><span class="cms-icon cmsi-phone-alt text-16"></span><?php 
			etc_print_html( $phone ); 
		?></a>
		<a <?php etc_print_html($widget->get_render_attribute_string('btn_text')); ?>>
			<?php etc_print_html($settings['btn_text']); ?>
			<i class="cmsi-arrow-circle-right text-26 rtl-flip"></i>
		</a>
	</div>
</div>