<?php
// Wrap
$widget->add_render_attribute('wrap', [
	'class' => array_filter([
		'cms-eheading',
		'cms-eheading-'.$widget->get_setting('layout'),
		'text-'.$widget->get_setting('align','start'),
	])
]);
// Small Heading
$widget->add_inline_editing_attributes( 'smallheading_text' );
$widget->add_render_attribute( 'smallheading_text', [
	'class' => [
		'cms-smallheading empty-none font-700 text-16 pb-10',
		'text-'.$widget->get_setting('smallheading_color', 'accent') 
	]
]);
// Large Heading
$widget->add_inline_editing_attributes( 'heading_text');
$widget->add_render_attribute( 'heading_text', [
	'class' => [
		'cms-heading empty-none',
		'text-'.$widget->get_setting('heading_color','heading'),
		'pb-30'
	]
]);
// Description Bold
$widget->add_inline_editing_attributes( 'description_bold_text' );
$widget->add_render_attribute( 'description_bold_text', [
	'class' => array_filter([
		'cms-desc text-17 pb-25 font-700 empty-none',
		'text-'.$widget->get_setting('description_bold_color','primary')
	])
]);
// Description
$widget->add_inline_editing_attributes( 'description_text' );
$widget->add_render_attribute( 'description_text', [
	'class' => array_filter([
		'cms-desc text-17 empty-none',
		'text-'.$widget->get_setting('description_color','body')
	])
]);
// Link 1
$link1_page = $widget->get_setting('link1_page','');
switch ($settings['link1_type']) {
	case 'page':
		$page = !empty($link1_page) ? get_page_by_path($link1_page, OBJECT) : [];
		$link1_url  = !empty($page) ? get_permalink($page->ID) : '#';
		break;
	
	default:
		$link1_url = $widget->get_setting('link1_custom', ['url' => '#'])['url'];
		break;
}
$widget->add_inline_editing_attributes( 'link1_text' );
$widget->add_render_attribute( 'link1_text', [
	'class' => [
		'btn btn-lg',
		'btn-'.$widget->get_setting('link1_color','secondary-regular'),
		'btn-hover-'.$widget->get_setting('link1_color_hover','accent-regular')
	],
	'href'	=> $link1_url
]);
// Link 2
$link2_page = $widget->get_setting('link2_page','');
switch ($settings['link2_type']) {
	case 'page':
		$page = !empty($link2_page) ? get_page_by_path($link2_page, OBJECT) : [];
		$link2_url  = !empty($page) ? get_permalink($page->ID) : '#';
		break;
	
	default:
		$link2_url = $widget->get_setting('link2_custom', ['url' => '#'])['url'];
		break;
}
$widget->add_inline_editing_attributes( 'link2_text' );
$widget->add_render_attribute( 'link2_text', [
	'class' => [
		'btn btn-lg',
		'btn-outline-'.$widget->get_setting('link2_color','primary'),
		'btn-outline-hover-'.$widget->get_setting('link2_color_hover','primary')
	],
	'href'	=> $link2_url
]);
// Feature
$features = $widget->get_setting('cms_feature', []);
$widget->add_render_attribute('features-item',[
	'class' => [
		'cms-list d-flex gap-20 no-wrap',
		'justify-content-'.$widget->get_setting('align','start'),
		'text-16 font-700',
		'text-'.$widget->get_setting('feature_color','primary')
	]
]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
	<div <?php etc_print_html( $widget->get_render_attribute_string( 'smallheading_text' ) ); ?>><?php echo nl2br( $settings['smallheading_text'] ); ?></div>
	<h2 <?php etc_print_html( $widget->get_render_attribute_string( 'heading_text' ) ); ?>><?php echo nl2br( $settings['heading_text'] ); ?></h2>
	<div <?php etc_print_html( $widget->get_render_attribute_string( 'description_bold_text' ) ); ?>><?php echo nl2br( $settings['description_bold_text'] ); ?></div>
	<div <?php etc_print_html( $widget->get_render_attribute_string( 'description_text' ) ); ?>><?php echo nl2br( $settings['description_text'] ); ?></div>
	<div class="cms-eheading-buttons d-flex gap-30 pt-30"><?php 
		if(!empty($settings['link1_text'])) { ?>
			<a <?php etc_print_html( $widget->get_render_attribute_string( 'link1_text' ) ); ?>>
				<?php echo esc_html( $settings['link1_text'] ); ?>
				<i class="cms-btn-icon cmsi-arrow-right rtl-flip text-10"></i>
			</a>
		<?php } 
		if(!empty($settings['link2_text'])){ 
			?>
			<a <?php etc_print_html( $widget->get_render_attribute_string( 'link2_text' ) ); ?>>
				<?php echo esc_html( $settings['link2_text'] ); ?>
			</a>
		<?php }
		?>
	</div>
	<?php if($settings['show_feature'] === 'yes'): ?>
		<div class="cms-heading-features cms-lists-1 mt-50">
			<?php 
				foreach ( $features as $key => $cms_feature ):
					$title_key = $widget->get_repeater_setting_key( 'title', 'cms_list', $key );
					$widget->add_render_attribute($title_key, 'class', 'flex-basic');
					$widget->add_inline_editing_attributes( $title_key, 'none' );
				?>
			        <div <?php etc_print_html($widget->get_render_attribute_string('features-item')); ?>>
			            <span class="cms-list-icon cmsi-check flex-auto"></span>
			            <span <?php etc_print_html( $widget->get_render_attribute_string( $title_key ) ); ?>><?php echo esc_html( $cms_feature['title'] ) ?></span>
			        </div>
				<?php endforeach;
			?>
		</div>
	<?php endif; ?>
</div>