<?php
// Wrap
$widget->add_render_attribute('wrap', [
	'class' => array_filter([
		'cms-eheading',
		'cms-eheading-'.$widget->get_setting('layout'),
		'text-'.$widget->get_setting('align','start'),
		'd-flex gutter gutter-grid'
	])
]);
// Large Heading
$widget->add_inline_editing_attributes( 'heading_text');
$widget->add_render_attribute( 'heading_text', [
	'class' => [
		'cms-heading empty-none',
		'text-'.$widget->get_setting('heading_color','heading'),
		'mt-n10 pb-55'
	]
]);
// Description Bold
$widget->add_inline_editing_attributes( 'description_bold_text' );
$widget->add_render_attribute( 'description_bold_text', [
	'class' => array_filter([
		'cms-desc text-17 pt-25 font-700 empty-none',
		'text-'.$widget->get_setting('description_bold_color','body-darken')
	])
]);
// Description
$widget->add_inline_editing_attributes( 'description_text' );
$widget->add_render_attribute( 'description_text', [
	'class' => array_filter([
		'cms-desc text-17 empty-none',
		'text-'.$widget->get_setting('description_color','body')
	])
]);
// Link 1
$link1_page = $widget->get_setting('link1_page','');
switch ($settings['link1_type']) {
	case 'page':
		$page = !empty($link1_page) ? get_page_by_path($link1_page, OBJECT) : [];
		$url  = !empty($page) ? get_permalink($page->ID) : '#';
		break;
	
	default:
		$url = $widget->get_setting('link1_custom', ['url' => '#'])['url'];
		break;
}
$widget->add_inline_editing_attributes( 'link1_text' );
$widget->add_render_attribute( 'link1_text', [
	'class' => [
		'btn btn-lg',
		'btn-outline-'.$widget->get_setting('link1_color','secondary'),
		'btn-hover-'.$widget->get_setting('link1_color_hover', 'secondary')
	],
	'href'	=> $url
]);
// Buttons
$widget->add_render_attribute('buttons',[
	'class' => [
		'cms-heading-buttons d-flex gap-30 align-items-center pt-50 mt-n5',
		'justify-content-'.$widget->get_setting('align','start'),
		'empty-none'
	]
]);
// Feature
$features = $widget->get_setting('cms_feature', []);
$widget->add_render_attribute('features',[
	'class' => [
		'cms-heading-features cms-lists',
		'text-15 font-700',
		'text-'.$widget->get_setting('feature_color','body'),
		'pt-40'
	]
]);
$widget->add_render_attribute('features-item',[
	'class' => [
		'cms-list d-flex gap-10 no-wrap',
		'justify-content-'.$widget->get_setting('align','start')
	]
]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
	<div class="col-7 col-tablet-6 col-mobile-extra-12">
		<h2 <?php etc_print_html( $widget->get_render_attribute_string( 'heading_text' ) ); ?>><?php echo nl2br( $settings['heading_text'] ); ?></h2>
		<?php
			// Banner Small
			ob_start();
				wiseguard_elementor_image_render($settings,[
					'name'        => 'banner_small',
					'img_class'   => 'cms-heading-banner-small absolute bottom-right',
					'custom_size' => ['width' => 206, 'height' => 137],
					'default'	  => true,
					'max_height'  => true,	
					'before'	  => '',
					'after'		  => '',
					'edge'   	  => [
						'show_edge'	  => 'no'
					]
				]);
			$banner_small = ob_get_clean();
			// video
			ob_start();
				wiseguard_elementor_button_video_render($widget, $settings, [
					'name'       => 'video_link',
					'icon'       => $widget->get_setting('video_icon')['value'].' flex-auto',
					'text'       => $widget->get_setting('video_text'),
					'text_class' => 'flex-auto cms-hidden-mobile_extra',
					'layout'     => '4',
					'class'      => 'size-88 justify-content-between absolute bottom-right z-top',
			    ]);
			$video = ob_get_clean();
			// Banner
			wiseguard_elementor_image_render($settings,[
				'name'        => 'banner',
				'img_class'   => 'img-cover cms-clip-tl1',
				'custom_size' => ['width' => 620, 'height' => 464],
				'default'	  => true,
				'max_height'  => true,	
				'before'	  => '<div class="cms-heading-banner relative ml-110 ml-tablet-0"><div class="relative">',
				'after'		  => $video.'</div>'.$banner_small.'</div>',
				'edge'   	  => [
					'show_edge'	  => 'top-left'
				]
			]);
		?>
	</div>
	<div class="col-5 col-tablet-6 pl-90 pl-laptop-20 col-mobile-extra-12 pt-115 pt-mobile-extra-20">
		<div <?php etc_print_html( $widget->get_render_attribute_string( 'description_text' ) ); ?>><?php echo nl2br( $settings['description_text'] ); ?></div>
		<div <?php etc_print_html( $widget->get_render_attribute_string( 'description_bold_text' ) ); ?>><?php echo nl2br( $settings['description_bold_text'] ); ?></div>
		<div <?php etc_print_html($widget->get_render_attribute_string('features')); ?>>
			<?php 
				foreach ( $features as $key => $cms_feature ):
					$title_key = $widget->get_repeater_setting_key( 'title', 'cms_list', $key );
					$widget->add_render_attribute($title_key, 'class', 'flex-basic');
					$widget->add_inline_editing_attributes( $title_key, 'none' );
				?>
			        <div <?php etc_print_html($widget->get_render_attribute_string('features-item')); ?>>
			            <span class="cms-icon cmsi-check-circle text-22 text-accent flex-auto"></span>
			            <span <?php etc_print_html( $widget->get_render_attribute_string( $title_key ) ); ?>><?php echo esc_html( $cms_feature['title'] ) ?></span>
			        </div>
				<?php endforeach;
			?>
		</div>
		<div <?php etc_print_html($widget->get_render_attribute_string('buttons')); ?>><?php if(!empty($settings['link1_text'])) { ?>
			<a <?php etc_print_html( $widget->get_render_attribute_string( 'link1_text' ) ); ?>>
				<?php echo esc_html( $settings['link1_text'] ); ?>
				<i class="cms-btn-icon cmsi-arrow-right rtl-flip text-10"></i>
			</a>
		<?php } ?></div>
	</div>
</div>