<?php
// Wrap
$widget->add_render_attribute('wrap', [
	'class' => array_filter([
		'cms-eheading',
		'cms-eheading-'.$widget->get_setting('layout'),
		'text-'.$widget->get_setting('align','start'),
		'd-flex gutter gutter-grid'
	])
]);
// Small Heading
$widget->add_inline_editing_attributes( 'smallheading_text' );
$widget->add_render_attribute( 'smallheading_text', [
	'class' => [
		'cms-smallheading empty-none font-700 text-17 pb-10',
		'text-'.$widget->get_setting('smallheading_color', 'accent') 
	]
]);
// Large Heading
$widget->add_inline_editing_attributes( 'heading_text');
$widget->add_render_attribute( 'heading_text', [
	'class' => [
		'cms-heading empty-none',
		'text-'.$widget->get_setting('heading_color','heading'),
		'pb-40'
	]
]);
// Description Bold
$widget->add_inline_editing_attributes( 'description_bold_text' );
$widget->add_render_attribute( 'description_bold_text', [
	'class' => array_filter([
		'cms-desc text-17 pt-25 font-700 empty-none',
		'text-'.$widget->get_setting('description_bold_color','body-darken')
	])
]);
// Description
$widget->add_inline_editing_attributes( 'description_text' );
$widget->add_render_attribute( 'description_text', [
	'class' => array_filter([
		'cms-desc text-17 empty-none',
		'text-'.$widget->get_setting('description_color','body')
	])
]);
// Link 1
$link1_page = $widget->get_setting('link1_page','');
switch ($settings['link1_type']) {
	case 'page':
		$page = !empty($link1_page) ? get_page_by_path($link1_page, OBJECT) : [];
		$url  = !empty($page) ? get_permalink($page->ID) : '#';
		break;
	
	default:
		$url = $widget->get_setting('link1_custom', ['url' => '#'])['url'];
		break;
}
$widget->add_inline_editing_attributes( 'link1_text' );
$widget->add_render_attribute( 'link1_text', [
	'class' => [
		'btn btn-lg',
		'btn-secondary btn-hover-accent'
	],
	'href'	=> $url
]);

// Link 2
$link2_page = $widget->get_setting('link2_page','');
switch ($settings['link2_type']) {
	case 'page':
		$page = !empty($link2_page) ? get_page_by_path($link2_page, OBJECT) : [];
		$url  = !empty($page) ? get_permalink($page->ID) : '#';
		break;
	
	default:
		$url = $widget->get_setting('link2_custom', ['url' => '#'])['url'];
		break;
}
$widget->add_inline_editing_attributes( 'link2_text' );
$widget->add_render_attribute( 'link2_text', [
	'class' => [
		'cms-link',
		'cms-link-'.$widget->get_setting('link2_style'),
		'text-'.$widget->get_setting('link2_color','default'),
		'text-hover-'.$widget->get_setting('link2_color_hover','default')
	],
	'href'	=> $url
]);
// Buttons
$widget->add_render_attribute('buttons',[
	'class' => [
		'cms-heading-buttons d-flex gap align-items-center pt-50 mt-n5',
		'justify-content-'.$widget->get_setting('align','start')
	],
	'style' => '--cms-gap:30px;'
]);
// Signature
$savatar_class = wiseguard_nice_class(['savatar', 'circle']);
//
$widget->add_inline_editing_attributes( 'sname' );
$widget->add_render_attribute('sname', [
	'class' => [
		'sname',
		'cms-heading text-17',
	]
]);
//
$widget->add_inline_editing_attributes( 'sposition' );
$widget->add_render_attribute('sposition', [
	'class' => [
		'sposition',
		'text-14 text-secondary-lighten',
	]
]);
// Feature
$features = $widget->get_setting('cms_feature', []);
$widget->add_render_attribute('features',[
	'class' => [
		'cms-heading-features cms-lists',
		'text-15 font-700',
		'text-'.$widget->get_setting('feature_color','body'),
		'pt-30'
	]
]);
$widget->add_render_attribute('features-item',[
	'class' => [
		'cms-list d-flex gap-10 no-wrap',
		'justify-content-'.$widget->get_setting('align','start')
	]
]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
	<div class="col-6 col-mobile-extra-12">
		<div <?php etc_print_html( $widget->get_render_attribute_string( 'smallheading_text' ) ); ?>><?php echo nl2br( $settings['smallheading_text'] ); ?></div>
		<h2 <?php etc_print_html( $widget->get_render_attribute_string( 'heading_text' ) ); ?>><?php echo nl2br( $settings['heading_text'] ); ?></h2>
		<div class="pl-110 pl-tablet-0">
			<div <?php etc_print_html( $widget->get_render_attribute_string( 'description_text' ) ); ?>><?php echo nl2br( $settings['description_text'] ); ?></div>
			<div <?php etc_print_html( $widget->get_render_attribute_string( 'description_bold_text' ) ); ?>><?php echo nl2br( $settings['description_bold_text'] ); ?></div>
			<div <?php etc_print_html($widget->get_render_attribute_string('features')); ?>>
				<?php 
					foreach ( $features as $key => $cms_feature ):
						$title_key = $widget->get_repeater_setting_key( 'title', 'cms_list', $key );
						$widget->add_render_attribute($title_key, 'class', 'flex-basic');
						$widget->add_inline_editing_attributes( $title_key, 'none' );
					?>
				        <div <?php etc_print_html($widget->get_render_attribute_string('features-item')); ?>>
				            <span class="cms-icon cmsi-check-circle text-22 text-accent flex-auto"></span>
				            <span <?php etc_print_html( $widget->get_render_attribute_string( $title_key ) ); ?>><?php echo esc_html( $cms_feature['title'] ) ?></span>
				        </div>
					<?php endforeach;
				?>
			</div>
			<div <?php etc_print_html($widget->get_render_attribute_string('buttons')); ?>>
				<?php if(!empty($settings['link1_text'])) { ?>
					<a <?php etc_print_html( $widget->get_render_attribute_string( 'link1_text' ) ); ?>>
						<?php echo esc_html( $settings['link1_text'] ); ?>
						<i class="cms-btn-icon cmsi-arrow-right rtl-flip text-10"></i>
					</a>
				<?php }
				if(!empty($settings['link2_text'])){ 
					?>
					<a <?php etc_print_html( $widget->get_render_attribute_string( 'link2_text' ) ); ?>>
						<?php echo esc_html( $settings['link2_text'] ); ?>
						<i class="cmsi-arrow-alt-circle-right text-32 text-primary rtl-flip"></i>
					</a>
				<?php } 
					// Signature
				?>
				<div class="cms-signature d-flex gap-10 align-items-center">
					<?php wiseguard_elementor_image_render($settings, [
						'name'        => 'savatar',
						'custom_size' => ['width'=>56, 'height'=>56],
						'img_class'   => $savatar_class,
						'before'      => '<div class="savatars circle outline-1">',
						'after'       => '</div>'
	 				]); ?>
	 				<div class="stext flex-auto relative">
	 					<?php 
	 						wiseguard_elementor_image_render($settings, [
								'name'        => 'simage',
								'size'        => 'custom',
								'custom_size' => ['width' => 134, 'height'=> 68]
	 						]);
	 					?>
	 					<div class="cms--signature absolute center">
		 					<div <?php etc_print_html($widget->get_render_attribute_string('sname')); ?>><?php echo nl2br($settings['sname']); ?></div>
		 					<div <?php etc_print_html($widget->get_render_attribute_string('sposition')); ?>><?php echo nl2br($settings['sposition']); ?></div>
		 				</div>
	 				</div>
				</div>
			</div>
		</div>
	</div>
	<div class="col-6 pl-90 pl-laptop-20 col-mobile-extra-12 order-mobile-extra-first">
		<?php
			// Banner title
			ob_start();
		?>
			<div class="cms-heading-banner-title"><?php echo nl2br($settings['banner_title']); ?></div>
		<?php
			$banner_title = ob_get_clean();
			// Banner
			wiseguard_elementor_image_render($settings,[
				'name'        => 'banner',
				'img_class'   => 'w-100 img-cover cms-clip-tr1',
				'custom_size' => ['width' => 550, 'height' => 627],
				'default'	  => true,
				'max_height'  => true,	
				'before'	  => '<div class="cms-heading-banner relative pb-40 mt-10 cms-sticky relative">',
				'after'		  => $banner_title.'</div>',
				'edge'   	  => [
					'show_edge'	  => 'top-right'
				]
			]);
		?>
	</div>
</div>