<?php
// Wrap
$widget->add_render_attribute('wrap', [
	'class' => array_filter([
		'cms-eheading',
		'cms-eheading-'.$widget->get_setting('layout'),
		'text-'.$widget->get_setting('align','start')
	])
]);
// Small Heading
$widget->add_inline_editing_attributes( 'smallheading_text' );
$widget->add_render_attribute( 'smallheading_text', 'class', 'cms-smallheading empty-none font-700 text-16 text-primary pb-10' );
// Large Heading
$widget->add_inline_editing_attributes( 'heading_text', 'none' );
$widget->add_render_attribute( 'heading_text', [
	'class' => 'cms-heading empty-none' 
]);
// Description Bold
$widget->add_inline_editing_attributes( 'description_bold_text' );
$widget->add_render_attribute( 'description_bold_text', [
	'class' => array_filter([
		'cms-desc text-16 pt-20 font-700 empty-none'
	])
]);
// Description
$widget->add_inline_editing_attributes( 'description_text' );
$widget->add_render_attribute( 'description_text', [
	'class' => array_filter([
		'cms-desc text-16 pt-20 empty-none'
	])
]);
// Link 1
$link1_page = $widget->get_setting('link1_page','');
switch ($settings['link1_type']) {
	case 'page':
		$page = !empty($link1_page) ? get_page_by_path($link1_page, OBJECT) : [];
		$url  = !empty($page) ? get_permalink($page->ID) : '#';
		break;
	
	default:
		$url = $widget->get_setting('link1_custom', ['url' => '#'])['url'];
		break;
}
$widget->add_inline_editing_attributes( 'link1_text' );
$widget->add_render_attribute( 'link1_text', [
	'class' => [
		'btn btn-lg',
		'btn-secondary btn-hover-primary',
		'icon-last'
	],
	'href'	=> $url
]);

// Link 2
$link2_page = $widget->get_setting('link2_page','');
switch ($settings['link2_type']) {
	case 'page':
		$page = !empty($link2_page) ? get_page_by_path($link2_page, OBJECT) : [];
		$url  = !empty($page) ? get_permalink($page->ID) : '#';
		break;
	
	default:
		$url = $widget->get_setting('link2_custom', ['url' => '#'])['url'];
		break;
}
$widget->add_inline_editing_attributes( 'link2_text' );
$widget->add_render_attribute( 'link2_text', [
	'class' => [
		'cms-link',
		'cms-link-'.$widget->get_setting('link2_style'),
		'text-'.$widget->get_setting('link2_color','default'),
		'text-hover-'.$widget->get_setting('link2_color_hover','default')
	],
	'href'	=> $url
]);
// Buttons
$widget->add_render_attribute('buttons',[
	'class' => [
		'cms-heading-buttons d-flex gap pt-25',
		'justify-content-'.$widget->get_setting('align','start')
	],
	'style' => '--cms-gap:30px;'
]);
// Feature
$features = $widget->get_setting('cms_feature', []);
$widget->add_render_attribute('features-item',[
	'class' => [
		'cms-list d-flex gap-10',
		'justify-content-'.$widget->get_setting('align','start')
	]
]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
	<?php
		// Banner
		wiseguard_elementor_image_render($settings,[
			'name'        => 'banner',
			'img_class'   => 'mb-30',
			'custom_size' => ['width' => 510, 'height' => 510],
			'default'	  => false		
		]);
	?>
	<div <?php etc_print_html( $widget->get_render_attribute_string( 'smallheading_text' ) ); ?>><?php echo nl2br( $settings['smallheading_text'] ); ?></div>
	<h2 <?php etc_print_html( $widget->get_render_attribute_string( 'heading_text' ) ); ?>><?php echo nl2br( $settings['heading_text'] ); ?></h2>
	<div <?php etc_print_html( $widget->get_render_attribute_string( 'description_bold_text' ) ); ?>><?php echo nl2br( $settings['description_bold_text'] ); ?></div>
	<div <?php etc_print_html( $widget->get_render_attribute_string( 'description_text' ) ); ?>><?php echo nl2br( $settings['description_text'] ); ?></div>
	<div <?php etc_print_html($widget->get_render_attribute_string('buttons')); ?>>
		<?php if(!empty($settings['link1_text'])) { ?>
			<a <?php etc_print_html( $widget->get_render_attribute_string( 'link1_text' ) ); ?>>
				<i class="cms-btn-icon cmsi-edge-right-up rtl-flip text-10"></i>
				<?php echo esc_html( $settings['link1_text'] ); ?>
			</a>
		<?php }
		if(!empty($settings['link2_text'])){ 
			?>
			<a <?php etc_print_html( $widget->get_render_attribute_string( 'link2_text' ) ); ?>>
				<?php echo esc_html( $settings['link2_text'] ); ?>
				<i class="cmsi-arrow-alt-circle-right text-32 text-primary rtl-flip"></i>
			</a>
		<?php } ?>
	</div>
	<div class="cms-heading-features pt-30">
		<?php 
			foreach ( $features as $key => $cms_feature ):
				$title_key = $widget->get_repeater_setting_key( 'title', 'cms_list', $key );
				$widget->add_render_attribute($title_key, 'class', 'flex-auto');
				$widget->add_inline_editing_attributes( $title_key, 'none' );
			?>
		        <div <?php etc_print_html($widget->get_render_attribute_string('features-item')); ?>>
		            <?php 
		            	\Elementor\Icons_Manager::render_icon( $cms_feature['icon'], [ 'aria-hidden' => 'true', 'class' => 'cms-icon flex-auto' ] ); 
		            ?>
		            <span <?php etc_print_html( $widget->get_render_attribute_string( $title_key ) ); ?>><?php echo esc_html( $cms_feature['title'] ) ?></span>
		        </div>
			<?php endforeach;
		?>
	</div>
</div>