<?php
use Elementor\Icons_Manager;

$settings['num_words'] = !empty($settings['num_words']) ? $settings['num_words'] : 21;
$settings['readmore_text'] = !empty($settings['readmore_text']) ? $settings['readmore_text'] : esc_html__('Read More', 'wiseguard');

$html_id  = etc_get_element_id($settings);
$source   = $widget->get_setting('source', '');
$orderby  = $widget->get_setting('orderby', 'date');
$order    = $widget->get_setting('order', 'desc');
$limit    = $widget->get_setting('limit', 6);
extract(etc_get_posts_of_grid( 'cms-industry', [
    'source'   => $source,
    'orderby'  => $orderby,
    'order'    => $order,
    'limit'    => $limit
]));

$arrows = $widget->get_setting('arrows');
$dots = $widget->get_setting('dots');

$title_tag = $widget->get_setting('title_tag', 'h3');

$thumbnail_size             = $widget->get_setting('thumbnail_size', 'custom');
$thumbnail_custom_dimension = [
    'width'  => !empty($settings['thumbnail_custom_dimension']['width']) ? $settings['thumbnail_custom_dimension']['width'] : 400,
    'height' => !empty($settings['thumbnail_custom_dimension']['height']) ? $settings['thumbnail_custom_dimension']['height'] : 474
];
$num_words                  = $widget->get_setting('num_words', '');
$readmore_text              = $settings['readmore_text'];

$posts_data = array(
    'taxonomy'                   => 'industry-category',
    //
    'layout'                     => $widget->get_setting('layout', '3'),
    'source'                     => $source,
    'orderby'                    => $orderby,
    'order'                      => $order,
    'limit'                      => $limit,
    'thumbnail_size'             => $thumbnail_size,
    'thumbnail_custom_dimension' => $thumbnail_custom_dimension,
    'num_words'                  => $num_words,
    'readmore_text'              => $readmore_text
);
// Wrap
$widget->add_render_attribute('wrap',[
    'id'              => $html_id,
    'class'           => [
        'cms-post-carousel',
        'cms-carousel-dots-2',
        'cms-grid', 
        'cms-industry-grid', 
        'cms-grid-'.$widget->get_setting('layout','3')
    ]
]);
// Call To Action
$widget->add_inline_editing_attributes( 'text' );
$widget->add_inline_editing_attributes( 'link_text' );
// Wrap
$widget->add_render_attribute('cta-wrap', [
    'class' => array_filter([
        'cms-cta flex-basic',
        'text-15 font-700',
    ])
]);
// Text
$widget->add_render_attribute('cta_text', [
    'class' => [
        'cms-cta-desc',
        'text-'.$widget->get_setting('cta_text_color','body')
    ]
]);

// Link
$page_link = $widget->get_setting('cta_page_link','');
switch ($settings['cta_link_type']) {
    case 'page':
        $page = !empty($page_link) ? get_page_by_path($page_link, OBJECT) : [];
        $url  = !empty($page) ? get_permalink($page->ID) : '#';
        break;
    
    default:
        $url = $widget->get_setting('cta_custom_link', ['url' => '#'])['url'];
        break;
}
$widget->add_render_attribute( 'cta_link_text', [
    'class' => [
        'cms-cta-link',
        'cms-link',
        'cms-link-1',
        'text-'.$widget->get_setting('cta_link_color','accent'),
        'text-hover-'.$widget->get_setting('cta_link_hover_color','secondary')
    ],
    'href'  => $url
]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
    <div class="cms-carousel swiper">
        <div class="swiper-wrapper">
            <?php
                wiseguard_get_post_grid($settings, $posts, $posts_data,[
                    'item_class' => 'cms-swiper-item swiper-slide'
                ]);
            ?>
        </div>
    </div>
    <div class="d-flex gap-40 justify-content-between align-items-center pt-25 pt-tablet-40">
        <div <?php etc_print_html($widget->get_render_attribute_string('cta-wrap')); ?>>
            <span <?php etc_print_html($widget->get_render_attribute_string('cta_text')) ?>><?php etc_print_html($settings['cta_text']) ?></span>
            <a <?php etc_print_html( $widget->get_render_attribute_string( 'cta_link_text' ) ); ?>>
                <?php 
                    // text
                    echo esc_html( $settings['cta_link_text'] );
                ?><i class="cmsi-arrow-right rtl-flip text-10"></i>
            </a>
        </div>
        <?php if ($arrows == 'yes') : ?>
            <div class="cms-carousel-buttons-1 white d-flex justify-content-end gap-30 flex-auto flex-smobile-full order-smobile-first">
                <div class="cms-carousel-button prev cms-carousel-button-prev">
                    <i class="cms-button-arrow-hover cmsi-long-arrow-left-2"></i>
                    <span class="cms-button-arrow-text">
                        <?php
                            $icon_settings = $widget->get_settings_for_display('arrow_prev_icon');
                            if (empty($icon_settings['value'])) {
                                $icon_settings = [
                                    'library' => 'cmsi',
                                    'value'   => 'cmsi-arrow-left',
                                ];
                            }
                            Icons_Manager::render_icon($icon_settings, ['aria-hidden' => 'true','class' => 'rtl-flip text-10']);
                        ?>
                        <?php esc_html_e('Prev','wiseguard') ?>
                    </span>
                </div>
                <div class="cms-carousel-button next cms-carousel-button-next">
                    <i class="cms-button-arrow-hover cmsi-long-arrow-right-2"></i>
                    <span class="cms-button-arrow-text">
                        <?php esc_html_e('Next','wiseguard') ?>
                        <?php
                            $icon_settings = $widget->get_settings_for_display('arrow_next_icon');
                            if (empty($icon_settings['value'])) {
                                $icon_settings = [
                                    'library' => 'cmsi',
                                    'value'   => 'cmsi-arrow-right',
                                ];
                            }
                            Icons_Manager::render_icon($icon_settings, ['aria-hidden' => 'true', 'class' => 'rtl-flip text-10']);
                        ?>
                    </span>
                </div>
            </div>
        <?php endif ?>
    </div>
     <?php if ($dots == 'yes') : 
        $dots_classes = [
            'cms-carousel-dots',
            'cms-carousel-dots-out',
            wiseguard_elementor_get_alignment_class($widget, $settings, [
                'name'         => 'dots-align',
                'default'      => 'center',
                'prefix_class' => 'justify-content-'
            ])
        ]
    ?>
        <div class="<?php echo wiseguard_nice_class($dots_classes); ?>"></div>
    <?php endif ?>
</div>