<?php 
// Wrap
$widget->add_render_attribute('wrap',[
    'class' => [
        'cms-maps-pointer',
        'cms-maps-pointer-'.$settings['layout'],
        'relative',
        'col-6',
        'col-mobile-12'
    ]
]);
// Items
$active_pointer = $settings['active_pointer'];
$cms_pointers = $widget->get_setting('cms_pointers', []);
$banner_custom_dimension = [
    'width'  => !empty($settings['banner_custom_dimension']['width']) ? $settings['banner_custom_dimension']['width'] : 130,
    'height' => !empty($settings['banner_custom_dimension']['height']) ? $settings['banner_custom_dimension']['height'] : 164
];
// Large Heading
$widget->add_inline_editing_attributes( 'heading_text', 'none' );
$widget->add_render_attribute( 'heading_text', [
    'class' => [
        'cms-heading empty-none',
        'text-'.$widget->get_setting('heading_color'),
        'col-6',
        'col-mobile-12'
    ]
]);
// Rating
$rated = $widget->get_setting('star_rated', 100);
$widget->add_render_attribute('star_color', [
    'class' => [
        'cms-star-rate relative',
        'text-'.$widget->get_setting('star_color','body')
    ]
]);
$widget->add_render_attribute('star_rated_color', [
    'class' => [
        'cms-star-rated absolute',
        'text-'.$widget->get_setting('star_rated_color','white'),
    ],
    'data-width' => $rated,
    'style'      => 'width:'.$rated.'%;'
]);
$widget->add_render_attribute('text_color', [
    'class' => [
        'flex-basic text-15 cms-text p-tb-28 p-lr-40 p-lr-smobile-20',
        'text-'.$widget->get_setting('text_color','body')
    ]
]);

$widget->add_render_attribute('percent_text', [
    'class' => [
        'text-underline font-700',
        'text-'.$widget->get_setting('star_rated_color','secondary')
    ]
]);
?>
<div class="cms-maps-pointers-3 cms-shadow-2 cms-radius-trbr-10 bg-white">
    <div class="cms-map-rating d-flex">
        <div <?php etc_print_html($widget->get_render_attribute_string('text_color')); ?>>
            <span <?php etc_print_html($widget->get_render_attribute_string('percent_text')); ?>><?php 
                etc_print_html($widget->get_setting('percent','99.9%').' '.$widget->get_setting('percent_text','Customer Satisfaction'));
            ?></span>
            <?php
                etc_print_html($widget->get_setting('percent_text2','based on 750+ reviews of 6,154 Completed Projects, and 2,194 Happy Customers trust us.'));
            ?>
        </div>
        <div class="flex-auto flex-smobile-full order-smobile-first bg-secondary p-lr-30 p-tb-40 cms-radius-tr-10">
            <div <?php etc_print_html($widget->get_render_attribute_string('star_color')); ?>>
                <div <?php etc_print_html($widget->get_render_attribute_string('star_rated_color')); ?>></div>
            </div>
        </div>
    </div>
    <div class="cms-map-content pl-60 pl-laptop-20 pr-30 p-tb-33">
        <div class="d-flex gutter-20 align-items-center">
            <h3 <?php etc_print_html( $widget->get_render_attribute_string( 'heading_text' ) ); ?>><?php echo nl2br( $settings['heading_text'] ); ?></h3>
            <div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
                <?php 
                    wiseguard_elementor_image_render($settings,[
                        'name'        => 'maps_img',
                        'img_class'   => '',
                        'size'        => 'full',
                        'custom_size' => ['width' => '', 'height' => '']
                    ]);
                ?> 
                <?php
                    foreach ($cms_pointers as $key => $cms_pointer):
                    $is_active = ( $key + 1 ) === $active_pointer ? true : false;
                    $address     = $cms_pointer['address'];
                    $map_zoom    = 14;
                    $map_api_key = wiseguard_get_opt('gm_api_key');
                    $map_params  = [
                        rawurlencode( $address ),
                        absint( $map_zoom )
                    ];
                    $map_url = 'https://maps.google.com/maps?q=%1$s&amp;t=m&amp;z=%2$d&amp;iwloc=near';
                    //elementor-repeater-item-

                    $item_key = $widget->get_repeater_setting_key( 'item', 'cms_maps_pointers', $key );
                    $widget->add_render_attribute( $item_key, [
                        'id'    => 'cms-pointer-item-'.$cms_pointer['_id'],
                        'class' => array_filter([ 
                            'cms-pointer-item absolute cms-touchedside',
                            'elementor-repeater-item-'.$cms_pointer['_id'],
                            'cms-hover-active',
                            $is_active ? 'active' : ''
                        ]),
                        'data-active' => $is_active,
                    ] );
                ?>
                    <div <?php etc_print_html($widget->get_render_attribute_string($item_key)); ?>>
                        <div class="cms-pointer cms-ripple">
                            <div class="cms--pointer cms-circle"></div>
                        </div>
                        <div class="cms-pointer-content d-flex no-wrap cms-radius-4 cms-shadow-1 cms--touchedside">
                            <?php 
                                $cms_pointer['banner_size'] = $settings['banner_size'];
                                $cms_pointer['banner_custom_dimension'] = $banner_custom_dimension;
                                wiseguard_elementor_image_render($cms_pointer,[
                                    'name'           => 'banner',
                                    'image_size_key' => 'banner',
                                    'img_class'      => 'cms-radius-tlbl-4',
                                    'size'           => 'custom',
                                    'custom_size'    => $banner_custom_dimension,
                                    'before'         => '<div class="flex-auto">',
                                    'after'          => '</div>'    
                                ]);
                            ?>
                            <div class="cms-pointer--content flex-basic">
                                <h4 class="text-19 text-line-1"><?php echo esc_html($cms_pointer['title']); ?></h4>
                                <div class="address text-14 pt-10 pb-10"><?php echo esc_html($cms_pointer['address']); ?></div>
                                <a class="cms-link text-secondary-lighten text-hover-primary" target="_blank" href="<?php echo vsprintf( $map_url, $map_params ); ?>"><i class="cmsi-map-marker text-16"></i><?php echo esc_html__('Get Directions','wiseguard'); ?></a>
                            </div>
                        </div>
                    </div>
                <?php  endforeach; ?>
            </div>
        </div>
    </div>
</div>