<?php
use Elementor\Group_Control_Image_Size;
use Elementor\Control_Media;
use Elementor\Icons_Manager;

$process = $widget->get_setting('process', []);
if(empty($process)) return;

$arrows = $widget->get_setting('arrows', '');
$dots = $widget->get_setting('dots', '');
//
$thumbnail_custom_dimension = [
    'width'  => !empty($settings['image_custom_dimension']['width']) ? $settings['image_custom_dimension']['width'] : 620,
    'height' => !empty($settings['image_custom_dimension']['height']) ? $settings['image_custom_dimension']['height'] : 454
];
// Heading 
// Small Heading
$widget->add_inline_editing_attributes( 'smallheading_text' );
$widget->add_render_attribute( 'smallheading_text', [
    'class' => [
        'cms-smallheading empty-none font-700 text-16 pb-10',
        'text-'.$widget->get_setting('smallheading_color', 'accent') 
    ]
]);
// Large Heading
$widget->add_inline_editing_attributes( 'heading_text');
$widget->add_render_attribute( 'heading_text', [
    'class' => [
        'cms-heading empty-none',
        'text-'.$widget->get_setting('heading_color','heading'),
        'pb-75'
    ]
]);
// Description Bold
$widget->add_inline_editing_attributes( 'description_bold_text' );
$widget->add_render_attribute( 'description_bold_text', [
    'class' => array_filter([
        'cms-desc-bold text-17 pb-25 font-700 empty-none mt-n7',
        'text-'.$widget->get_setting('desc_bold_color','heading')
    ])
]);
// Description
$widget->add_inline_editing_attributes( 'description_text' );
$widget->add_render_attribute( 'description_text', [
    'class' => array_filter([
        'cms-desc text-17 pb-30 empty-none',
        'text-'.$widget->get_setting('desc_color','body')
    ])
]);
// Link 1
$link1_page = $widget->get_setting('link1_page','');
switch ($settings['link1_type']) {
    case 'page':
        $page = !empty($link1_page) ? get_page_by_path($link1_page, OBJECT) : [];
        $url  = !empty($page) ? get_permalink($page->ID) : '#';
        break;
    
    default:
        $url = $widget->get_setting('link1_custom', ['url' => '#'])['url'];
        break;
}
$widget->add_inline_editing_attributes( 'link1_text' );
$widget->add_render_attribute( 'link1_text', [
    'class' => [
        'btn btn-lg',
        'btn-'.$widget->get_setting('link1_color', 'secondary'),
        'btn-hover-'.$widget->get_setting('link1_color_hover', 'accent')
    ],
    'href'  => $url
]);
// Feature
$features = $widget->get_setting('cms_feature', []);
$widget->add_render_attribute('features-item',[
    'class' => [
        'cms-list d-flex gap-10 no-wrap',
        'justify-content-'.$widget->get_setting('align','start'),
        'text-16 font-700',
        'text-'.$widget->get_setting('feature_color','secondary'),
        'bdr-'.$widget->get_setting('feature_border_color', 'border')
    ]
]);
// Layout mode setting
// Carousel Settings
$widget->add_render_attribute('carousel-settings',[
    'class' => [
        'cms-process',
        'cms-process-'.$widget->get_setting('layout', '1'),
        'cms-carousel swiper',
    ]
]);
// Grid Settings
$widget->add_render_attribute('grid-settings',[
    'class' => [
        'cms-process',
        'cms-process-'.$widget->get_setting('layout', '1'),
        'cms-process-grid'
    ]
]);
// Items
$widget->add_render_attribute( 'process-item',[
    'class' => [
        'process-item',
        'relative',
        ($settings['layout_mode'] === 'carousel') ? 'cms-swiper-item swiper-slide' : 'process-item-grid',
        'hover-icon-bounce'
    ]
]);
//
$widget->add_render_attribute('count', [
    'class' => [
        'absolute top-right',
        'cms-heading font-300 text-34',
        'text-'.$widget->get_setting('count_color','border'),
        'pt-15 pr-20'
    ]
]);
$widget->add_render_attribute('title', [
    'class' => [
        'cms-heading text-19 font-500 empty-none pt-20',
        'text-'.$widget->get_setting('title_color','heading')
    ]
]);
$widget->add_render_attribute('description', [
    'class' => [
        'cms-desc text-15 pt-15 empty-none',
        'text-'.$widget->get_setting('desc_color','body'),
        'mb-n8'
    ]
]);
?>
<div class="col-7 col-tablet-10 col-mobile-extra-12 pr-70 pr-laptop-20">
    <div <?php etc_print_html( $widget->get_render_attribute_string( 'smallheading_text' ) ); ?>><?php echo nl2br( $settings['smallheading_text'] ); ?></div>
    <h2 <?php etc_print_html( $widget->get_render_attribute_string( 'heading_text' ) ); ?>><?php echo nl2br( $settings['heading_text'] ); ?></h2>
</div>
<div class="d-flex gutter">
    <div class="col-6 col-tablet-5 col-mobile-extra-12 pr-130 pr-laptop-20">
        <div class="cms-sticky">
            <div <?php etc_print_html( $widget->get_render_attribute_string( 'description_bold_text' ) ); ?>><?php echo nl2br( $settings['description_bold_text'] ); ?></div>
            <div <?php etc_print_html( $widget->get_render_attribute_string( 'description_text' ) ); ?>><?php echo nl2br( $settings['description_text'] ); ?></div>
            <?php if(!empty($settings['link1_text'])) { ?>
                <a <?php etc_print_html( $widget->get_render_attribute_string( 'link1_text' ) ); ?>>
                    <?php echo esc_html( $settings['link1_text'] ); ?>
                    <i class="cms-btn-icon cmsi-arrow-circle-right rtl-flip text-26"></i>
                </a>
            <?php } ?>
            <div class="cms-heading-features cms-lists-1 pt-80 pt-tablet-40">
                <?php 
                    foreach ( $features as $key => $cms_feature ):
                        $title_key = $widget->get_repeater_setting_key( 'title', 'cms_list', $key );
                        $widget->add_render_attribute($title_key, 'class', 'flex-basic');
                        $widget->add_inline_editing_attributes( $title_key, 'none' );
                    ?>
                        <div <?php etc_print_html($widget->get_render_attribute_string('features-item')); ?>>
                            <span class="cms-icon cmsi-check-circle text-26 text-accent flex-auto"></span>
                            <span <?php etc_print_html( $widget->get_render_attribute_string( $title_key ) ); ?>><?php echo esc_html( $cms_feature['title'] ) ?></span>
                        </div>
                    <?php endforeach;
                ?>
            </div>
        </div>
    </div>
    <div class="col-6 col-tablet-7 col-mobile-extra-12">
        <?php
            switch ($settings['layout_mode']) {
                case 'carousel':
            ?>
            <div <?php etc_print_html($widget->get_render_attribute_string('carousel-settings')); ?>>
                <div class="swiper-wrapper">
            <?php
                break;
                default:
            ?>
            <div <?php etc_print_html($widget->get_render_attribute_string('grid-settings')); ?>>
            <?php
                break;
            }
                $count = 0;
                foreach ($process as $key => $_process) {
                    $count ++;
                    if($count < 10) $count = '0'.$count;

                    $_process['image_size'] = $settings['image_size'];
                    $_process['image_custom_dimension'] = $thumbnail_custom_dimension;

                    $item_key = $widget->get_repeater_setting_key( 'item', 'cms_process_item', $key );
                    $widget->add_render_attribute( $item_key,[
                        'class' => 'swiper-slide'
                    ]);
                    ?>
                    <div <?php etc_print_html($widget->get_render_attribute_string('process-item')); ?>>
                        <?php
                        // Image
                            wiseguard_elementor_image_render($_process,[
                                'name'           => 'image',
                                'image_size_key' => 'image',
                                'img_class'      => 'cms-process-banner img-cover cms-radius-16',
                                'custom_size'    => $thumbnail_custom_dimension,
                                'before'         => '<div class="cms-gradient-primary-darken-bt cms-radius-16 overflow-hidden"><div class="cms-gradient-render"></div>',
                                'after'          => '</div>'
                            ]);
                        // Title
                        ?>
                        <div class="cms-process-content absolute bottom-left z-top ml-n40 ml-tablet-n20 mb-smobile-80 bg-white cms-radius-tltrbl-10 p-40 p-lr-smobile-20 cms-shadow-3">
                            <div class="cms-picon bg-secondary text-white text-48 cms-thumb-icon-3 absolute top-left ml-40 mt-n40"><?php 
                                wiseguard_elementor_icon_render($_process['icon'],['library' => 'wiseguard-icon', 'value' => 'wiseguard-icon-default'], ['class' => '']);
                            ?></div>
                            <div <?php etc_print_html($widget->get_render_attribute_string('title')); ?>><?php etc_print_html($_process['title']); ?></div>
                            <div <?php etc_print_html($widget->get_render_attribute_string('description')); ?>><?php etc_print_html($_process['desc']); ?></div>
                            <div <?php etc_print_html($widget->get_render_attribute_string('count')); ?>><?php echo esc_html($count); ?></div>
                        </div>
                    </div>
                <?php } 
            switch ($settings['layout_mode']) {
                case 'carousel':
            ?>
                    </div>
                <?php if ($dots == 'yes') : ?>
                    <div class="cms-carousel-dots cms-carousel-dots-out empty-none"></div>
                <?php endif ?>
                <?php if ($arrows == 'yes') : ?>
                    <div class="cms-carousel-buttons-1 white d-flex gap-30 absolute bottom-right z-top mr-40 mb-15">
                        <div class="cms-carousel-button prev cms-carousel-button-prev">
                            <i class="cms-button-arrow-hover cmsi-long-arrow-left-2"></i>
                            <span class="cms-button-arrow-text">
                                <?php
                                    $icon_settings = $widget->get_settings_for_display('arrow_prev_icon');
                                    if (empty($icon_settings['value'])) {
                                        $icon_settings = [
                                            'library' => 'cmsi',
                                            'value'   => 'cmsi-arrow-left',
                                        ];
                                    }
                                    Icons_Manager::render_icon($icon_settings, ['aria-hidden' => 'true','class' => 'rtl-flip text-10']);
                                ?>
                                <?php esc_html_e('Prev','wiseguard') ?>
                            </span>
                        </div>
                        <div class="cms-carousel-button next cms-carousel-button-next">
                            <i class="cms-button-arrow-hover cmsi-long-arrow-right-2"></i>
                            <span class="cms-button-arrow-text">
                                <?php esc_html_e('Next','wiseguard') ?>
                                <?php
                                    $icon_settings = $widget->get_settings_for_display('arrow_next_icon');
                                    if (empty($icon_settings['value'])) {
                                        $icon_settings = [
                                            'library' => 'cmsi',
                                            'value'   => 'cmsi-arrow-right',
                                        ];
                                    }
                                    Icons_Manager::render_icon($icon_settings, ['aria-hidden' => 'true', 'class' => 'rtl-flip text-10']);
                                ?>
                            </span>
                        </div>
                    </div>
                <?php endif ?>
            </div>
            <?php
                break;
                default:
            ?>
            </div>
            <?php
                break;
            }
        ?>
    </div>
</div>
