<?php
$progressbar_list = $widget->get_setting('progressbar_list',[]);
// wrap
$widget->add_render_attribute('wrap', [
	'class' => [
		'cms-eprogress-bar',
		'cms-eprogress-bar-'.$settings['layout'],
	]
]);
// Large Heading
$widget->add_inline_editing_attributes( 'heading_text');
$widget->add_render_attribute( 'heading_text', [
	'class' => [
		'cms-heading empty-none lh-1375',
		'text-'.$widget->get_setting('heading_color','heading'),
		'pb-25'
	]
]);
// Description Bold
$widget->add_inline_editing_attributes( 'description_bold_text' );
$widget->add_render_attribute( 'description_bold_text', [
	'class' => array_filter([
		'cms-desc-bold text-17 pb-25 font-700 empty-none',
		'text-'.$widget->get_setting('description_bold_color','primary')
	])
]);
// Description
$widget->add_inline_editing_attributes( 'description_text' );
$widget->add_render_attribute( 'description_text', [
	'class' => array_filter([
		'cms-desc text-17 empty-none',
		'text-'.$widget->get_setting('description_color','body'),
		'pb-25'
	])
]);
// Link 1
$link1_page = $widget->get_setting('link1_page','');
switch ($settings['link1_type']) {
	case 'page':
		$page = !empty($link1_page) ? get_page_by_path($link1_page, OBJECT) : [];
		$link1_url  = !empty($page) ? get_permalink($page->ID) : '#';
		break;
	
	default:
		$link1_url = $widget->get_setting('link1_custom', ['url' => '#'])['url'];
		break;
}
$widget->add_inline_editing_attributes( 'link1_text' );
$widget->add_render_attribute( 'link1_text', [
	'class' => [
		'btn btn-lg',
		'btn-primary-lighten btn-hover-secondary'
	],
	'href'	=> $link1_url
]);
// Signature
$savatar_class = wiseguard_nice_class(['savatar', 'circle']);
//
$widget->add_inline_editing_attributes( 'sname' );
$widget->add_render_attribute('sname', [
	'class' => [
		'sname',
		'cms-heading text-17',
	]
]);
//
$widget->add_inline_editing_attributes( 'sposition' );
$widget->add_render_attribute('sposition', [
	'class' => [
		'sposition',
		'text-14 text-secondary-lighten',
	]
]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
	<h2 <?php etc_print_html( $widget->get_render_attribute_string( 'heading_text' ) ); ?>><?php echo nl2br( $settings['heading_text'] ); ?></h2>
	<div <?php etc_print_html( $widget->get_render_attribute_string( 'description_bold_text' ) ); ?>><?php echo nl2br( $settings['description_bold_text'] ); ?></div>
	<div <?php etc_print_html( $widget->get_render_attribute_string( 'description_text' ) ); ?>><?php echo nl2br( $settings['description_text'] ); ?></div>
	<?php foreach ( $progressbar_list as $key => $progressbar ):
		$title_key        = $widget->get_repeater_setting_key( 'title', 'progressbar_list', $key );
		$wrapper_key      = $widget->get_repeater_setting_key( 'wrapper', 'progressbar_list', $key );
		$progress_bar_key = $widget->get_repeater_setting_key( 'progress_bar', 'progressbar_list', $key );
		
		$widget->add_inline_editing_attributes( $title_key );
		$widget->add_render_attribute( $title_key, [
			'class'=>[
				'cms-progress-bar-title',
				'text-15 font-700 text-primary',
				'pb-10',
				'd-flex justify-content-between no-wrap'
			],
			'style' => 'width:'.$progressbar['percent']['size'].'%'
		]);

		$widget->add_render_attribute( $wrapper_key, [
			'class'         => 'cms-progress-wrap bg-'.$widget->get_setting('progress_color','grey'),
			'role'          => 'progressbar',
			'aria-valuemin' => '0',
			'aria-valuemax' => '100',
			'aria-valuenow' => $progressbar['percent']['size'],
		] );

		if ( ! empty( $progressbar['progress_type'] ) ) {
			$widget->add_render_attribute( $wrapper_key, 'class', 'progress-' . $progressbar['progress_type'] );
		}

		$widget->add_render_attribute( $progress_bar_key, [
			'class'    => 'cms-progress-bar bg-'.$widget->get_setting('progressbar_color','accent'),
			'data-max' => $progressbar['percent']['size'],
		] );
		?>
		<div class="cms-progress-bar-wrap">
			<?php if ( ! empty( $progressbar['title'] ) ) { ?>
	            <div <?php etc_print_html( $widget->get_render_attribute_string( $title_key ) ); ?>>
	            	<?php echo esc_html( $progressbar['title'] ); ?>
	            	<span><span class="cms-progress-bar-number text-14 text-body" data-duration="2000" data-delimiter="" data-to-value="<?php echo esc_attr($progressbar['percent']['size']); ?>"></span>%</span>	
	            </div>
			<?php } ?>
	        <div <?php etc_print_html( $widget->get_render_attribute_string( $wrapper_key ) ); ?>>
	            <div <?php etc_print_html( $widget->get_render_attribute_string( $progress_bar_key ) ); ?>>
	            	<span class="cms-progress-bar-number" data-duration="2000" data-delimiter="" data-to-value="<?php echo esc_attr($progressbar['percent']['size']); ?>"></span>%
	            </div>
	        </div>
	    </div>
	<?php endforeach; ?>
	<div class="d-flex gap-30 pt-15">
		<?php if(!empty($settings['link1_text'])) { ?>
			<a <?php etc_print_html( $widget->get_render_attribute_string( 'link1_text' ) ); ?>>
				<?php echo esc_html( $settings['link1_text'] ); ?>
				<i class="cms-btn-icon cmsi-arrow-circle-right rtl-flip text-26"></i>
			</a>
		<?php } ?>
		<div class="cms-signature d-flex gap-10 align-items-center">
			<?php wiseguard_elementor_image_render($settings, [
				'name'        => 'savatar',
				'custom_size' => ['width'=>52, 'height'=>52],
				'img_class'   => $savatar_class,
				'before'      => '<div class="savatars circle outline-1">',
				'after'       => '</div>'
				]); ?>
				<div class="stext flex-auto relative">
					<?php 
						wiseguard_elementor_image_render($settings, [
							'name'        => 'simage',
							'size'        => 'full',
							'custom_size' => ['width'=>'','height'=>'']
						]);
					?>
					<div class="cms--signature absolute center">
 					<div <?php etc_print_html($widget->get_render_attribute_string('sname')); ?>><?php echo nl2br($settings['sname']); ?></div>
 					<div <?php etc_print_html($widget->get_render_attribute_string('sposition')); ?>><?php echo nl2br($settings['sposition']); ?></div>
 				</div>
				</div>
		</div>
	</div>
</div>