<?php
	// Wrap attribute
	$align = wiseguard_elementor_get_alignment_class($widget, $settings, ['name' => 'align', 'prefix_class' => 'justify-content-']);
	$widget->add_render_attribute('wraps', [
		'class' => array_filter([
			'cms-eqc',
			'cms-eqc-'.$settings['layout'],
			'd-flex gap-30 gap-smobile-10',
			'text-13',
			$align
		])
	]);
	// Adress
	$icon_address_color = $widget->get_setting('icon_address_color', 'primary');
	$address     = $settings['address'];
	$map_zoom    = 14;
	$map_api_key = wiseguard_get_opt('gm_api_key');
	$map_params  = [
	    rawurlencode( $address ),
	    absint( $map_zoom )
	];
	$map_url = 'https://maps.google.com/maps?q=%1$s&amp;t=m&amp;z=%2$d&amp;iwloc=near';
	
	$widget->add_render_attribute( 'address-item', [
		'class' => [
			'cms-eqc-item',
			'd-flex align-items-center gap-10',
			'cms-address',
			'text-'.$settings['address_color'],
			'text-hover-'.$icon_address_color
		],
		'href'   => vsprintf( $map_url, $map_params ),
		'target' => '_blank'
	]);
	// address icon
	$widget->add_render_attribute( 'address-icon', [
		'class' => [
			'cms-icon',
			'cms-icon-color',
			'text-'.$icon_address_color,
			'cmsi-map-marker'
		]
	]);
	// address title
	$widget->add_inline_editing_attributes( 'address_title' );
	$widget->add_render_attribute( 'address_title', [
		'class' => [
			'cms-address-title',
			'cms-icon-color',
			'text-'.$icon_address_color,
			wiseguard_add_hidden_device_controls_render($settings, 'title_'),
			'empty-none'
		]
	]);
	// address
	$widget->add_inline_editing_attributes( 'address' );
	$widget->add_render_attribute( 'address', [
		'class' => [
			'cms-address-text',
			wiseguard_add_hidden_device_controls_render($settings, 'title_')
		]
	]);
	// Email
		$icon_email_color = $widget->get_setting('icon_email_color', 'primary');
		$widget->add_render_attribute( 'email-item', [
			'class' => [
				'cms-eqc-item',
				'd-flex align-items-center gap-10',
				'cms-email',
				'text-'.$settings['email_color'],
				'text-hover-'.$icon_email_color
			],
			'href'   => 'mailto:'.$settings['email'],
			'target' => '_blank'
		]);
		// email icon
		$widget->add_render_attribute( 'email-icon', [
			'class' => [
				'cms-icon',
				'cms-icon-color',
				'text-'.$icon_email_color,
				'cmsi-email'
			]
		]);
		// email title
		$widget->add_inline_editing_attributes( 'email_title' );
		$widget->add_render_attribute( 'email_title', [
			'class' => [
				'cms-email-title',
				'cms-icon-color',
				'text-'.$icon_email_color,
				wiseguard_add_hidden_device_controls_render($settings, 'title_'),
				'empty-none'
			]
		]);
		// email
		$widget->add_inline_editing_attributes( 'email' );
		$widget->add_render_attribute( 'email', [
			'class' => [
				'cms-email-text',
				wiseguard_add_hidden_device_controls_render($settings, 'title_')
			]
		]);
	// Phone
	$icon_phone_color = $widget->get_setting('icon_phone_color', 'primary');
	$phone_link  = str_replace(' ', '', $settings['phone']);
	$widget->add_render_attribute( 'phone-item',[ 
		'class' => [
			'cms-eqc-item',
			'd-flex align-items-center gap-10',
			'cms-phone',
			'text-'.$settings['phone_color'],
			'text-hover-'.$icon_phone_color
		],
		'href' => 'tel:'.$phone_link
	]);
		// phone icon
		$widget->add_render_attribute( 'phone-icon', [
			'class' => [
				'cms-icon',
				'cms-icon-color',
				'text-'.$icon_email_color,
				'cmsi-phone-alt'
			]
		]);
		// phone title
		$widget->add_inline_editing_attributes('phone_title');
		$widget->add_render_attribute( 'phone_title',[ 
			'class' => [
				'cms-phone-title',
				'cms-icon-color',
				'text-'.$icon_phone_color,
				wiseguard_add_hidden_device_controls_render($settings, 'title_'),
				'empty-none'
			]
		]);
		// phone number
		$widget->add_inline_editing_attributes('phone');
		$widget->add_render_attribute( 'phone',[ 
			'class' => [
				'cms-phone-text',
				wiseguard_add_hidden_device_controls_render($settings, 'title_')
			]
		]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wraps')); ?>>
	<?php 
	// Email
	if(!empty($settings['email'])){
	?>
	<a <?php etc_print_html( $widget->get_render_attribute_string( 'email-item' ) ); ?>>
		<span <?php etc_print_html($widget->get_render_attribute_string('email-icon')); ?>></span>
		<span <?php etc_print_html($widget->get_render_attribute_string('email_title')); ?>><?php echo esc_html($settings['email_title']); ?></span>
		<span <?php etc_print_html($widget->get_render_attribute_string('email')); ?>><?php echo esc_html($settings['email']); ?></span>
	</a>
	<?php }
	// Phone
	if(!empty($settings['phone'])) { ?>
		<a <?php etc_print_html( $widget->get_render_attribute_string( 'phone-item' ) ); ?>>
			<span <?php etc_print_html($widget->get_render_attribute_string('phone-icon')); ?>></span>
				<span <?php etc_print_html($widget->get_render_attribute_string('phone_title')); ?>><?php echo esc_html($settings['phone_title']); ?></span>
				<span <?php etc_print_html($widget->get_render_attribute_string('phone')); ?>><?php echo esc_html($settings['phone']); ?></span>
		</a>
	<?php } 
	// Address
	if(!empty($address)) { ?>
		<a <?php etc_print_html( $widget->get_render_attribute_string( 'address-item' ) ); ?>>
			<span <?php etc_print_html($widget->get_render_attribute_string('address-icon')); ?>></span>
			<span <?php etc_print_html($widget->get_render_attribute_string('address_title')); ?>><?php echo esc_html($settings['address_title']); ?></span>
			<span <?php etc_print_html($widget->get_render_attribute_string('address')); ?>><?php echo esc_html($settings['address']); ?></span>
		</a>
	<?php } ?>
</div>