<?php
	// Wrap attribute
	$align = wiseguard_elementor_get_alignment_class($widget, $settings, ['name' => 'align', 'prefix_class' => 'justify-content-']);
	$widget->add_render_attribute('wraps', [
		'class' => array_filter([
			'cms-eqc',
			'cms-eqc-'.$settings['layout'],
			'd-flex gap',
			'text-13',
			$align
		]),
		'style' => '--cms-gap:30px;--cms-gap-tablet:20px;--cms-gap-mobile:10px;'
	]);
	// Adress
	$icon_address_color = $widget->get_setting('icon_address_color', 'primary');
	$address     = $settings['address'];
	$map_zoom    = 14;
	$map_api_key = wiseguard_get_opt('gm_api_key');
	$map_params  = [
	    rawurlencode( $address ),
	    absint( $map_zoom )
	];
	$map_url = 'https://maps.google.com/maps?q=%1$s&amp;t=m&amp;z=%2$d&amp;iwloc=near';
	
	$widget->add_render_attribute( 'address-item', [
		'class' => [
			'cms-eqc-item',
			'd-flex align-items-center gap-10',
			'cms-address',
			'text-'.$settings['address_color'],
			'text-hover-'.$icon_address_color
		],
		'href'   => vsprintf( $map_url, $map_params ),
		'target' => '_blank'
	]);
	// address icon
	$widget->add_render_attribute( 'address-icon', [
		'class' => [
			'cms-icon',
			'cms-icon-color',
			'text-'.$icon_address_color,
			'cmsi-map-marker',
			'text-16'
		]
	]);
	// address title
	$widget->add_inline_editing_attributes( 'address_title' );
	$widget->add_render_attribute( 'address_title', [
		'class' => [
			'cms-address-title',
			'cms-icon-color',
			'text-'.$icon_address_color,
			wiseguard_add_hidden_device_controls_render($settings, 'title_')
		]
	]);
	// address
	$widget->add_inline_editing_attributes( 'address' );
	$widget->add_render_attribute( 'address', [
		'class' => [
			'cms-address-text',
			//wiseguard_add_hidden_device_controls_render($settings, 'title_')
		]
	]);
	// Email
		$icon_email_color = $widget->get_setting('icon_email_color', 'primary');
		$widget->add_render_attribute( 'email-item', [
			'class' => [
				'cms-eqc-item',
				'd-flex align-items-center gap-10',
				'cms-email',
				'text-'.$settings['email_color'],
				'text-hover-'.$icon_email_color
			],
			'href'   => 'mailto:'.$settings['email'],
			'target' => '_blank'
		]);
		// email icon
		$widget->add_render_attribute( 'email-icon', [
			'class' => [
				'cms-icon',
				'cms-icon-color',
				'text-'.$icon_email_color,
				'cmsi-email',
				'text-16'
			]
		]);
		// email title
		$widget->add_inline_editing_attributes( 'email_title' );
		$widget->add_render_attribute( 'email_title', [
			'class' => [
				'cms-email-title',
				'cms-icon-color',
				'text-'.$icon_email_color,
				wiseguard_add_hidden_device_controls_render($settings, 'title_')
			]
		]);
		// email
		$widget->add_inline_editing_attributes( 'email' );
		$widget->add_render_attribute( 'email', [
			'class' => [
				'cms-email-text',
				//wiseguard_add_hidden_device_controls_render($settings, 'title_')
			]
		]);
	// Time
		$icon_time_color = $widget->get_setting('icon_time_color', 'primary');
		$widget->add_render_attribute( 'time-item', [
			'class' => [
				'cms-eqc-item',
				'd-flex align-items-center gap-10',
				'cms-time',
				'text-'.$settings['time_color'],
				'text-hover-'.$icon_email_color
			]
		]);
		// time icon
		$widget->add_render_attribute( 'time-icon', [
			'class' => [
				'cms-icon',
				'cms-icon-color',
				'text-'.$icon_email_color,
				'cmsi-clock',
				'text-16'
			]
		]);
		// time title
		$widget->add_inline_editing_attributes( 'time_title' );
		$widget->add_render_attribute( 'time_title', [
			'class' => [
				'cms-time-title',
				'cms-icon-color',
				'text-'.$icon_email_color,
				wiseguard_add_hidden_device_controls_render($settings, 'title_')
			]
		]);
		// time
		$widget->add_inline_editing_attributes( 'time' );
		$widget->add_render_attribute( 'time', [
			'class' => [
				'cms-time-text',
				//wiseguard_add_hidden_device_controls_render($settings, 'title_')
			]
		]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wraps')); ?>>
	<?php if(!empty($address)) { ?>
		<a <?php etc_print_html( $widget->get_render_attribute_string( 'address-item' ) ); ?>>
			<span <?php etc_print_html($widget->get_render_attribute_string('address-icon')); ?>></span>
			<span <?php etc_print_html($widget->get_render_attribute_string('address_title')); ?>><?php echo esc_html($settings['address_title']); ?></span>
			<span <?php etc_print_html($widget->get_render_attribute_string('address')); ?>><?php echo esc_html($settings['address']); ?></span>
		</a>
	<?php }
		if(!empty($settings['email'])){
	?>
	<a <?php etc_print_html( $widget->get_render_attribute_string( 'email-item' ) ); ?>>
		<span <?php etc_print_html($widget->get_render_attribute_string('email-icon')); ?>></span>
		<span <?php etc_print_html($widget->get_render_attribute_string('email_title')); ?>><?php echo esc_html($settings['email_title']); ?></span>
		<span <?php etc_print_html($widget->get_render_attribute_string('email')); ?>><?php echo esc_html($settings['email']); ?></span>
	</a>
	<?php } 
		if(!empty($settings['time'])){
	?>
	<span <?php etc_print_html( $widget->get_render_attribute_string( 'time-item' ) ); ?>>
		<span <?php etc_print_html($widget->get_render_attribute_string('time-icon')); ?>></span>
		<span <?php etc_print_html($widget->get_render_attribute_string('time_title')); ?>><?php echo esc_html($settings['time_title']); ?></span>
		<span <?php etc_print_html($widget->get_render_attribute_string('time')); ?>><?php echo esc_html($settings['time']); ?></span>
	</span>
	<?php } ?>
</div>