<?php
use Elementor\Icons_Manager;

$settings['num_words'] = !empty($settings['num_words']) ? $settings['num_words'] : 30;
$settings['readmore_text'] = !empty($settings['readmore_text']) ? $settings['readmore_text'] : esc_html__('Read More', 'wiseguard');

$html_id  = etc_get_element_id($settings);
$source   = $widget->get_setting('source', '');
$orderby  = $widget->get_setting('orderby', 'date');
$order    = $widget->get_setting('order', 'desc');
$limit    = $widget->get_setting('limit', 6);
extract(etc_get_posts_of_grid( 'cms-service', [
    'source'   => $source,
    'orderby'  => $orderby,
    'order'    => $order,
    'limit'    => $limit
]));

$arrows = $widget->get_setting('arrows');
$dots   = $widget->get_setting('dots');

$title_tag = $widget->get_setting('title_tag', 'h3');

$thumbnail_size             = $widget->get_setting('thumbnail_size', 'custom');
$thumbnail_custom_dimension = [
    'width'  => !empty($settings['thumbnail_custom_dimension']['width']) ? $settings['thumbnail_custom_dimension']['width'] : 400,
    'height' => !empty($settings['thumbnail_custom_dimension']['height']) ? $settings['thumbnail_custom_dimension']['height'] : 267
];
$num_words                  = $widget->get_setting('num_words', '');
$readmore_text              = $settings['readmore_text'];

$posts_data = array(
    'layout'                     => $widget->get_setting('layout', '2'),
    'taxonomy'                   => 'service-category',
    'source'                     => $source,
    'orderby'                    => $orderby,
    'order'                      => $order,
    'limit'                      => $limit,
    'thumbnail_size'             => $thumbnail_size,
    'thumbnail_custom_dimension' => $thumbnail_custom_dimension,
    'num_words'                  => $num_words,
    'readmore_text'              => $readmore_text
);

// Wrap
$widget->add_render_attribute('wrap',[
    'id'              => $html_id,
    'class'           => [
        'cms-post-carousel',
        'cms-grid', 
        'cms-service-grid', 
        'cms-grid-'.$widget->get_setting('layout','2')
    ]
]);
// Call To Action
$widget->add_inline_editing_attributes( 'text' );
$widget->add_inline_editing_attributes( 'link_text' );
// Wrap
$widget->add_render_attribute('cta-wrap', [
    'class' => array_filter([
        'cms-cta',
        'text-15 font-700',
        'text-center pt-35 mb-n20'
    ])
]);
// Text
$widget->add_render_attribute('text', [
    'class' => [
        'cms-desc',
        'text-'.$widget->get_setting('text_color','body')
    ]
]);

// Link
$page_link = $widget->get_setting('page_link','');
switch ($settings['link_type']) {
    case 'page':
        $page = !empty($page_link) ? get_page_by_path($page_link, OBJECT) : [];
        $url  = !empty($page) ? get_permalink($page->ID) : '#';
        break;
    
    default:
        $url = $widget->get_setting('custom_link', ['url' => '#'])['url'];
        break;
}
$widget->add_render_attribute( 'link_text', [
    'class' => [
        'cms-link',
        'cms-link-2',
        'text-'.$widget->get_setting('link_color','secondary'),
        'text-hover-'.$widget->get_setting('link_color_hover','accent')
    ],
    'href'  => $url
]);
?>
<div <?php etc_print_html($widget->get_render_attribute_string('wrap')); ?>>
    <div class="cms-carousel swiper">
        <div class="swiper-wrapper">
            <?php
                wiseguard_get_post_grid($settings, $posts, $posts_data,[
                    'item_class' => 'cms-swiper-item swiper-slide'
                ]);
            ?>
        </div>
    </div>
    <?php if ($arrows == 'yes') : ?>
        <div class="cms-carousel-button-in-vert prev cms-carousel-button-prev">
            <?php
            $icon_settings = $widget->get_settings_for_display('arrow_prev_icon');
            if (empty($icon_settings['value'])) {
                $icon_settings = [
                    'library' => 'eicons',
                    'value'   => 'eicon-chevron-left',
                ];
            }
            Icons_Manager::render_icon($icon_settings, ['aria-hidden' => 'true']);
            ?>
        </div>
        <div class="cms-carousel-button-in-vert next cms-carousel-button-next">
            <?php
            $icon_settings = $widget->get_settings_for_display('arrow_next_icon');
            if (empty($icon_settings['value'])) {
                $icon_settings = [
                    'library' => 'eicons',
                    'value'   => 'eicon-chevron-right',
                ];
            }
            Icons_Manager::render_icon($icon_settings, ['aria-hidden' => 'true']);
            ?>
        </div>
    <?php endif ?>
    <?php if ($dots == 'yes') : ?>
        <div class="cms-carousel-dots cms-carousel-dots-out justify-content-center"></div>
    <?php endif ?>
    <div <?php etc_print_html($widget->get_render_attribute_string('cta-wrap')); ?>>
        <span <?php etc_print_html($widget->get_render_attribute_string('text')) ?>><?php etc_print_html($settings['text']) ?></span>
        <?php if($settings['link_text']!==''): ?><a <?php etc_print_html( $widget->get_render_attribute_string( 'link_text' ) ); ?>>
            <?php 
                // text
                echo esc_html( $settings['link_text'] );
            ?><i class="cmsi-arrow-right rtl-flip text-10"></i>
        </a><?php endif; ?>
    </div>
</div>