<?php
class CSS_Generator {
	/**
	 * scssc class instance
	 *
	 * @access protected
	 * @var scssc
	 */
	protected $scssc = null;

	/**
	 * Debug mode is turn on or not
	 *
	 * @access protected
	 * @var boolean
	 */
	protected $dev_mode = true;

	/**
	 * opt_name
	 *
	 * @access protected
	 * @var string
	 */
	protected $opt_name = '';

	/**
	 * Constructor
	 */
	function __construct() {
		$this->opt_name = wiseguard_get_opt_name();

		if ( empty( $this->opt_name ) ) {
			return;
		}
		$this->dev_mode = wiseguard_get_opt( 'dev_mode', '0' ) === '1' ? true : false;
		add_filter( 'cms_scssc_on', function(){ return $this->dev_mode;} );
		add_filter( 'cms_scssc_lib', function(){ return 'new'; });
		add_action( 'init', array( $this, 'init' ) );
		//add_action( 'wp_enqueue_scripts', array( $this, 'enqueue' ), 20 );
	}

	/**
	 * init hook - 10
	 */
	function init() {
		
		if ( !class_exists( '\Leafo\ScssPhp\Compiler' ) )
        {
            return;
        }
		add_action( 'wp', array( $this, 'generate_with_dev_mode' ) );
	}

	function generate_with_dev_mode() {
		if ( $this->dev_mode === true ) {
			$this->generate_file();
		}
	}

	/**
	 * Generate options and css files
	 */
	function generate_file() {
		require_once(ABSPATH . 'wp-admin/includes/file.php');
        global $wp_filesystem;
        if ( ! is_a( $wp_filesystem, 'WP_Filesystem_Base') ){
            $creds = request_filesystem_credentials( site_url() );
            wp_filesystem($creds);
        }

		$scss_dir = get_template_directory() . '/assets/scss/';
		$css_dir  = get_template_directory() . '/assets/css/';

		$this->scssc = new \Leafo\ScssPhp\Compiler();
		$this->scssc->setImportPaths( $scss_dir );

		$_options = $scss_dir . 'theme_variables.scss';
		$wp_filesystem->put_contents(
            $_options,
            preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->options_output() ),
           FS_CHMOD_FILE
        );

		$css_file = $css_dir . 'theme.css';
		// scss_formatter  or scss_formatter_compressed
		$this->scssc->setFormatter( 'Leafo\ScssPhp\Formatter\Crunched' );
		$wp_filesystem->put_contents(
            $css_file,
            preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "theme.scss"' ) ),
            FS_CHMOD_FILE
        );
	}
	protected function options_output() {
		ob_start();
        // single css options
        printf('%s', $this->print_single_scss_opt());
        // Theme Colors
        printf('%s', $this->print_theme_colors());
		return ob_get_clean();
	}
	protected function print_single_scss_opt() {
        ob_start();
        $accent_color = wiseguard_configs('accent_color');
        $primary_color = wiseguard_configs('primary_color');
        $secondary_color = wiseguard_configs('secondary_color');
        // color
        foreach ($accent_color as $key => $value) {
            printf('$accent_color_%1$s: %2$s;', str_replace(['#',' '], [''],$key), $value );
        }
        foreach ($primary_color as $key => $value) {
            printf('$primary_color_%1$s: %2$s;', str_replace(['#',' '], [''],$key), $value );
        }
        foreach ($secondary_color as $key => $value) {
            printf('$secondary_color_%1$s: %2$s;', str_replace(['#',' '], [''],$key), $value );
        }
        return ob_get_clean();
    }
    protected function print_theme_colors(){
    	$color = wiseguard_theme_colors();
    	$_color = [];
    	unset($color['']);
    	unset($color['custom']);
    	unset($color['white']);
    	foreach ($color as $key => $value) {
    		$_color[] = '\''.$key.'\'';
    	}
    	return '$cms_theme_colors:('.implode(',',$_color).')';
    }
}

new CSS_Generator();