<?php
/**
 * Helper functions for the theme
 *
 * @package WiseGuard
 */

/**
 * Check is Blog page
 * 
 * */
if(!function_exists('cms_is_blog')){
    function cms_is_blog(){
        if(is_home() || is_archive() || is_category() || is_tag() || is_author() || is_date() || is_post_type_archive() || is_tax() || is_search() ){
            return true;
        } else {
            return false;
        }
    }
}
/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 *
 * @return array
 */
function wiseguard_body_classes($classes){
    $classes[] = wiseguard_is_built_with_elementor() ? 'cms-is-elementor' : 'cms-not-elementor';
    $classes[] = (wiseguard_get_opt('sidebar_on', 'off') === 'on') ? 'cms-has-sidebar' : 'cms-not-sidebar';
    $classes[] = cms_is_blog() ? 'cms-blog-page' : '';
    $classes[] = 'cms-heading-font-'.wiseguard_get_opts('heading_font','default');
    return $classes;
}
add_filter('body_class', 'wiseguard_body_classes');


function wiseguard_archive_title_remove_label($title){
    if (is_category()) {
        $title = single_cat_title('', false);
    } elseif (is_tag()) {
        $title = single_tag_title('', false);
    } elseif (is_author()) {
        $title = get_the_author();
    } elseif (is_post_type_archive()) {
        $title = post_type_archive_title('', false);
    } elseif (is_tax()) {
        $title = single_term_title('', false);
    } elseif (is_home()) {
        $title = single_post_title('', false);
    }
    return $title;
}
add_filter('get_the_archive_title', 'wiseguard_archive_title_remove_label');
/**
 * Custom Post Type
 * 
 * **/
add_filter('cms_extra_post_types', 'wiseguard_add_posttype');
if(!function_exists('wiseguard_add_posttype')){
    function wiseguard_add_posttype($postypes){
        $portfolio      = wiseguard_get_opt('portfolio_slug', 'portfolio');
        $portfolio_name = wiseguard_get_opt(
            'portfolio_name',
            esc_attr__('Portfolio', 'wiseguard')
        );
        $postypes['portfolio'] = [
            'status'     => apply_filters('wiseguard_enable_portfolio', false),
            'item_name'  => $portfolio_name,
            'items_name' => $portfolio_name,
            'args' => [
                'menu_icon'          => 'dashicons-admin-post',
                'supports'           => ['title', 'thumbnail', 'editor','excerpt'],
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => [
                    'slug' => $portfolio,
                ],
            ],
            'labels' => [],
        ];
        // Service
        $postypes['cms-service'] = [
            'status'     => apply_filters('wiseguard_enable_service', true),
            'item_name'  => esc_html__('Service', 'wiseguard'),
            'items_name' => esc_html__('Services', 'wiseguard'),
            'args' => [
                'menu_icon'          => 'dashicons-admin-post',
                'supports'           => ['title', 'thumbnail', 'editor', 'excerpt'],
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => [
                    'slug' => apply_filters('wiseguard_cms_service_slug', 'service'),
                ],
            ],
            'labels' => [],
        ];
        // Industry
        $postypes['cms-industry'] = [
            'status'     => apply_filters('wiseguard_enable_industry', true),
            'item_name'  => esc_html__('Industry', 'wiseguard'),
            'items_name' => esc_html__('Industrys', 'wiseguard'),
            'args' => [
                'menu_icon'          => 'dashicons-admin-post',
                'supports'           => ['title', 'thumbnail', 'editor', 'excerpt'],
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => [
                    'slug' => apply_filters('wiseguard_cms_industry_slug', 'industry'),
                ],
            ],
            'labels' => [],
        ];
        // Case
        $postypes['cms-case'] = [
            'status'     => apply_filters('wiseguard_enable_case', true),
            'item_name'  => esc_html__('Case', 'wiseguard'),
            'items_name' => esc_html__('Cases', 'wiseguard'),
            'args' => [
                'menu_icon'          => 'dashicons-admin-post',
                'supports'           => ['title', 'thumbnail', 'editor', 'excerpt'],
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => [
                    'slug' => apply_filters('wiseguard_cms_case_slug', 'cases'),
                ],
            ],
            'labels' => [],
        ];
        // career
        $postypes['cms-career'] = [
            'status'     => apply_filters('wiseguard_enable_career', true),
            'item_name'  => esc_html__('Career', 'wiseguard'),
            'items_name' => esc_html__('Careers', 'wiseguard'),
            'args' => [
                'menu_icon'          => 'dashicons-admin-post',
                'supports'           => ['title', 'thumbnail', 'editor', 'excerpt'],
                'public'             => true,
                'publicly_queryable' => true,
                'rewrite'            => [
                    'slug' => apply_filters('wiseguard_cms_career_slug', 'career'),
                ],
            ],
            'labels' => [],
        ];
        // Header Top
        $postypes['cms-header-top'] = [
            'status'     => apply_filters('wiseguard_enable_header_top', true),
            'item_name'  => esc_html__('Header Top', 'wiseguard'),
            'items_name' => esc_html__('Headers Top', 'wiseguard'),
            'args'       => [
                'menu_icon'          => 'dashicons-editor-insertmore',
                'supports'           => ['title', 'editor', 'thumbnail'],
                'public'             => true,
                'publicly_queryable' => true,
            ],
            'labels' => [],
        ];
        // Side Nav
        $postypes['cms-sidenav'] = [
            'status'     => apply_filters('wiseguard_enable_sidenav', true),
            'item_name'  => esc_html__('Side Nav', 'wiseguard'),
            'items_name' => esc_html__('Side Navs', 'wiseguard'),
            'args'       => [
                'menu_icon'          => 'dashicons-editor-insertmore',
                'supports'           => ['title', 'editor', 'thumbnail'],
                'public'             => true,
                'publicly_queryable' => true,
            ],
            'labels' => [],
        ];
        // Footer
        $postypes['cms-footer'] = [
            'status'     => apply_filters('wiseguard_enable_footer', true),
            'item_name'  => esc_html__('Footer', 'wiseguard'),
            'items_name' => esc_html__('Footers', 'wiseguard'),
            'args'       => [
                'menu_icon'          => 'dashicons-editor-insertmore',
                'supports'           => ['title', 'editor', 'thumbnail'],
                'public'             => true,
                'publicly_queryable' => true,
            ],
            'labels' => [],
        ];

        return $postypes;
    }
}
add_filter('cms_extra_taxonomies', 'wiseguard_add_tax');
if(!function_exists('wiseguard_add_tax')){
    function wiseguard_add_tax($taxonomies){
        $taxonomies['portfolio-category'] = [
            'status'      => apply_filters('wiseguard_enable_portfolio', false),
            'post_type'   => ['portfolio'],
            'taxonomy'    => esc_html__('Portfolio Category', 'wiseguard'),
            'taxonomies'  => esc_html__('Portfolio Categories', 'wiseguard'),
            'args'        => [],
            'labels'      => [],
        ];
        $taxonomies['service-category'] = [
            'status'      => apply_filters('wiseguard_enable_service', true),
            'post_type'   => ['cms-service'],
            'taxonomy'    => esc_html__('Service Category', 'wiseguard'),
            'taxonomies'  => esc_html__('Service Categories', 'wiseguard'),
            'args'        => [],
            'labels'      => [],
        ];
        $taxonomies['industry-category'] = [
            'status'      => apply_filters('wiseguard_enable_industry', true),
            'post_type'   => ['cms-industry'],
            'taxonomy'    => esc_html__('Industry Category', 'wiseguard'),
            'taxonomies'  => esc_html__('Industry Categories', 'wiseguard'),
            'args'        => [],
            'labels'      => [],
        ];
         $taxonomies['case-category'] = [
            'status'      => apply_filters('wiseguard_enable_case', true),
            'post_type'   => ['cms-case'],
            'taxonomy'    => esc_html__('Case Category', 'wiseguard'),
            'taxonomies'  => esc_html__('Case Categories', 'wiseguard'),
            'args'        => [],
            'labels'      => [],
        ];
        return $taxonomies;
    }
}

/**
 * Enable mega menu
 **/
add_filter('cms_enable_megamenu', 'wiseguard_enable_megamenu');
if(!function_exists('wiseguard_enable_megamenu')){
    function wiseguard_enable_megamenu(){
        return true;
    }
}
/* Enable onepage */
add_filter('cms_enable_onepage', 'wiseguard_enable_onepage');
if(!function_exists('wiseguard_enable_onepage')){
    function wiseguard_enable_onepage(){
        return false;
    }
}
/**
 * Pagination Ajax
 * **/
add_action('wp_ajax_wiseguard_get_pagination_html', 'wiseguard_get_pagination_html');
add_action('wp_ajax_nopriv_wiseguard_get_pagination_html', 'wiseguard_get_pagination_html');
if (!function_exists('wiseguard_get_pagination_html')) {
    function wiseguard_get_pagination_html()
    {
        try {
            if (!isset($_POST['query_vars'])) {
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'wiseguard'));
            }
            $query = $_POST['query_vars'];
            if(isset($_POST['filter']) && !empty($_POST['filter'])){
                $query['tax_query'] = [
                    'relation'       => 'OR',
                ];
                $tmp = explode('|', $_POST['filter']);
                if (isset($tmp[0]) && isset($tmp[1])) {
                    $query['tax_query'][] = array(
                        'taxonomy' => $tmp[1],
                        'field' => 'slug',
                        'operator' => 'IN',
                        'terms' => array($tmp[0]),
                    );
                }
            }
            $query = new WP_Query($query);
            ob_start();
            wiseguard_posts_pagination($query, true);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => esc_html__('Load Successfully!', 'wiseguard'),
                    'data' => array(
                        'html' => $html,
                        'query_vars' => $_POST['query_vars'],
                        'post' => $query->have_posts()
                    ),
                )
            );
        } catch (Exception $e) {
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}
add_action('wp_ajax_wiseguard_load_more_post_grid', 'wiseguard_load_more_post_grid');
add_action('wp_ajax_nopriv_wiseguard_load_more_post_grid', 'wiseguard_load_more_post_grid');
if (!function_exists('wiseguard_load_more_post_grid')) {
    function wiseguard_load_more_post_grid()
    {
        try {
            if (!isset($_POST['settings'])) {
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'wiseguard'));
            }
            $settings = $_POST['settings'];
            set_query_var('paged', $settings['paged']);
            extract(etc_get_posts_of_grid($settings['posttype'], [
                'source' => isset($settings['source']) ? $settings['source'] : '',
                'orderby' => isset($settings['orderby']) ? $settings['orderby'] : 'date',
                'order' => isset($settings['order']) ? $settings['order'] : 'desc',
                'limit' => isset($settings['limit']) ? $settings['limit'] : '6',
                'post_ids' => '',
            ]));
            ob_start();
            wiseguard_get_post_grid($settings, $posts, $settings);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => esc_html__('Load Successfully!', 'wiseguard'),
                    'data' => array(
                        'html' => $html,
                        'paged' => $settings['paged'],
                        'posts' => $posts,
                        'max' => $max,
                    ),
                )
            );
        } catch (Exception $e) {
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}

/**
 * @param string $str - String containing line breaks
 * @param string $tag - ul or ol
 * @param string $class - classes to add if required
 */
function wiseguard_nl2html($str,  $args = [])
{
    $args = wp_parse_args($args, [
        'item_before' => '<div>',
        'item_after'  => '</div>',
        'before'      => '',
        'after'       => ''
    ]);
    $bits = explode("\n", $str);

    $newstring = [];
    foreach ($bits as $bit) {
        $newstring[] = $args['item_before'] . $bit . $args['item_after'];
    }
    return $args['before'] . implode('', $newstring) . $args['after'];
}

/**
 * ================================================
 * All function for Demo Data
 * 
 * @package CMS Theme
 * @subpackage Fotis
 * @since 1.0
 * ================================================
 * 
*/
/* Create Demo Data */
if(!function_exists('wiseguard_enable_export_mode')){
    function wiseguard_enable_export_mode() {
        return defined('DEV_MODE') && DEV_MODE == true ? true : false;
    }
}
add_filter('swa_ie_export_mode', 'wiseguard_enable_export_mode');
if (!function_exists('wiseguard_cpt_dev_mode')) {
    function wiseguard_cpt_dev_mode()
    {
        return defined('DEV_MODE') && DEV_MODE == true ? true : false;
    }
}
add_filter('cpt_dev_mode', 'wiseguard_cpt_dev_mode');
/**
 * Update custom post type edit with Elementor
 * **/
if (!function_exists('wiseguard_elementor_cpts')) {
    add_action('theme_core_ie_after_import', 'wiseguard_elementor_cpts');
    add_action('after_switch_theme', 'wiseguard_elementor_cpts');
    function wiseguard_elementor_cpts(){
        $default = (array)get_option('elementor_cpt_support');
        $cpt_support = array_merge(
            $default, 
            [
                //core
                'post',
                'page',
                'cms-footer',
                'cms-header-top',
                'cms-mega-menu',
                'portfolio',
                // theme
                'cms-career',
                'cms-case',
                'cms-industry',
                'cms-service',
                'cms-sidenav',
                // WooCommerce
                //'product'
            ]
        );
        update_option( 'elementor_cpt_support', $cpt_support );
    }
}
/**
 * Update Option TranslatePress
 * 
 * */
if(!function_exists('wiseguard_translatepress_configs')){
    add_action('plugins_loaded', 'wiseguard_translatepress_configs');
    add_action('activate_translatepress-multilingual/index.php', 'wiseguard_translatepress_configs');
    add_action('theme_core_ie_after_import', 'wiseguard_translatepress_configs');
    function wiseguard_translatepress_configs(){
        $trp_settings = (array)get_option('trp_settings');
        $trp_settings['trp-ls-floater'] = 'no'; // Hide Floating language selection
        $trp_settings['trp-ls-show-poweredby'] = 'no'; // Hide "Powered by TranslatePress"
        update_option( 'trp_settings', $trp_settings );
    }
}

/*
 *  Dashboard Configurations
 */
if (!function_exists('wiseguard_cpt_dashboard_config')) {
    add_filter('cpt_dashboard_config', 'wiseguard_cpt_dashboard_config');
    function wiseguard_cpt_dashboard_config()
    {
        return [
            'documentation_link'  => 'https://farost.gitbook.io/wiseguard-wordpress-theme',
            'ticket_link'         => 'mailto:farost.agency@gmail.com',
            'video_tutorial_link' => 'https://www.youtube.com/channel/UCR57ptzvmUEhJ_jIB7QQavg',
            'demo_link'           => 'http://demo.farost.net/wiseguard',
        ];
    }
}
add_filter('cms_documentation_link', function(){ return 'https://farost.gitbook.io/wiseguard-wordpress-theme';});
add_filter('cms_ticket_link', function(){ return ['type' => 'url', 'link' => 'mailto:farost.agency@gmail.com'];});
add_filter('cms_video_tutorial_link', function(){ return 'https://www.youtube.com/channel/UCR57ptzvmUEhJ_jIB7QQavg';});
/**
 * =========================
 * End Demo Data
 * =========================
 * */

/* ------ Disable Lazy loading ---- */
//add_filter('wp_lazy_loading_enabled', '__return_false');
//add_filter('wiseguard_enable_lazy_load', '__return_false');
