<?php
/**
 * Custom template tags for this theme.
 *
 * @package WiseGuard
 */

/**
 * Page loading.
 **/
function wiseguard_page_loading(){
    $page_loading = wiseguard_get_opt('show_page_loading', false);
    if ($page_loading) { ?>
        <section id="cms-loadding" class="cms-loader">
            <div class="loading-spinner">
                <div class="cms-bounce1"></div>
                <div class="cms-bounce2"></div>
                <div class="cms-bounce3"></div>
            </div>
        </section>
    <?php }
}
/**
 * Header Top
 * 
 * **/
if(!function_exists('wiseguard_header_top')){
    function wiseguard_header_top($args = []){
        if(is_singular('cms-header-top') || is_singular('cms-footer')  || is_singular('cms-mega-menu') ) return;
        $args = wp_parse_args($args, []);
        $header_top_layout = wiseguard_get_opts('header_top_layout', '', 'header_top_custom');
        $cms_post = get_post($header_top_layout);
        if(in_array($header_top_layout, ['-1', '0', 'none', ''])) return;
        if (!is_wp_error($cms_post) && $cms_post->ID == $header_top_layout && class_exists('Elementor_Theme_Core') && class_exists('\Elementor\Plugin')){
            $content = \Elementor\Plugin::$instance->frontend->get_builder_content( $header_top_layout );
            if(empty($content)){
                $content = $cms_post->post_content;
            }
        } else {
            $content = $cms_post->post_content;
        }
    ?>
    <div id="cms-header-top" class="cms-header-top empty-none"><?php 
        printf('%s', $content); 
    ?></div>
    <?php
    }
}
/**
 * Header layout.
 **/
function wiseguard_header_layout(){
    $header_layout = wiseguard_get_opts('header_layout', '1', 'header_custom');
    if ($header_layout == '0' || is_singular('cms-header-top') || is_singular('cms-footer')  || is_singular('cms-mega-menu')) return;
    get_template_part('template-parts/header/header-layout', $header_layout);
}
/**
 * Header
 * Header Class
 * **/
if(!function_exists('wiseguard_header_classes')){
    function wiseguard_header_classes($class = ''){
        $classes = [
            'cms-header',
            'header-layout-'.wiseguard_get_opts('header_layout','1', 'header_custom'),
            'sticky-'.wiseguard_get_opts( 'header_sticky', 'off', 'header_custom'),
            'transparent-'.wiseguard_get_opts( 'header_transparent', 'off', 'header_custom'),
            $class
        ];
        if(wiseguard_get_opts( 'header_transparent', 'off', 'header_custom') === 'on'){
            $classes[] = 'header-transparent';
        }
        return implode(' ', array_filter($classes));
    }
}
/**
 * Header Container class 
 * 
 * **/
if(!function_exists('wiseguard_header_container_classes')){
    function wiseguard_header_container_classes($class = ''){
        $classes = [
            'cms-header-main',
            wiseguard_get_opts( 'header_width', 'container', 'header_custom'),
            $class
        ];
        return implode(' ', array_filter($classes));
    }
}
/**
 * Header Search 
 * 
 * */
if(!function_exists('wiseguard_header_search')){
    function wiseguard_header_search($args = []){
        $args = wp_parse_args($args, [
            'class'       => 'site-header-item menu-color',
            'echo'        => true,
            'text'        => '',
            'modal-mode'  => 'fade',
            'modal-slide' => '',
            'modal-class' => '',
            'placeholder' => '',
            'before'      => '',
            'after'       => ''  
        ]);
        $search_on = wiseguard_get_opts('search_icon', 'off', 'header_custom');
        if($search_on != 'on') return;
        add_action('wp_footer', 'wiseguard_search_popup');
        $classes = ['site-header-search cms-modal', $args['class']];
    ob_start();
    printf('%s', $args['before']);
?>
    <div class="<?php echo implode(' ', array_filter($classes)); ?>" data-modal="#cms-modal-search" data-focus=".cms-search-popup-input" data-modal-mode="<?php echo esc_attr($args['modal-mode']); ?>" data-modal-slide="<?php echo esc_attr($args['modal-slide']); ?>" data-modal-class="<?php echo esc_attr($args['modal-class']); ?>" <?php if(!empty($args['placeholder'])): ?>data-modal-placeholder="<?php echo esc_attr($args['placeholder']); ?>"<?php endif; ?>><i class="cmsi-search search-toggle"></i><?php printf('%s', $args['text']); ?></div>
<?php
    printf('%s', $args['after']);
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
/**
 * Header Search Popup
 */
function wiseguard_search_popup(){ 
    $placeholder = wiseguard_get_opt('search_field_placeholder', esc_html__('Type Words Then Enter', 'wiseguard'));
    ?>
    <div id="cms-modal-search" class="cms-modal-html cms-modal-search">
        <i class="cms-modal-close cms-close cmsi-remove"></i>
        <div class="cms-modal-content">
            <form role="search" method="get" class="search-popup relative" action="<?php echo esc_url(home_url('/')); ?>">
                <input type="text" placeholder="<?php echo esc_attr($placeholder); ?>" name="s" class="cms-search-popup-input"/>
                <button type="submit" class="cms-search-popup-submit"><i class="cmsi-search"></i></button>
            </form>
        </div>
    </div>
<?php }
/**
 * Header Cart
 * 
 * */
if(!function_exists('wiseguard_header_cart')){
    function wiseguard_header_cart($args = []){
        $args = wp_parse_args($args, [
            'class' => '',
            'echo'  => true,
            'position' => 'dropdown' // modal
        ]);
        $cart_on = wiseguard_get_opts('cart_icon', 'off', 'header_custom');
        if(!class_exists('Woocommerce') || $cart_on != 'on') return;
        $classes  =['site-header-item site-header-cart menu-color', $args['class']];

        switch ($args['position']) {
            case 'modal':
                $classes[] = 'cms-modal';
                add_action('wp_footer', 'wiseguard_cart_content');
                break;
            
            default:
                $classes[] = 'cms-touchedside';
                add_action('wiseguard_cart_dropdown', 'wiseguard_cart_content_dropdown');
                break;
        }
    ob_start();
?>
    <div class="<?php  echo implode(' ', array_filter($classes)); ?>" data-modal="#cms-modal-cart">
        <div class="relative cms-cart-icon">
            <i class="cmsi-shopping-cart cart-icon"></i>
            <span class="cart-counter cart_total"><?php echo sprintf( _n( '%d', '%d', WC()->cart->cart_contents_count, 'wiseguard' ), WC()->cart->cart_contents_count ); ?></span>
        </div>
        <?php do_action('wiseguard_cart_dropdown'); ?>
    </div>
<?php
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
/**
 * Header Cart
 * Update cart count
 * 
 * */
if(!function_exists('wiseguard_woocommerce_add_to_cart_fragments')){
    add_filter('woocommerce_add_to_cart_fragments', 'wiseguard_woocommerce_add_to_cart_fragments', 10, 1 );
    function wiseguard_woocommerce_add_to_cart_fragments( $fragments ) {
        if(!class_exists('WooCommerce')) return;
        ob_start();
        ?><span class="cart-counter cart_total">
            <?php echo sprintf( _n( '%d', '%d', WC()->cart->cart_contents_count, 'wiseguard' ), WC()->cart->cart_contents_count ); ?>
        </span>
        <?php
        $fragments['.cart_total'] = ob_get_clean();

        return $fragments;
    }
}

/**
 * 
 * Cart Content
 * 
 */
function wiseguard_cart_content(){
    if (!class_exists('Woocommerce')) return;
?>
    <div id="cms-modal-cart" class="cms-modal-html cms-modal-slide cms-modal-cart cms-shadow-1">
        <span class="cms-modal-close cms-close cmsi-remove"></span>
        <div class="cms-modal-content">
            <div class="widget_shopping_cart cms-mousewheel">
                <div class="widget_shopping_cart_content">
                    <?php woocommerce_mini_cart(); ?>
                </div>
            </div>
        </div>
    </div>
<?php
}
function wiseguard_cart_content_dropdown(){
    if (!class_exists('Woocommerce')) return;
?>
    <div class="cms-header-cart-dropdown cms--touchedside overflow-hidden">
        <div class="widget_shopping_cart cms-mousewheel">
            <div class="widget_shopping_cart_content">
                <?php woocommerce_mini_cart(); ?>
            </div>
        </div>
    </div>
<?php
}
/**
 * Header Phone
 * */
if(!function_exists('wiseguard_header_phone_render')){
    function wiseguard_header_phone_render($args = []){
        $args = wp_parse_args($args, [
            'name'  => '',
            'class' => 'btn btn-outline btn-sm',
            'icon'  => 'cmsi-phone-alt',
            'data'  => [
                'default'     => 'btn-1',
                'transparent' => 'btn-white-25'
            ],
            'style' => ''
        ]);
        $phone_text = wiseguard_get_opt('h_phone'.$args['name'].'_text', '');
        $phone_number = wiseguard_get_opt('h_phone'.$args['name'].'_number', '');
        if(wiseguard_get_opts('h_phone'.$args['name'].'_on', 'off', 'header_custom') !== 'on' || empty($phone_number) ) return;
        $tel = str_ireplace(' ', '', $phone_number); // remove space for link

        $classes = ['h-btn', $args['class'], $args['style']];
    ?>
        <div class="site-header-item site-header-button site-header-phone d-flex">
            <a class="<?php echo implode(' ', array_filter($classes)); ?>" data-classes='<?php echo wp_json_encode($args['data']); ?>' href="tel:<?php echo esc_attr($tel);?>"><?php 
                if(!empty($args['icon'])) echo '<i class="phone-icon '.esc_attr($args['icon']).'"></i>';
                printf('<span class="cms-hidden-laptop lh-1"><span class="phone-text d-block pb-5 empty-none">%s</span>%s</span>', $phone_text, $phone_number);
            ?></a>
        </div>
    <?php
    }
}
if(!function_exists('wiseguard_header_phone_render2')){
    function wiseguard_header_phone_render2($args = []){
        $args = wp_parse_args($args, [
            'name'  => '',
            'class' => '',
            'icon'  => 'cmsi-phone-alt',
            'data'  => [
                'default'     => '',
                'transparent' => ''
            ],
            'style' => ''
        ]);
        $phone_text = wiseguard_get_opt('h_phone'.$args['name'].'_text', '');
        $phone_number = wiseguard_get_opt('h_phone'.$args['name'].'_number', '');
        if(wiseguard_get_opts('h_phone'.$args['name'].'_on', 'off', 'header_custom') !== 'on' || empty($phone_number) ) return;
        $tel = str_ireplace(' ', '', $phone_number); // remove space for link

        $classes = ['d-flex gap-20 align-items-center', $args['class'], $args['style']];
    ?>
        <div class="site-header-item site-header-phone site-header-phone-2 d-flex">
            <a class="<?php echo implode(' ', array_filter($classes)); ?>" data-classes='<?php echo wp_json_encode($args['data']); ?>' href="tel:<?php echo esc_attr($tel);?>"><?php 
                if(!empty($args['icon'])) echo '<i class="phone-icon '.esc_attr($args['icon']).'"></i>';
                printf('<span class="cms-hidden-laptop lh-1 font-700"><span class="phone-text d-block pb-10 empty-none">%s</span>%s</span>', $phone_text, $phone_number);
            ?></a>
        </div>
    <?php
    }
}
if(!function_exists('wiseguard_header_phone_render3')){
    function wiseguard_header_phone_render3($args = []){
        $args = wp_parse_args($args, [
            'name'  => '',
            'class' => '',
            'icon'  => 'cmsi-phone-alt'
        ]);
        $phone_text = wiseguard_get_opt('h_phone'.$args['name'].'_text', '');
        $phone_number = wiseguard_get_opt('h_phone'.$args['name'].'_number', '');
        if(wiseguard_get_opts('h_phone'.$args['name'].'_on', 'off', 'header_custom') !== 'on' || empty($phone_number) ) return;
        $tel = str_ireplace(' ', '', $phone_number); // remove space for link

        $classes = ['d-flex gap-20 align-items-center', $args['class']];
    ?>
        <a class="<?php echo implode(' ', array_filter($classes)); ?>" href="tel:<?php echo esc_attr($tel);?>"><?php 
            if(!empty($args['icon'])) echo '<i class="phone-icon '.esc_attr($args['icon']).'"></i>';
            printf('%s', $phone_number);
        ?></a>
    <?php
    }
}
/**
 * Header Mail
 * */
if(!function_exists('wiseguard_header_mail_render')){
    function wiseguard_header_mail_render($args = []){
        $args = wp_parse_args($args, [
            'name'  => '',
            'class' => '',
            'icon'  => 'cmsi-email'
        ]);
        $email = wiseguard_get_opt('h_mail'.$args['name'].'_text', '');
        if(wiseguard_get_opts('h_mail'.$args['name'].'_on', 'off', 'header_custom') !== 'on' || empty($email) ) return;
        $classes = ['d-flex gap-20 align-items-center', $args['class']];
    ?>
        <a class="<?php echo implode(' ', array_filter($classes)); ?>" href="mailto:<?php echo esc_attr($email);?>"><?php 
            if(!empty($args['icon'])) echo '<i class="mail-icon '.esc_attr($args['icon']).'"></i>';
            printf('%s', $email);
        ?></a>
    <?php
    }
}
/**
 * Header Button
 * */
if(!function_exists('wiseguard_header_button_render')){
    function wiseguard_header_button_render($args = []){
        $args = wp_parse_args($args, [
            'name'       => 'h_btn',
            'wrap_class' => '',
            'class'      => 'btn btn-outline btn-sm',
            'icon'       => '',
            'data'       => [
                'default'     => '',
                'transparent' => ''
            ],
            'before' => '',
            'after'  => ''
        ]);
        $h_btn_text        = wiseguard_get_opt( $args['name'].'_text' );
        if(wiseguard_get_opts($args['name'].'_on', 'off', 'header_custom') !== 'on' || empty($h_btn_text)) return;

        $h_btn_link_type   = wiseguard_get_opt( $args['name'].'_link_type', 'page' );
        $h_btn_link        = wiseguard_get_opt( $args['name'].'_link' );
        $h_btn_link_custom = wiseguard_get_opt( $args['name'].'_link_custom' );
        $h_btn_target      = wiseguard_get_opt( $args['name'].'_target', '_self' );
        if ( $h_btn_link_type == 'page' ) {
            $h_btn_url = get_permalink( $h_btn_link );
        } else {
            $h_btn_url = $h_btn_link_custom;
        }

        $attrs = [
            'class'        => $args['class'],
            'data-classes' => $args['data']
        ];
        $wrap_classes = ['site-header-item site-header-button', $args['wrap_class']];

        printf('%s', $args['before']);
        
    ?>
    <div class="<?php echo wiseguard_nice_class($wrap_classes); ?>">
        <a class="h-btn <?php echo esc_attr($attrs['class']); ?>" data-classes=<?php echo wp_json_encode($args['data']); ?> href="<?php echo esc_url( $h_btn_url ); ?>" target="<?php echo esc_attr( $h_btn_target ); ?>">
            <?php printf( '<span class="cms-hidden-laptop-large">%1$s</span>%2$s', $h_btn_text, $args['icon'] ); ?>        
        </a>
    </div>
    <?php
    printf('%s', $args['after']);
    }
}
/**
 * Header
 * Side Nav
 * */
if(!function_exists('wiseguard_header_side_nav_render')){
    function wiseguard_header_side_nav_render($args = []){
        $hide_sidebar_icon = wiseguard_get_opts( 'hide_sidebar_icon', 'off', 'header_custom' );
        if ( $hide_sidebar_icon != 'on' ) return;
            $args = wp_parse_args($args, [
                'class' => '',
                'slide' => 'left'
            ]);
            $classes = array_filter(['site-side-navs cms-modal', $args['class']]);
        ?>
            <div class="<?php echo wiseguard_nice_class($classes); ?>" data-modal="#cms-side-nav" data-modal-slide="<?php echo esc_attr($args['slide']); ?>">
                <div class="site-side-nav"><span></span></div>
            </div>
        <?php
    }
}
add_action('wp_footer', 'wiseguard_header_side_nav_content_render');
if(!function_exists('wiseguard_header_side_nav_content_render')){
    function wiseguard_header_side_nav_content_render($args = []){
        $hide_sidebar_icon = wiseguard_get_opts( 'hide_sidebar_icon', 'off', 'header_custom' );
        if ( $hide_sidebar_icon !='on' ) return;
        $header_sidenav_layout = wiseguard_get_opts('header_sidenav_layout', 'none', 'hide_sidebar_icon');
        if(in_array($header_sidenav_layout, ['-1', '0', 'none', ''])) return;
        $cms_post = get_post($header_sidenav_layout);
        if (!is_wp_error($cms_post) && $cms_post->ID == $header_sidenav_layout && class_exists('Elementor_Theme_Core') && class_exists('\Elementor\Plugin')){
            $content = \Elementor\Plugin::$instance->frontend->get_builder_content( $header_sidenav_layout );
            if(empty($content)){
                $content = $cms_post->post_content;
            }
        } else {
            $content = $cms_post->post_content;
        }
        ?>
            <div id="cms-side-nav" class="cms-modal-html cms-modal-slide cms-modal-sidenav bg-primary-darken">
                <span class="cms-modal-close cms-close cmsi-remove"></span>
                <div class="cms-modal-content">
                    <div class="cms-sidenav-content cms-mousewheel">
                        <div class="cms-sidenav--content p-lr-70 p-lr-mobile-0">
                            <?php printf('%s', $content);  ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php
    }
}
/**
 * Header Tools Classes
 * 
 * */
if(!function_exists('wiseguard_header_tools_classes')){
    function wiseguard_header_tools_classes($args = []){
        $args = wp_parse_args($args, [
            'class' => ''
        ]);
        $h_btn_text   = wiseguard_get_opt( 'h_btn_text' );
        $h_btn2_text  = wiseguard_get_opt( 'h_btn2_text' );
        $phone_number = wiseguard_get_opt( 'h_phone_number' );
        $h_btn_on     = $h_btn2_on = $h_phone_on = 'off';
        if(wiseguard_get_opts('h_btn_on', 'off', 'header_custom') == 'on' && !empty($h_btn_text)){
            $h_btn_on = 'on';
        }
        if(wiseguard_get_opts('h_btn2_on', 'off', 'header_custom') == 'on' && !empty($h_btn2_text)){
            $h_btn2_on = 'on';
        };
        if(wiseguard_get_opts('h_phone_on', 'off', 'header_custom') == 'on' && !empty($phone_number) ){
            $h_phone_on = 'on';
        };
        $search_on         = wiseguard_get_opts('search_icon', 'off', 'header_custom');
        $cart_on           = wiseguard_get_opts('cart_icon', 'off', 'header_custom');
        $hide_sidebar_icon = wiseguard_get_opts( 'hide_sidebar_icon', 'off', 'header_custom' );

        if($search_on == 'on' || $cart_on == 'on' || $hide_sidebar_icon == 'on' || $h_btn_on == 'on' || $h_btn2_on == 'on' || $h_phone_on == 'on'){
            $classes[] = 'has-tools';
        } else {
            $classes[] = 'cms-hidden-min-desktop';
        }
        $classes[] = $args['class'];

        return wiseguard_nice_class($classes);
    }
}
/**
 * Header
 * Mega Menu
 * */
add_filter('cms_megamenu_render', 'wiseguard_cms_megamenu_render');
if(!function_exists('wiseguard_cms_megamenu_render')){
    function wiseguard_cms_megamenu_render($content, $before, $after){
        $before = $after = '';
        return $before.$content.$after;
    }
}
/**
 * Page title layout
 **/
function wiseguard_page_title_layout($args = []){
    // remove page title on some custom post type
    if(is_singular() && in_array(get_post_type(), ['cms-service', 'cms-industry', 'cms-case', 'cms-career'])) return;
    $header_transparent = '';
    if(wiseguard_get_opts('header_transparent', 'off', 'header_custom') == 'on'){
        $header_transparent = 'ptitle-header-transparent';
    }
    $args = wp_parse_args($args, [
        'show'            => wiseguard_get_opts('pagetitle', 'on', 'custom_ptitle'),
        'layout'          => wiseguard_get_opts('ptitle_layout', '', 'custom_ptitle'),
        'show_title'      => wiseguard_get_opts('show_title', 'on', 'custom_ptitle'),
        'show_breadcrumb' => wiseguard_get_opts('show_breadcrumb', 'on', 'custom_ptitle'),
        'ptitle_align'    => wiseguard_get_opts('ptitle_align', 'center', 'custom_ptitle'),
        'container'       => wiseguard_get_opts('content_width', 'container', 'on'),
        'class'           => ''
    ]);
    // Configs
    $ptitle_bg = wiseguard_get_opts('page_title_bg', ['background-color' => '#999', 'background-image' => ''], 'custom_ptitle');
    $args['class'] = implode(' ', array_filter([
        'cms-ptitle',
        'text-'.$args['ptitle_align'],
        !empty($ptitle_bg['background-image']) ? 'custom' : '',
        $header_transparent,
        $args['class']
    ]));
    if($args['show'] === 'off' || is_404() || is_singular('cms-header-top') || is_singular('cms-footer')  || is_singular('cms-mega-menu')) return;
    get_template_part('template-parts/page-title', $args['layout'], $args);
}
/**
 * Get page title and description.
 *
 * @return array Contains 'title'
 */
function wiseguard_get_page_titles(){
    $title = '';

    // Default titles
    if (!is_archive()) {
        // Posts page view
        if (is_home()) {
            // Only available if posts page is set.
            if (
                !is_front_page() &&
                ($page_for_posts = get_option('page_for_posts'))
            ) {
                $title = get_post_meta($page_for_posts, 'custom_title', true);
                if (empty($title)) {
                    $title = get_the_title($page_for_posts);
                }
            }
            if (is_front_page()) {
                $title = esc_html__('Blog', 'wiseguard');
            }
        }
        // Single page view
        elseif (is_page()) {
            $title = get_post_meta(get_the_ID(), 'custom_title', true);
            if (!$title) {
                $title = get_the_title();
            }
        } elseif (is_404()) {
            $title = esc_html__('404', 'wiseguard');
        } elseif (is_search()) {
            $title = esc_html__('Search results', 'wiseguard');
        } else {
            $title = get_post_meta(get_the_ID(), 'custom_title', true);
            if (!$title) {
                $title = get_the_title();
            }
        }
    } elseif (is_author()) {
        $title = esc_html__('Author:', 'wiseguard') . ' ' . get_the_author();
    }
    // Author
    else {
        $title = get_the_archive_title();
        if (class_exists('WooCommerce') && is_shop()) {
            $title = esc_html__('Our Shop', 'wiseguard');
        }
    }

    return [
        'title' => $title,
    ];
}
/**
 * Prints HTML for breadcrumbs.
 */
function wiseguard_breadcrumb($args= []){
    if (!class_exists('CMS_Breadcrumb')) {
        return;
    }

    $breadcrumb = new CMS_Breadcrumb();
    $entries = $breadcrumb->get_entries();

    if (empty($entries)) {
        return;
    }
    $args = wp_parse_args($args, [
        'icon_home' => '',
        'class'     => '',
        'before'    => '',
        'after'     => ''
    ]);

    ob_start();

    foreach ($entries as $key => $entry) {
        $entry = wp_parse_args($entry, array(
            'label' => '',
            'url' => ''
        ));

        if (empty($entry['label'])) {
            continue;
        }

        echo '<li>';
        if (!empty($entry['url'])) {
            printf(
                '<a class="breadcrumb-entry" href="%1$s">%2$s%3$s</a>',
                esc_url($entry['url']),
                $key === 0 ?  $args['icon_home'] : '',
                esc_attr($entry['label'])
            );
        } else {
            printf('<span class="breadcrumb-entry" >%s</span>', esc_html($entry['label']));
        }

        echo '</li>';
    }

    $output = ob_get_clean();

    if ($output) {
        printf('%s', $args['before']);
            printf('<ul class="%1$s">%2$s</ul>',implode(' ', array_filter(['cms-breadcrumb unstyled', $args['class']])), $output);
        printf('%s', $args['after']);
    }
}
/**
 * Main Content 
 * 
 * **/
if(!function_exists('wiseguard_show_sidebar')){
    function wiseguard_show_sidebar($sidebar=''){
        $sidebar_on = wiseguard_get_opt('sidebar_on','off');
        if(empty($sidebar)){
            if(wiseguard_is_woocommerce()){
                $sidebar_name = 'sidebar-product';
            } else {
                $sidebar_name = 'sidebar-post';
            }
        } else {
            $sidebar_name = $sidebar;
        }
        /*$show_sidebar = ($sidebar_on === 'on' && is_active_sidebar($sidebar_name) && !in_array(get_post_type(), [
            'page',
            'portfolio',
            'cms-footer',
            'cms-header-top',
            'cms-service',
            'cms-industry', 
            'cms-case',
            'cms-porfolio',
            'cms-career'
        ]));*/
        $show_sidebar = ($sidebar_on === 'on' && is_active_sidebar($sidebar_name));
        return $show_sidebar;
    }
}
if(!function_exists('wiseguard_main_content_classes')){
    function wiseguard_main_content_classes($args = []){
        $args = wp_parse_args($args, [
            'class' => '',
            'sidebar' => ''
        ]);
        $classes = [
            'cms-main',
            $args['class']
        ];
        if(wiseguard_is_built_with_elementor()){
            $classes[] = 'is-elementor';
        } else {
            $classes[] = wiseguard_get_opts('content_width', 'container', 'on');
            if(wiseguard_is_woocommerce()){
                if(wiseguard_show_sidebar($args['sidebar']) && !is_singular('product') ){
                    $classes[] = 'cms-main-sidebar cms-woo-sidebar d-flex justify-content-center';
                } else {
                    $classes[] = 'cms-woo-content';
                }
            } elseif(wiseguard_show_sidebar($args['sidebar'])){
                $classes[] = 'cms-main-sidebar d-flex justify-content-center';
            } else {
                $classes[] = 'no-sidebar';
            }
        }
        echo implode(' ', array_filter($classes));
    }
}
function wiseguard_content_has_sidebar_open($sidebar=''){
    if(!wiseguard_show_sidebar($sidebar)) return;
    ?>
    <div class="cms-main-content">
    <?php
}
function wiseguard_content_has_sidebar_close($sidebar=''){
    if(!wiseguard_show_sidebar($sidebar)) return;
    ?>
    </div>
    <?php
}

/**
 * Footer layout
 **/
function wiseguard_footer(){
    if(is_singular('cms-header-top') || is_singular('cms-footer')  || is_singular('cms-mega-menu') || is_singular('cms-sidenav')) return;
    //get_template_part('template-parts/footer-layout','');
    $footer_layout = wiseguard_get_opts('footer_layout', '1', 'footer_custom');

    switch ($footer_layout){
        case 'none':
            break;
        case '1':
            wiseguard_footer_copyright();
            break;
        default : 
            wiseguard_footer_elementor_builder();
            break;
    }
}
/*
 * Footer css class
*/
if(!function_exists('wiseguard_footer_css_class')){
    function wiseguard_footer_css_class($args = []){
        $args = wp_parse_args($args, [
            'class' => ''
        ]);
        $footer_layout = wiseguard_get_opts( 'footer_layout', '1' );
        $footer_fixed = wiseguard_get_opts('footer_fixed', '0');
        $css_classes = [
            'cms-footer',
            'relative'
        ];
        if(!in_array($footer_layout, ['-1', '0', '1', 'none'])) {
            $css_classes[] = 'cms-footer-elementor';
        } else {
            $css_classes[] = wiseguard_get_opts('content_width', 'container', 'on');
        }

        if($footer_fixed == '1') $css_classes[] = 'cms-footer-fixed';
        echo implode(' ', array_filter($css_classes));
    }
}
if(!function_exists('wiseguard_default_copyright_text')){
    function wiseguard_default_copyright_text($text = '', $args = []){
        $args = wp_parse_args($args, [
            'link_color'       => '',
            'link_hover_color' => ''
        ]);
        if(!empty($text)){
            $default_copyright_text = $text;
        } else {
            $default_copyright_text = sprintf( esc_html__('&copy;%s %s, All Rights Reserved. With Love by %s ','wiseguard'), date('Y') , get_bloginfo('name'), '<a href="'.esc_url('https://farost.net/').'" target="_blank" rel="nofollow" class="'.$args['link_color'].' '.$args['link_hover_color'].'">'.esc_html__('farost.net','wiseguard').'</a>');
        }
        return $default_copyright_text;
    }
}
if(!function_exists('wiseguard_footer_copyright')){
    function wiseguard_footer_copyright($args = []){
        $args = wp_parse_args($args, [
            'class' => ''
        ]);
        $classes = ['cms-copyright-text cms-footer-copyright', $args['class']];

        if(is_404()) $classes[] = 'text-center';
    ?>
    <div class="<?php echo implode(' ', array_filter($classes));?>">
        <?php echo wiseguard_default_copyright_text(); ?>
    </div>
    <?php
    }
}
/**
* Footer elementor builder
*
*/
if(!function_exists('wiseguard_footer_elementor_builder')){
    function wiseguard_footer_elementor_builder(){
        if(!class_exists('Elementor\Plugin') || !class_exists('Elementor_Theme_Core')) return;
        $footer_layout = wiseguard_get_opts('footer_layout', '1', 'footer_custom');
        if(in_array($footer_layout, ['-1', '0', '1', 'none'])) return;
        $cms_post = get_post($footer_layout);
        if (!is_wp_error($cms_post) && $cms_post->ID == $footer_layout){
            $content = \Elementor\Plugin::$instance->frontend->get_builder_content( $footer_layout );
            if(!empty($content)){
                etc_print_html($content);
            } else {
            ?>
            <div class="<?php etc_print_html(wiseguard_get_opts('content_width', 'container', 'on'));  ?> cms-copyright-text cms-footer-copyright">
                <?php etc_print_html($cms_post->post_content); ?>
            </div>
            <?php 
            }
        }
    }
}

/**
 * Post Term
 * 
 *  */
if(!function_exists('wiseguard_get_the_term_list')){
    function wiseguard_get_the_term_list( $post_id, $taxonomy, $sep = '', $class = '' ) {
        $terms = get_the_terms( $post_id, $taxonomy );
        
        if ( is_wp_error( $terms ) ) {
            return $terms;
        }
     
        if ( empty( $terms ) ) {
            return false;
        }
     
        $links = array();
     
        foreach ( $terms as $term ) {
            $link = get_term_link( $term, $taxonomy );
            if ( is_wp_error( $link ) ) {
                return $link;
            }
            $links[] = '<a href="' . esc_url( $link ) . '" class="'.wiseguard_nice_class(['cms-term', $class]).'">' . $term->name . '</a>';
        }
     
        /**
         * Filters the term links for a given taxonomy.
         *
         * The dynamic portion of the hook name, `$taxonomy`, refers
         * to the taxonomy slug.
         *
         * Possible hook names include:
         *
         *  - `term_links-category`
         *  - `term_links-post_tag`
         *  - `term_links-post_format`
         *
         * @since 2.5.0
         *
         * @param string[] $links An array of term links.
         */
        $term_links = apply_filters( "cms_term_links-{$taxonomy}", $links );  // phpcs:ignore WordPress.NamingConventions.ValidHookName.UseUnderscores
     
        return implode( $sep, $term_links );
    }
}
if(!function_exists('wiseguard_the_terms')){
    function wiseguard_the_terms( $post_id, $taxonomy, $sep = ', ', $class = '' ) {
        $term_list = wiseguard_get_the_term_list( $post_id, $taxonomy, $sep, $class );
        if ( is_wp_error( $term_list ) ) {
            return false;
        }
     
        /**
         * Filters the list of terms to display.
         *
         * @since 2.9.0
         *
         * @param string $term_list List of terms to display.
         * @param string $taxonomy  The taxonomy name.
         * @param string $sep       String to use between the terms.
         * @param string $class     CSS class to use in the terms.
         */
        echo apply_filters( 'wiseguard_the_terms', $term_list, $taxonomy, $sep, $class );
    }
}

/**
 * Post Title
 * 
 * */
if(!function_exists('wiseguard_entry_title')){
    function wiseguard_entry_title($args= []){
        $args=wp_parse_args($args, [
            'class' => ''
        ]);
        $classes = array_filter(['cms-post-title', $args['class']]);
    ?>
        <h2 class="<?php echo implode(' ', $classes); ?>">
            <a href="<?php echo esc_url( get_permalink() ); ?>">
                <?php if ( is_sticky() ) { ?>
                    <i class="cmsi-thumbtack"></i>
                <?php } ?>
                <?php the_title(); ?>
            </a>
        </h2>
    <?php
    }
}
if(!function_exists('wiseguard_entry_single_title')){
    function wiseguard_entry_single_title($args = []){
        $args  = wp_parse_args($args, [
            'class' => ''
        ]);
        $classes = ['cms-post-title cms-post-single-title', $args['class'], 'empty-none'];
    ?>
        <h2 class="<?php echo wiseguard_nice_class($classes); ?>"><?php 
            the_title(); 
        ?></h2>
    <?php
    }
}

/**
 * Post Thumbnail
 * 
 * */
if(!function_exists('wiseguard_entry_thumbnail')){
    function wiseguard_entry_thumbnail($args = []){
        if ( !has_post_thumbnail() ) return;
        $args = wp_parse_args($args, [
            'class'     => '',
            'size'      => 'medium',
            'img_class' => '',
            'content'   => ''
        ]);
        $classes      = wiseguard_nice_class(['cms-post-thumbnail', 'relative', $args['class']]);
        $opt_prefix   = is_singular('post')?'post_':'archive_';
    ?>
        <div class="<?php echo esc_attr($classes); ?>"><?php
            wiseguard_the_post_thumbnail([
                'size'    => $args['size'],
                'class'   => $args['img_class']
            ]);
            printf('%s', $args['content']);
        ?></div>
    <?php
    }
}
if(!function_exists('wiseguard_the_post_thumbnail')){
    function wiseguard_the_post_thumbnail($args = []){
        $args = wp_parse_args($args, [
            'size'    => 'medium',
            'class'   => '',
            'content' => ''
        ]);
        $image_size_w = get_option($args['size'].'_size_w');
        $image_size_h = get_option($args['size'].'_size_h');
        printf(
            '<img width="%1$s" height="%2$s" class="%3$s" data-src="%4$s" />',
            $image_size_w,
            $image_size_h,
            implode(' ', array_filter(['cms-lazy loading', $args['class']])),
            get_the_post_thumbnail_url(null, $args['size'])
        );
    }
}
/**
 * Get excerpt
 * The excerpt with custom length.
 * @return string      
 */
function wiseguard_get_the_excerpt($length = 55, $post = null){
    $post = get_post($post);

    if (empty($post) || 0 >= $length) {
        return '';
    }

    if (post_password_required($post)) {
        return esc_html__('Post password required.', 'wiseguard');
    }

    $content = apply_filters(
        'the_content',
        strip_shortcodes($post->post_content)
    );
    $content = str_replace(']]>', ']]&gt;', $content);

    $excerpt_more = apply_filters('wiseguard_excerpt_more', '&hellip;');
    $excerpt = wp_trim_words($content, $length, $excerpt_more);

    return $excerpt;
}
/**
* Print post excerpt based on length.
*
* @param integer $length
*/
if (!function_exists('wiseguard_entry_excerpt')) :
    function wiseguard_entry_excerpt($args)
    {
        $args = wp_parse_args($args, [
            'length' => 55,
            'class' => ''
        ]);
        $cms_the_excerpt = get_the_excerpt();
        $classes = ['cms-excerpt', $args['class']];
    ?>
    <div class="<?php echo wiseguard_nice_class($classes); ?>"><?php
        if (!empty($cms_the_excerpt)) {
            echo esc_html($cms_the_excerpt);
        } else {
            echo wp_kses_post(wiseguard_get_the_excerpt($args['length']));
        }
    ?></div>
    <?php
    }
endif;
/**
 * Post Page Link
 * */
function wiseguard_entry_link_pages(){
    wp_link_pages(array(
        'before'      => '<div class="cms-page-links d-flex gap" style="--cms-gap:20px;">',
        'after'       => '</div>',
        'link_before' => '<span>',
        'link_after'  => '</span>',
    ));
}
/**
 * Post Readmore
 * */
if(!function_exists('wiseguard_entry_readmore')){
    function wiseguard_entry_readmore(){
    ?>
        <div class="cms-readmore">
            <a class="btn btn-lg btn-secondary btn-hover-accent" href="<?php echo esc_url( get_permalink() ); ?>"><?php echo esc_html__( 'Explore More', 'wiseguard' ); ?><span class="btn-icon cmsi-arrow-circle-right text-22 rtl-flip"></span></a>
        </div>
    <?php
    }
}
/**
 * Prints post meta
 */
if (!function_exists('wiseguard_post_meta')) :
    function wiseguard_post_meta($args = [])
    {
        $args = wp_parse_args($args, [
            'opt_prefix' => 'archive_',
            'class'      => '',
            'gap'        => '',
            'tax'        => 'category',
            'separator'  => '',
        ]);
        $classes = ['cms-post-meta', $args['class'], 'd-flex'];
        if(!empty($args['gap'])) $classes[] = 'gap';
        $author_on     = (bool) wiseguard_get_opt($args['opt_prefix'].'author_on', true);
        $categories_on = (bool) wiseguard_get_opt($args['opt_prefix'].'categories_on', true);
        $date_on       = (bool) wiseguard_get_opt($args['opt_prefix'].'date_on', true);
        $comments_on   = (bool) wiseguard_get_opt($args['opt_prefix'].'comments_on', false);

        $metas = [];
        if ($author_on || $comments_on || $categories_on || $date_on) : ?>
            <div class="<?php echo implode(' ', array_filter($classes)); ?>" style="<?php echo esc_attr($args['gap']); ?>">
                <?php if ($categories_on ) : ?>
                    <div class="meta-item category empty-none"><?php wiseguard_the_terms(get_the_ID(), $args['tax'], ', ', 'text-white text-hover-primary'); ?></div>
                <?php endif; ?>
                <?php if ($date_on ) : ?>
                    <div class="meta-item date"><?php echo get_the_date(); ?></div>
                <?php endif; ?>
                <?php if ($author_on) : ?>
                    <div class="separator"></div>
                    <div class="meta-item author">
                        <?php wiseguard_the_author_posts_link([
                            'text'       => '',
                            'link_class' => ''
                        ]); ?>
                    </div>
                <?php endif; ?>
                <?php if ($comments_on) : ?>
                    <div class="separator"></div>
                    <div class="meta-item comment"><?php wiseguard_comment_number(['link_class' => 'text-secondary-lighten']); ?></div>
                <?php endif; ?>
            </div>
        <?php endif;
    }
endif;
/**
 * Author Post link
 * 
 * */
if(!function_exists('wiseguard_the_author_posts_link')){
    function wiseguard_the_author_posts_link($args = []){
        $args = wp_parse_args($args, [
            'id'         => '',   
            'text'       => '',
            'link_class' => '',
            'object'     => ''
        ]);
        if(! is_object($args['object'])){
            global $authordata;
            if ( ! is_object( $authordata ) ) {
                return '';
            }
            $user_id = $authordata->ID;
        } else {
            $user_id = $args['object']->post_author;
        }

        

        $link = sprintf(
            '%1$s<a href="%2$s" title="%3$s" class="%4$s" rel="author">%5$s</a>',
            $args['text'],
            esc_url( get_author_posts_url( $user_id , get_the_author_meta('user_nicename',$user_id ) ) ),
            /* translators: %s: Author's display name. */
            esc_attr( sprintf( esc_html__( 'Posts by %s', 'wiseguard' ), get_the_author_meta('display_name', $user_id ) ) ),
            $args['link_class'],
            get_the_author_meta('display_name', $user_id )
        );
        echo apply_filters( 'wiseguard_the_author_posts_link', $link );
    }
}
/**
 * Post Comment Count
 * */
if(!function_exists('wiseguard_comments_link')){
    function wiseguard_comment_number($args=[]){
        $args = wp_parse_args($args, [
            'title_class' => 'text-body text-hover-secondary-lighten',
            'link_class'  => ''  
        ]);
        $number = get_comments_number();
        switch ($number) {
            case '1':
                $html = '<span class="'.$args['title_class'].'">'.esc_html__('Comment','wiseguard').':&nbsp;</span>'.number_format_i18n($number);
                break;
            default:
                $html = '<span class="'.$args['title_class'].'">'.esc_html__('Comments','wiseguard').':&nbsp;</span>'.number_format_i18n($number);
                break;
        }
    ?>
        <a href="<?php the_permalink(); ?>" class="<?php echo esc_attr($args['link_class']); ?>"><?php printf('%s', $html);?></a>
    <?php
    }
}
/**
 * Prints tag list
 */
if (!function_exists('wiseguard_entry_tagged_in')){
    function wiseguard_entry_tagged_in($args = []) {
        $show_tag  = (bool)wiseguard_get_opt('post_tags_on', true);
        $tags_list = get_the_tag_list('', ' ');
        if (!$tags_list || !$show_tag) return;
        $args = wp_parse_args($args, [
            'class' => ''
        ]);
    ?>
        <div class="<?php echo implode(' ', array_filter(['cms-post-tags', $args['class']])) ?>">
            <div class="label w-100"><?php esc_html_e('Post Tags','wiseguard'); ?>:</div>
            <div class="tagcloud">
                <?php printf('%2$s', '', $tags_list); ?>
            </div>
        </div>
    <?php 
    }
}

/**
 * List socials share for post.
 * 
 * 
 */
function wiseguard_socials_share_default($args = []) {
    $args = wp_parse_args($args, [
        'class' => '',
        'show' => false
    ]);
    if(!$args['show']) return;
    $img_url = get_the_post_thumbnail_url();
    ?>
    <div class="<?php echo implode(' ', array_filter(['cms-social-share', $args['class']])) ?>">
        <div class="label w-100"><?php echo esc_html__('Share:', 'wiseguard'); ?></div>
        <div class="d-flex gap" style="--cms-gap:10px;--cms-gap-mobile:10px;">
            <a title="<?php echo esc_attr__('Facebook', 'wiseguard'); ?>" target="_blank"
               href="https://www.facebook.com/sharer/sharer.php?u=<?php the_permalink(); ?>" 
               class="cmsi-facebook"></a>
            <a title="<?php echo esc_attr__('Twitter', 'wiseguard'); ?>" target="_blank"
               href="https://twitter.com/intent/tweet?url=<?php the_permalink(); ?>&text=<?php the_title(); ?>" 
               class="cmsi-twitter-circle"></a>
            <a title="<?php echo esc_attr__('LinkedIn', 'wiseguard'); ?>" target="_blank"
               href="http://www.linkedin.com/shareArticle?mini=true&url=<?php the_permalink(); ?>&title=<?php the_title(); ?>" 
               class="cmsi-linkedin-circle"></a>
        </div>
    </div>
    <?php
}
function wiseguard_social_share_pinterest(){
?>
    <a title="<?php echo esc_attr__('Pinterest', 'wiseguard'); ?>" target="_blank"
               href="http://pinterest.com/pin/create/button/?url=<?php the_permalink(); ?>&media=<?php echo esc_url($img_url); ?>&description=<?php the_title(); ?>%20" 
               class="cmsi-pinterest d-none"></a>
<?php
}

/**
 * Get category taxomomy name by post type
 * 
 * */
function wiseguard_post_taxonomy_category(){
    switch (get_post_type()) {
        case 'cms-industry':
            return 'industry-category';
            break;
        case 'cms-service':
            return 'service-category';
            break;
        case 'cms-case':
            return 'case-category';
            break;
        case 'cms-career':
            return 'career-category';
            break;
        default:
            return 'category';
            break;
    }
}
/**
 * Custom Comment List
 */
function wiseguard_comment_list($comment, $args, $depth){
    $add_below = 'comment'; 
    $comment_classes = [empty($args['has_children'])?'':'parent'];
    ?>
    <div id="comment-<?php comment_ID(); ?>" <?php comment_class(implode(' ', array_filter($comment_classes)));?> >
        <div class="d-flex gap" style="--cms-gap-mobile:20px;">
            <div class="comment-avatar flex-auto"><?php if ($args['avatar_size'] != 0) {
                echo get_avatar($comment, 100, '', '', ['class' => '']);
            } ?></div>
            <div class="comment-content flex-basic flex-mobile-auto">
                <div class="comment-heading d-flex gap-10 align-items-center mt-n8">
                    <div class="comment-name font-700 text-secondary-darken">
                        <?php printf('%s', get_comment_author_link()); ?>
                    </div>
                    <div class="comment-meta">
                        <?php echo get_comment_date() . ' - ' . get_comment_time(); ?>
                    </div>
                </div>
                <div class="comment-text"><?php 
                    if(is_singular('product')){
                        woocommerce_review_display_rating();
                        echo '<div class="pb-15 clearfix"></div>';
                    }
                    //
                    comment_text();
                ?></div>
                <div class="comment-reply">
                    <?php comment_reply_link(
                          array_merge($args, [
                              'add_below' => $add_below,
                              'depth'     => $depth,
                              'max_depth' => $args['max_depth']
                          ])
                      ); ?>
                </div>
            </div>
        </div>

<?php }

/* Author Social */
function wiseguard_get_user_social(){
    $user_facebook = get_user_meta(get_the_author_meta('ID'), 'user_facebook', true);
    $user_twitter = get_user_meta(get_the_author_meta('ID'), 'user_twitter', true);
    $user_linkedin = get_user_meta(get_the_author_meta('ID'), 'user_linkedin', true);
    $user_skype = get_user_meta(get_the_author_meta('ID'), 'user_skype', true);
    $user_youtube = get_user_meta(get_the_author_meta('ID'), 'user_youtube', true);
    $user_vimeo = get_user_meta(get_the_author_meta('ID'), 'user_vimeo', true);
    $user_tumblr = get_user_meta(get_the_author_meta('ID'), 'user_tumblr', true);
    $user_rss = get_user_meta(get_the_author_meta('ID'), 'user_rss', true);
    $user_pinterest = get_user_meta(get_the_author_meta('ID'), 'user_pinterest', true);
    $user_instagram = get_user_meta(get_the_author_meta('ID'), 'user_instagram', true);
    $user_yelp = get_user_meta(get_the_author_meta('ID'), 'user_yelp', true);

    ?>
    <div class="user-social unstyled d-flex gap" style="--cms-gap:10px;--cms-gap-mobile:10px;">
        <?php if (!empty($user_facebook)) { ?>
            <a href="<?php echo esc_url($user_facebook); ?>" class="cmsi-facebook"></a>
        <?php } ?>
        <?php if (!empty($user_twitter)) { ?>
            <a href="<?php echo esc_url($user_twitter); ?>" class="cmsi-twitter-circle"></a>
        <?php } ?>
        <?php if (!empty($user_linkedin)) { ?>
            <a href="<?php echo esc_url($user_linkedin); ?>" class="cmsi-linkedin-circle"></a>
        <?php } ?>
        <?php if (!empty($user_rss)) { ?>
            <a href="<?php echo esc_url($user_rss); ?>" class="cmsi-rss"></a>
        <?php } ?>
        <?php if (!empty($user_instagram)) { ?>
            <a href="<?php echo esc_url($user_instagram); ?>" class="cmsi-instagram"></a>
        <?php } ?>
        <?php if (!empty($user_skype)) { ?>
            <a href="<?php echo esc_url($user_skype); ?>" class="cmsi-skype"></a>
        <?php } ?>
        <?php if (!empty($user_pinterest)) { ?>
            <a href="<?php echo esc_url($user_pinterest); ?>" class="cmsi-pinterest"></a>
        <?php } ?>
        <?php if (!empty($user_vimeo)) { ?>
            <a href="<?php echo esc_url($user_vimeo); ?>" class="cmsi-vimeo-v"></a>
        <?php } ?>
        <?php if (!empty($user_youtube)) { ?>
            <a href="<?php echo esc_url($user_youtube); ?>" class="cmsi-youtube"></a>
        <?php } ?>
        <?php if (!empty($user_yelp)) { ?>
            <a href="<?php echo esc_url($user_yelp); ?>" class="cmsi-yelp"></a>
        <?php } ?>
        <?php if (!empty($user_tumblr)) { ?>
            <a href="<?php echo esc_url($user_tumblr); ?>" class="cmsi-tumblr"></a>
        <?php } ?>

    </div> <?php
}
/**
 * Prints posts pagination based on query
 *
 * @param WP_Query $query Custom query, if left blank, this will use global query ( current query )
 *
 * @return void
 */
if(!function_exists('wiseguard_posts_pagination')){
    function wiseguard_posts_pagination($query = null, $ajax = false){
        if ($ajax) {
            add_filter('paginate_links', 'wiseguard_ajax_paginate_links');
        }

        $classes = array();

        if (empty($query)) {
            $query = $GLOBALS['wp_query'];
        }

        if (empty($query->max_num_pages) || !is_numeric($query->max_num_pages) || $query->max_num_pages < 2) {
            return;
        }

        $paged = $query->get('paged', '');

        if (!$paged && is_front_page() && !is_home()) {
            $paged = $query->get('page', '');
        }

        $paged = $paged ? intval($paged) : 1;

        $pagenum_link = html_entity_decode(get_pagenum_link());
        $query_args = array();
        $url_parts = explode('?', $pagenum_link);

        if (isset($url_parts[1])) {
            wp_parse_str($url_parts[1], $query_args);
        }

        $pagenum_link = remove_query_arg(array_keys($query_args), $pagenum_link);
        $pagenum_link = trailingslashit($pagenum_link) . '%_%';

        $html_prev = '<i class="cmsi-arrow-left text-10 rtl-flip"></i>';
        $html_next = '<i class="cmsi-arrow-right text-10 rtl-flip"></i>';
        $paginate_links_args = array(
            'base'      => $pagenum_link,
            'total'     => $query->max_num_pages,
            'current'   => $paged,
            'mid_size'  => 1,
            'add_args'  => array_map('urlencode', $query_args),
            'prev_text' => $html_prev,
            'next_text' => $html_next,
        );
        if ($ajax) {
            $paginate_links_args['format'] = '?page=%#%';
        }
        $links = paginate_links($paginate_links_args);
        if ($links):
        ?>
            <nav class="navigation posts-pagination <?php echo esc_attr($ajax ? 'ajax' : ''); ?>">
                <div class="posts-page-links d-flex">
                    <?php
                        printf('%s', $links);
                    ?>
                </div>
            </nav>
        <?php
        endif;
    }
}

/**
 * Single Post
 * 
 * Display navigation to next/previous post when applicable.
 */
function wiseguard_post_nav_default(){
    if(!wiseguard_get_opt('post_navigation_on', true)) return;
    global $post;
    $previous = (is_attachment()) ? get_post($post->post_parent) : get_adjacent_post(false, '', true);
    $next = get_adjacent_post(false, '', false);

    if (!$next && !$previous) {
        return;
    }
    ?>
    <?php
    $next_post = get_next_post();
    $previous_post = get_previous_post();

    if (!empty($next_post) || !empty($previous_post)) {
        ?>
        <div class="cms-nav-links d-flex gap justify-content-between" style="--cms-gap:40px;">
            <?php if (is_a($previous_post, 'WP_Post') && get_the_title($previous_post->ID) != '') {
                $prev_img_id = get_post_thumbnail_id($previous_post->ID);
                $prev_img_url = wp_get_attachment_image_src($prev_img_id, 'thumbnail');
                ?>
                <a class="nav-item nav-post-prev" href="<?php echo esc_url(get_permalink($previous_post->ID)); ?>">
                    <i class="nav-icon cmsi-arrow-left text-10 rtl-flip"></i>
                    <span><?php echo esc_html__('Prev Post', 'wiseguard'); ?></span>
                </a>
            <?php } else { echo  '<span></span>';} ?>
            <?php if (is_a($next_post, 'WP_Post') && get_the_title($next_post->ID) != '') {
                $next_img_id = get_post_thumbnail_id($next_post->ID);
                $next_img_url = wp_get_attachment_image_src($next_img_id, 'thumbnail');
                ?>
                <a class="nav-item nav-post-next cms-radius-4" href="<?php echo esc_url(get_permalink($next_post->ID)); ?>">
                    <span><?php echo esc_html__('Next Post', 'wiseguard'); ?></span>
                    <i class="nav-icon cmsi-arrow-right text-10 rtl-flip"></i>
                </a>
            <?php } ?>
        </div>
    <?php }
}
/**
 * Single Post Comments
 * 
 * Comment Form
 * Move comment field to bottom
 * 
 * **/
function wiseguard_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    unset( $fields['cookies'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
add_filter( 'comment_form_fields', 'wiseguard_comment_field_to_bottom' );
/**
 * Single Post Comments
 * 
 * Comment Form
 * Comment form fields
**/
if(!function_exists('wiseguard_comment_form_args')){
    function wiseguard_comment_form_args($args = []){
        $args = wp_parse_args($args, []);
        $commenter = [
            'comment_author' => '',
            'comment_author_email' => ''
        ];
        $cms_comment_fields = array(
            'id_form'              => 'commentform',
            'title_reply_before'   => '<h3 id="reply-title" class="comment-reply-title">',
            'title_reply'          => is_singular('product') ? esc_attr__('Leave A Review','wiseguard') : esc_attr__( 'Leave A Reply', 'wiseguard'),
            'title_reply_to'       => is_singular('product') ? esc_attr__('Leave A Review To','wiseguard').'%s' : esc_attr__('Leave A Reply To','wiseguard').'%s',
            'cancel_reply_link'    => is_singular('product') ? esc_attr__( 'Cancel Review', 'wiseguard') : esc_attr__( 'Cancel Reply', 'wiseguard'),
            'id_submit'            => 'submit',
            'class_submit'         => 'btn-cmt-submit btn btn-xl btn-secondary-regular btn-hover-accent',
            'label_submit'         => is_singular('product') ? esc_attr__('Submit Review','wiseguard') : esc_attr__('Submit Comment','wiseguard'),
            'submit_button'        => '<button name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s">%4$s<i class="cmsi-arrow-circle-right-large rtl-flip text-32 pl-25"></i></button>', 
            'comment_notes_before' => '',
            'comment_field'        =>  '',
        );

        $cms_fields = [];
        $cms_fields['open'] = '';
        if(!is_user_logged_in()){
            $cms_fields['open'] .= wiseguard_comment_rating_fields([
                'echo' => false,
                'class' => 'mb-20'
            ]);
            $cms_fields['open'] .= wiseguard_woocommerce_comment_rating_fields([
                'echo' => false,
                'class' => 'mb-20'
            ]);
        }
        //open
        $cms_fields['open'] .= '<div class="cms-comment-form-fields-wrap d-flex gutter" style="--gutter-mobile:20px;">';
        // author
        $cms_fields['author'] = '<div class="comment-form-field comment-form-author col-4 col-mobile-12">'.
                    '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
                    '" size="30" placeholder="'.esc_attr__('Name', 'wiseguard').'"/></div>';
        // email 
        $cms_fields['email'] = '<div class="comment-form-field comment-form-email col-4 col-mobile-12">'.
                    '<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .
                    '" size="30" placeholder="'.esc_attr__('Email', 'wiseguard').'"/></div>';
        // website
        $cms_fields['website'] = '<div class="comment-form-field comment-form-website col-4 col-mobile-12">'.
                    '<input id="website" name="website" type="text" value="" size="30" placeholder="'.esc_attr__('Website', 'wiseguard').'"/></div>';
        // cookies (remove default cookies field)
        //$cms_fields['cookies'] = '';
        //Close 
        //$cms_fields['close'] = '</div>';

        $fields =  apply_filters( 'comment_form_default_fields', $cms_fields);
        $cms_comment_fields['fields'] = $fields;

        // Comment Field Message
        $cms_comment_fields['comment_field'] = '';
        if(is_user_logged_in()){
            $cms_comment_fields['comment_field'] .= wiseguard_comment_rating_fields([
                'echo' => false,
                'class' => 'col-12'
            ]);
            $cms_comment_fields['comment_field'] .= wiseguard_woocommerce_comment_rating_fields([
                'echo' => false,
                'class' => 'col-12'
            ]);
        }
        $cms_comment_fields['comment_field'] .= '<div class="comment-form-field comment-form-comment col-12"><textarea id="comment-msg" name="comment" cols="45" rows="8" placeholder="'.esc_attr__('Comment', 'wiseguard').'" aria-required="true">' .'</textarea></div>';
        // Close
        $cms_comment_fields['comment_field'] .= '</div>';

        // Note
        //$cms_comment_fields['comment_field'] .= '<div class="cmt-note pt-15">'.__('Please note, comments must be approved before they are published', 'wiseguard').'</div>';

        // Cookies
        if ( has_action( 'set_comment_cookies', 'wp_set_comment_cookies' ) && get_option( 'show_comments_cookies_opt_in' ) ) {
            $consent = empty( $commenter['comment_author_email'] ) ? '' : ' checked="checked"';
     
            $cms_comment_fields['comment_field'] .= sprintf(
                '<p class="comment-form-cookies-consent">%s %s</p>',
                sprintf(
                    '<input id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" type="checkbox" value="yes"%s />',
                    $consent
                ),
                sprintf(
                    '<label for="wp-comment-cookies-consent">%s</label>',
                    __( 'Save my name, email, and website in this browser for the next time I comment.','wiseguard' )
                )
            );
        }
        return $cms_comment_fields;
    }
}
// function for inline style
// make some configs
if (!function_exists('wiseguard_configs')) {
    function wiseguard_configs($value)
    {
        // accent color 
        $accent_color   = apply_filters('wiseguard_accent_color', [
            'regular' => '#aeca2e',
            'lighten' => '#a9c622',
            'darken'  => '#9eba26'
        ]);
        // primary color
        $primary_color   = apply_filters('wiseguard_primary_color', [
            'regular'  => '#001841',
            'lighten'  => '#010d20',
            'darken'   => '#01112b',
        ]);
        // secondary
        $secondary_color = apply_filters('wiseguard_secondary_color', [
            'regular'  => '#1543a0',
            'lighten'  => '#15459e',
            'darken'   => '#1e4773'
        ]);
        // logo
        $logo_w       = '186';
        $logo_h       = '51';
        $logo_w_sm    = '44';
        $logo_h_sm    = '51';
        $transparent_menu_color = ['regular' => '#ffffff', 'hover' => '#ffffff', 'active' => '#ffffff'];
        $header_height = '110';
        $header_width = '320';

        // body typo
        $body_font    = apply_filters('wiseguard_body_font','Roboto');
        $body_color   = apply_filters('wiseguard_body_color',[
            'regular' => '#7f8ba0'
        ]);
        // heading typo
        $heading_font    = apply_filters('wiseguard_heading_font', 'Libre Franklin');
        $heading_color   = apply_filters('wiseguard_heading_color', [
            'regular' => $primary_color['regular']
        ]);
        // Buttons
        $btn_font     = apply_filters('wiseguard_btn_font', 'Roboto');
        // Link
        $link_color = [
            'regular' => $primary_color['regular'], 
            'hover'   => $accent_color['regular'], 
            'active'  => $accent_color['regular']
        ];
        // Meta
        $meta_color = apply_filters('wiseguard_meta_color', $body_color['regular']);

        $accent_color_cf = [];
        foreach ($accent_color as $key => $accent_color_value) {
            $accent_color_cf[$key] =  wiseguard_get_opts('accent_color', $accent_color, 'color_custom')[$key];
        }
        $primary_color_cf = [];
        foreach ($primary_color as $key => $primary_color_value) {
            $primary_color_cf[$key] =  wiseguard_get_opts('primary_color', $primary_color, 'color_custom')[$key];
        }
        $secondary_color_cf = [];
        foreach ($secondary_color as $key => $secondary_color_value) {
            $secondary_color_cf[$key] =  wiseguard_get_opts('secondary_color', $secondary_color, 'color_custom')[$key];
        }

        $heading_color_cf = [];
        foreach ($heading_color as $key => $heading_color_value) {
            $heading_color_cf[$key] =  wiseguard_get_opts('heading_color', $heading_color, 'color_custom')[$key];
        }
        $configs = [
            // color
            'accent_color'    => $accent_color_cf,
            'primary_color'   => $primary_color_cf,
            'secondary_color' => $secondary_color_cf,
            'heading_color'   => $heading_color_cf,
            'link_color' => [
                'regular' => wiseguard_get_opts('link_color', $link_color, 'color_custom')['regular'],
                'hover'   => wiseguard_get_opts('link_color', $link_color, 'color_custom')['hover'],
                'active'  => wiseguard_get_opts('link_color', $link_color, 'color_custom')['active'],
            ],
            // body typo
            'body' => [
                'bg'          => '#fff',
                'family'      => wiseguard_get_opts('body_font_typo', ['font_family' => $body_font])['font_family'],
                'size'        => '17px',
                'weight'      => substr(wiseguard_get_opts('body_font_typo', ['font_style' => '400normal'])['font_style'], 0, 3),
                'style'       => substr(wiseguard_get_opts('body_font_typo', ['font_style' => '400normal'])['font_style'], 3),
                'color'       => wiseguard_get_opts('body_color', $body_color, 'color_custom')['regular'],
                'line-height' => 1.667,
            ],
            // Heading typo
            'heading' => [
                'family'      => wiseguard_get_opts('heading_font_typo', ['font_family' => $heading_font],'on')['font_family'],
                'weight'      => substr(wiseguard_get_opts('heading_font_typo', ['font_style' => '700normal'],'on')['font_style'], 0, 3),
                'style'       => substr(wiseguard_get_opts('heading_font_typo', ['font_style' => '700normal'],'on')['font_style'], 3),
                'line-height' => '1.375'
            ],
            // Meta
            'meta'  => [
                'color' => wiseguard_get_opts('meta_color', $meta_color)
            ],
            // Header 
            'header'    => [
                'height' => wiseguard_get_opts('header_height', ['height' => $header_height], 'header_custom')['height'].'px'
            ],
            // logo
            'logo'  => [
                'width'     => wiseguard_get_opts('logo_maxh',['width' => $logo_w, 'height' => $logo_h], 'header_custom')['width'],
                'height'    => wiseguard_get_opts('logo_maxh',['width' => $logo_w, 'height' => $logo_h], 'header_custom')['height'],
                'width-mobile'  => wiseguard_get_opts('logo_maxh_sm',['width' => $logo_w_sm, 'height' => $logo_h_sm],'header_custom')['width'],
                'height-mobile' => wiseguard_get_opts('logo_maxh_sm',['width' => $logo_w_sm, 'height' => $logo_h_sm],'header_custom')['height']
            ],
            // menu color
            'menu_color' => [
                'regular' => wiseguard_get_opts('main_menu_color', $primary_color)['regular'],
                'hover'   => wiseguard_get_opts('main_menu_color', $secondary_color)['regular'],
                'active'  => wiseguard_get_opts('main_menu_color', $secondary_color)['regular'],
            ],
            // transparent menu color
            'transparent_menu_color' => [
                'regular' => wiseguard_get_opts('transparent_menu_color', $transparent_menu_color)['regular'],
                'hover'   => wiseguard_get_opts('transparent_menu_color', $transparent_menu_color)['hover'],
                'active'  => wiseguard_get_opts('transparent_menu_color', $transparent_menu_color)['active'],
            ],
            // Dropdown

            // Page title
            'ptitle'  => [
                'color'      => '#fff',
                'bg-color'   => wiseguard_get_opts('page_title_bg', ['background-color' => '#c0c0c0', 'background-image' => ''], 'custom_ptitle')['background-color'],
                'bg-image'   => 'url('.wiseguard_get_opts('page_title_bg', ['background-color' => '#c0c0c0', 'background-image' => ''], 'custom_ptitle')['background-image'].')',
                'bg-overlay' => wiseguard_get_opts('page_title_overlay', 'rgba(var(--cms-primary-darken-rgb), 0.35)', 'custom_ptitle')
            ]
        ];
        return $configs[$value];
    }
}
if(!function_exists('wiseguard_theme_colors')){
    function wiseguard_theme_colors($args = []){
        $args = wp_parse_args($args, [
            'custom' => true
        ]);
        $colors = [
            'accent'    => wiseguard_configs('accent_color'),
            'primary'   => wiseguard_configs('primary_color'),
            'secondary' => wiseguard_configs('secondary_color'),
            'heading'   => wiseguard_configs('heading_color')
        ];
        $others = [
            'link' => wiseguard_configs('link_color'),
            'body' => ['color' => wiseguard_configs('body')['color']],
            'menu' => wiseguard_configs('menu_color')
        ];
        $opts = ['' => esc_html__('Default','wiseguard')];
        foreach ($colors as $key => $value) {
            if(is_array($value)){
                foreach ($value as $_key => $_value) {
                    $opts[$key.'-'.$_key] = $key.' '.$_key.'('.$_value.')';
                }
            } else {
                $opts[$key] = $key.'('.$value.')';
            }
        }
        $opts['white']  = esc_html__('White','wiseguard');
        $opts['body-darken']  = esc_html__('Body Darken','wiseguard');
        $opts['body-lighten']  = esc_html__('Body Lighten','wiseguard');
        $opts['grey']  = esc_html__('Grey','wiseguard').' (#f3f5fa)';
        $opts['grey2']  = esc_html__('Grey #2','wiseguard').' (#fbfcfd)';
        $opts['grey3']  = esc_html__('Grey #3','wiseguard').' (#edf0f8)';
        
        if($args['custom']){
            $opts['custom'] = esc_html__('Custom','wiseguard');
        }
        return $opts;
    }
}

if (!function_exists('wiseguard_hex_to_rgb')) {
    function wiseguard_hex_to_rgb($color)
    {

        $default = '0,0,0';

        //Return default if no color provided
        if (empty($color))
            return $default;

        //Sanitize $color if "#" is provided 
        if ($color[0] == '#') {
            $color = substr($color, 1);
        }

        //Check if color has 6 or 3 characters and get values
        if (strlen($color) == 6) {
            $hex = array($color[0] . $color[1], $color[2] . $color[3], $color[4] . $color[5]);
        } elseif (strlen($color) == 3) {
            $hex = array($color[0] . $color[0], $color[1] . $color[1], $color[2] . $color[2]);
        } else {
            return $default;
        }

        //Convert hexadec to rgb
        $rgb = array_map('hexdec', $hex);

        $output = implode(",", $rgb);

        //Return rgb(a) color string
        return $output;
    }
}

if (!function_exists('wiseguard_inline_styles')) {
    function wiseguard_inline_styles()
    {
        ob_start();
        // CSS Variable
        $accent_colors          = wiseguard_configs('accent_color');
        $primary_colors         = wiseguard_configs('primary_color');
        $secondary_colors       = wiseguard_configs('secondary_color');
        //
        $body                   = wiseguard_configs('body');
        $heading                = wiseguard_configs('heading');
        $heading_colors         = wiseguard_configs('heading_color');
        $meta                   = wiseguard_configs('meta');
        $link_color             = wiseguard_configs('link_color');
        //
        $header                 = wiseguard_configs('header');
        $logo                   = wiseguard_configs('logo');
        $menu_color             = wiseguard_configs('menu_color');
        $transparent_menu_color = wiseguard_configs('transparent_menu_color');
        //
        $ptitle                 = wiseguard_configs('ptitle');
        echo ':root{';
        // color rgb
        foreach ($accent_colors as $key => $value) {
            printf('--cms-accent-%1$s-rgb: %2$s;', str_replace('#', '', $key), wiseguard_hex_to_rgb($value));
        }
        foreach ($primary_colors as $key => $value) {
            printf('--cms-primary-%1$s-rgb: %2$s;', str_replace('#', '', $key), wiseguard_hex_to_rgb($value));
        }
        foreach ($secondary_colors as $key => $value) {
            printf('--cms-secondary-%1$s-rgb: %2$s;', str_replace('#', '', $key), wiseguard_hex_to_rgb($value));
        }
        foreach ($heading_colors as $key => $value) {
            printf('--cms-heading-%1$s-rgb: %2$s;', str_replace('#', '', $key), wiseguard_hex_to_rgb($value));
        }
        // color hex
        foreach ($accent_colors as $key => $value) {
            printf('--cms-accent-%1$s: %2$s;', str_replace('#', '', $key), $value);
        }
        foreach ($primary_colors as $key => $value) {
            printf('--cms-primary-%1$s: %2$s;', str_replace('#', '', $key), $value);
        }
        foreach ($secondary_colors as $key => $value) {
            printf('--cms-secondary-%1$s: %2$s;', str_replace('#', '', $key), $value);
        }
        foreach ($heading_colors as $key => $value) {
            printf('--cms-heading-%1$s: %2$s;', str_replace('#', '', $key), $value);
        }
        // Body
        foreach ($body as $key => $value) {
            if($key === 'family') $value = '\''.$value.'\', sans-serif';
            printf('--cms-body-%1$s: %2$s;', $key, $value);
        }
        // Heading
        foreach ($heading as $key => $value) {
            if($key === 'family') $value = '\''.$value.'\', sans-serif';
            printf('--cms-heading-%1$s: %2$s;', $key, $value);
        }
        // meta
        foreach ($meta as $key => $value) {
            printf('--cms-meta-%1$s: %2$s;', $key, $value);
        }
        // link color
        foreach ($link_color as $color => $value) {
            printf('--cms-link-%1$s-color: %2$s;', $color, $value);
        }
        // Header
        foreach ($header as $key => $value) {
            printf('--cms-header-%1$s: %2$s;', $key, $value);
        }
        // Logo
        foreach ($logo as $key => $value) {
            printf('--cms-logo-%1$s: %2$s;', $key, $value.'px');
        }
        // Menu color
        foreach ($menu_color as $color => $value) {
            printf('--cms-menu-%1$s: %2$s;', $color, $value);
        }
        // Menu color rgb
        foreach ($menu_color as $color => $value) {
            printf('--cms-menu-%1$s-rgb: %2$s;', str_replace('#', '', $color), wiseguard_hex_to_rgb($value));
        }
        // Transparent Menu color
        foreach ($transparent_menu_color as $color => $value) {
            printf('--cms-menu-transparent-%1$s: %2$s;', $color, $value);
        }
        // Transparent Menu color rgb
        foreach ($transparent_menu_color as $color => $value) {
            printf('--cms-menu-transparent-%1$s-rgb: %2$s;', str_replace('#', '', $color), wiseguard_hex_to_rgb($value));
        }
        // Page title
        foreach ($ptitle as $key => $value) {
            printf('--cms-ptitle-%1$s: %2$s;', $key, $value);
        }
        echo '}';
        return ob_get_clean();
    }
}
// end function for inline style

/**
 * Render Attributes
 * 
 * */
if(!function_exists('wiseguard_render_attrs')){
    function wiseguard_render_attrs($attrs = []){
        if(!is_array($attrs) || empty($attrs)) return;
        $atts = [];
        foreach ($attrs as $key => $attr) {
            $atts[] = $key.'="'.implode(' ', array_filter((array)$attr)).'"';
        }
        echo implode(' ', array_filter($atts));
    }
}

/**
 * Theme Options
 * 
 * **/
/**
 * Get Page List
 * @return array
 */
if (!function_exists('wiseguard_list_page')) {
    function wiseguard_list_page($default = [])
    {
        $page_list = array();
        if (!empty($default))
            $page_list[$default['value']] = $default['label'];
        $pages = get_pages(array('hierarchical' => 0, 'posts_per_page' => '-1'));
        foreach ($pages as $page) {
            $page_list[$page->ID] = $page->post_title;
        }
        return $page_list;
    }
}

/**
 * Get Post List
 * @return array
 */
if (!function_exists('wiseguard_list_post')) {
    function wiseguard_list_post($post_type = 'post', $default = false)
    {
        $post_list = array();
        if ($default) {
            $post_list['none'] = esc_html__('None', 'wiseguard');
            $post_list['-1'] = esc_html__('Default', 'wiseguard');
        }
        $posts = get_posts(array('post_type' => $post_type, 'posts_per_page' => '-1'));
        foreach ($posts as $post) {
            $post_list[$post->ID] = $post->post_title;
        }
        return $post_list;
    }
}

/**
 * Get theme option based on its id.
 *
 * @param string $opt_id Required. the option id.
 * @param mixed $default Optional. Default if the option is not found or not yet saved.
 *                         If not set, false will be used
 *
 * @return mixed
 */
function wiseguard_get_opt($opt_id, $default = false){
    $opt_name = wiseguard_get_opt_name();
    if (empty($opt_name)) {
        return $default;
    }
    global ${$opt_name};
    if (!isset(${$opt_name}) || !isset(${$opt_name}[$opt_id])) {
        $options = get_option($opt_name);
    } else {
        $options = ${$opt_name};
    }
    if (
        !isset($options) ||
        !isset($options[$opt_id]) ||
        $options[$opt_id] === ''
    ) {
        return $default;
    }
    if (is_array($options[$opt_id]) && is_array($default)) {
        foreach ($options[$opt_id] as $key => $value) {
            if (isset($default[$key]) && $value === '') {
                $options[$opt_id][$key] = $default[$key];
            }
        }
    }
    return $options[$opt_id];
}

/**
 * Get theme option based on its id.
 *
 * @param string $opt_id Required. the option id.
 * @param mixed $default Optional. Default if the option is not found or not yet saved.
 *                         If not set, false will be used
 *
 * @return mixed
 */
function wiseguard_get_page_opt($opt_id, $default = false){
    $page_opt_name = wiseguard_get_page_opt_name();
    if (empty($page_opt_name)) {
        return $default;
    }
    $id = get_the_ID();
    if (!is_archive() && is_home()) {
        if (!is_front_page()) {
            $page_for_posts = get_option('page_for_posts');
            $id = $page_for_posts;
        }
    }

    // Get page option for Shop Page
    if (class_exists('WooCommerce') && is_shop()) {
        $id = get_option('woocommerce_shop_page_id');
    }

    return $options = !empty($id)
        ? get_post_meta(intval($id), $opt_id, true)
        : $default;
}

/**
 *
 * Get post format values.
 *
 * @param $post_format_key
 * @param bool $default
 *
 * @return bool|mixed
 */
function wiseguard_get_post_format_value( $id = null, $post_format_key = '', $default = '' ) {
    global $post;
    if ( $id === null ) {
        $id = $post->ID;
    }

    return $value = ( ! empty( $id ) && '' !== get_post_meta( $id, $post_format_key, true ) ) ? get_post_meta( $id, $post_format_key, true ) : $default;
}

/**
 * Get option based on its id.
 * get option of theme and page
 *
 * @param  string $opt_id Required. the option id.
 * @param  mixed $default Optional. Default if the option is not found or not yet saved.
 *                         If not set, false will be used
 * @return mixed
 */
function wiseguard_get_opts($opt_id, $default = false, $dependency = ''){
    $theme_opt = wiseguard_get_opt($opt_id, $default);
    $_dependency = wiseguard_get_page_opt($dependency);
    if($dependency === 'on' || $_dependency === 'on'){
        $page_opt = wiseguard_get_page_opt($opt_id, $theme_opt);
        if ($page_opt !== null && $page_opt !== '' && $page_opt !== '-1') {
            if (is_array($page_opt) && is_array($theme_opt)) {
                foreach ($page_opt as $key => $value) {
                    foreach ($theme_opt as $key => $value) {
                        if (empty($page_opt[$key]) || $page_opt[$key] === 'px') {
                            $page_opt[$key] = $theme_opt[$key];
                        }
                    }
                }
            }
            $theme_opt = $page_opt;
        }
    }
    return $theme_opt;
}

/**
 * Get opt_name for options instance args and for
 * getting option value.
 *
 * @return string
 */
function wiseguard_get_opt_name_default(){
    return apply_filters('wiseguard_opt_name', 'cms_theme_options');
}
function wiseguard_get_opt_name(){
    if (isset($_POST['opt_name']) && !empty($_POST['opt_name'])) {
        return $_POST['opt_name'];
    }
    $opt_name = wiseguard_get_opt_name_default();
    if (defined('ICL_LANGUAGE_CODE')) {
        if (ICL_LANGUAGE_CODE != 'all' && !empty(ICL_LANGUAGE_CODE)) {
            $opt_name = $opt_name . '_' . ICL_LANGUAGE_CODE;
        }
    }

    return $opt_name;
}

/**
 * Get opt_name for options instance args and for
 * getting option value.
 *
 * @return string
 */
function wiseguard_get_page_opt_name(){
    return apply_filters('wiseguard_page_opt_name', 'cms_page_options');
}

/**
 * Get opt_name for options instance args and for
 * getting option value.
 *
 * @return string
 */
function wiseguard_get_post_opt_name(){
    return apply_filters('wiseguard_post_opt_name', 'wiseguard_post_options');
}
/*====== End Theme Option ==========*/
/**
 * Elementor
 * All function for Elementor
 * 
 * **/

/**
 * Ajax Pagination
 * Use in Element Post Grid/Blog
 * 
 * */
if (!function_exists('wiseguard_ajax_paginate_links')) {
    function wiseguard_ajax_paginate_links($link)
    {
        $parts = parse_url($link);
        parse_str($parts['query'], $query);
        if (isset($query['page']) && !empty($query['page'])) {
            return '#' . $query['page'];
        } else {
            return '#1';
        }
    }
}

/**
 * Custom WP Menu
 * 
 * */
// add class to link
add_filter('nav_menu_link_attributes', function ($atts, $item, $args) {
    $atts['class'] = 'cms-menu-link';
    if(isset($args->link_class) && !empty($args->link_class)){
        $atts['class'] .= ' '.$args->link_class;
    }
    return $atts;
}, 10, 3);

// Custom Menu title
add_filter('nav_menu_item_title', 'wiseguard_nav_menu_item_title', 10, 2);
function wiseguard_nav_menu_item_title($title){
    $title = '<span class="menu-title title">'.$title.'</span>';
    return $title;
}
/**
 *  Menu type Category
 *  add post count to menu title
*/
add_filter('the_title', 'wiseguard_menu_item_category_count', 10, 2);
function wiseguard_menu_item_category_count($title, $post_ID)
{
    if( 'nav_menu_item' == get_post_type($post_ID) )
    {
        if( 'taxonomy' == get_post_meta($post_ID, '_menu_item_type', true) && 'category' == get_post_meta($post_ID, '_menu_item_object', true) )
        {
            $category = get_category( get_post_meta($post_ID, '_menu_item_object_id', true) );
            $title .= sprintf('<span class="count">%d</span>', $category->count);
            //$title .= '<span class="arrow cmsi-arrow-circle-right rtl-flip text-26"></span>';
        }
    }
    return $title;
}